@@ -829,6 +829,16 @@ public interface IDatabase extends Cloneable {
    */
   boolean isExplorable();
 
+  /**
+   * @return true if this is a relational database for which the connection can be tested.
+   */
+  boolean isTestable();
+
+  /**
+   * @return true if this is a relational database for which exploring is disabled
+   */
+  boolean isExploringDisabled();
+
   /**
    * @return The SQL on this database to get a list of sequences.
    */
@@ -1183,4 +1193,20 @@ public interface IDatabase extends Cloneable {
    *     the clause for.
    */
   String getSqlInsertClauseBeforeFields(IVariables variables, String schemaTable);
+
+  /**
+   * Returns a list of UI element IDs that should be excluded from the database editor. Databricks
+   * doesn't need database name or manual URL fields.
+   *
+   * @return List of element IDs to exclude
+   */
+  List<String> getRemoveItems();
+
+  /**
+   * Returns whether URL information should be hidden in test connection dialogs. Databricks URLs
+   * may contain sensitive authentication tokens.
+   *
+   * @return true to hide URL information in test connection results
+   */
+  boolean isHideUrlInTestConnection();
 }
