@@ -17,7 +17,11 @@
 
 package org.apache.hop.core.gui.plugin;
 
-import java.lang.annotation.*;
+import java.lang.annotation.Documented;
+import java.lang.annotation.ElementType;
+import java.lang.annotation.Retention;
+import java.lang.annotation.RetentionPolicy;
+import java.lang.annotation.Target;
 
 /** This annotation signals to the plugin system that the class is a GUI plugin. */
 @Documented
