@@ -29,8 +29,8 @@ public class HopJson {
    */
   public static final ObjectMapper newMapper() {
     ObjectMapper objectMapper = new ObjectMapper();
-    objectMapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
-    objectMapper.configure(SerializationFeature.INDENT_OUTPUT, false);
+    objectMapper.disable(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES);
+    objectMapper.disable(SerializationFeature.INDENT_OUTPUT);
     return objectMapper;
   }
 }
