@@ -81,13 +81,12 @@ public class FileLoggingEventListener implements IHopLoggingEventListener {
 
     try {
       Object messageObject = event.getMessage();
-      if (messageObject instanceof LogMessage) {
+      if (messageObject instanceof LogMessage message) {
         boolean logToFile = false;
 
         if (logChannelId == null) {
           logToFile = true;
         } else {
-          LogMessage message = (LogMessage) messageObject;
           // This should be fast enough cause cached.
           List<String> logChannelChildren =
               LoggingRegistry.getInstance().getLogChannelChildren(logChannelId);
