@@ -353,14 +353,13 @@ public class ValueMetaInternetAddress extends ValueMetaDate {
     // See if we need to convert a null value into a String
     // For example, we might want to convert null into "Empty".
     //
-    if (!Utils.isEmpty(ifNull)) {
+    if (!Utils.isEmpty(ifNull)
+        && (Utils.isEmpty(pol)
+            || pol.equalsIgnoreCase(Const.rightPad(new StringBuilder(nullValue), pol.length())))) {
       // Note that you can't pull the pad method up here as a nullComp variable
       // because you could get an NPE since you haven't checked isEmpty(pol)
       // yet!
-      if (Utils.isEmpty(pol)
-          || pol.equalsIgnoreCase(Const.rightPad(new StringBuilder(nullValue), pol.length()))) {
-        pol = ifNull;
-      }
+      pol = ifNull;
     }
 
     // See if the polled value is empty
@@ -394,7 +393,7 @@ public class ValueMetaInternetAddress extends ValueMetaDate {
     switch (trimType) {
       case IValueMeta.TRIM_TYPE_LEFT:
         strpol = new StringBuilder(pol);
-        while (strpol.length() > 0 && strpol.charAt(0) == ' ') {
+        while (!strpol.isEmpty() && strpol.charAt(0) == ' ') {
           strpol.deleteCharAt(0);
         }
         pol = strpol.toString();
@@ -402,7 +401,7 @@ public class ValueMetaInternetAddress extends ValueMetaDate {
         break;
       case IValueMeta.TRIM_TYPE_RIGHT:
         strpol = new StringBuilder(pol);
-        while (strpol.length() > 0 && strpol.charAt(strpol.length() - 1) == ' ') {
+        while (!strpol.isEmpty() && strpol.charAt(strpol.length() - 1) == ' ') {
           strpol.deleteCharAt(strpol.length() - 1);
         }
         pol = strpol.toString();
@@ -410,10 +409,10 @@ public class ValueMetaInternetAddress extends ValueMetaDate {
         break;
       case IValueMeta.TRIM_TYPE_BOTH:
         strpol = new StringBuilder(pol);
-        while (strpol.length() > 0 && strpol.charAt(0) == ' ') {
+        while (!strpol.isEmpty() && strpol.charAt(0) == ' ') {
           strpol.deleteCharAt(0);
         }
-        while (strpol.length() > 0 && strpol.charAt(strpol.length() - 1) == ' ') {
+        while (!strpol.isEmpty() && strpol.charAt(strpol.length() - 1) == ' ') {
           strpol.deleteCharAt(strpol.length() - 1);
         }
         pol = strpol.toString();
