@@ -360,7 +360,7 @@ public class ValueMetaTimestamp extends ValueMetaDate {
     switch (trimType) {
       case IValueMeta.TRIM_TYPE_LEFT:
         strpol = new StringBuilder(pol);
-        while (strpol.length() > 0 && strpol.charAt(0) == ' ') {
+        while (!strpol.isEmpty() && strpol.charAt(0) == ' ') {
           strpol.deleteCharAt(0);
         }
         pol = strpol.toString();
@@ -368,17 +368,17 @@ public class ValueMetaTimestamp extends ValueMetaDate {
         break;
       case IValueMeta.TRIM_TYPE_RIGHT:
         strpol = new StringBuilder(pol);
-        while (strpol.length() > 0 && strpol.charAt(strpol.length() - 1) == ' ') {
+        while (!strpol.isEmpty() && strpol.charAt(strpol.length() - 1) == ' ') {
           strpol.deleteCharAt(strpol.length() - 1);
         }
         pol = strpol.toString();
         break;
       case IValueMeta.TRIM_TYPE_BOTH:
         strpol = new StringBuilder(pol);
-        while (strpol.length() > 0 && strpol.charAt(0) == ' ') {
+        while (!strpol.isEmpty() && strpol.charAt(0) == ' ') {
           strpol.deleteCharAt(0);
         }
-        while (strpol.length() > 0 && strpol.charAt(strpol.length() - 1) == ' ') {
+        while (!strpol.isEmpty() && strpol.charAt(strpol.length() - 1) == ' ') {
           strpol.deleteCharAt(strpol.length() - 1);
         }
         pol = strpol.toString();
