@@ -148,7 +148,7 @@ public class Variables implements IVariables {
 
   @Override
   public synchronized String resolve(String aString) {
-    if (aString == null || aString.isEmpty()) {
+    if (Utils.isEmpty(aString)) {
       return aString;
     }
 
@@ -168,9 +168,8 @@ public class Variables implements IVariables {
     while (startIndex < resolved.length()) {
       int resolverIndex = resolved.indexOf(StringUtil.RESOLVER_OPEN);
       if (resolverIndex < 0) {
-        // There's nothing more to do here.
-        //
-        return null;
+
+        return resolved;
       }
 
       // Is there a close token?
@@ -242,9 +241,7 @@ public class Variables implements IVariables {
 
         // If we have a value to retrieve from the JSON we got back, we can do that:
         //
-        if (StringUtils.isEmpty(secretValue)) {
-          return resolvedArgument;
-        } else {
+        if (!StringUtils.isEmpty(secretValue)) {
           try {
             JSONObject js = (JSONObject) new JSONParser().parse(resolvedArgument);
             Object value = js.get(secretValue);
@@ -298,7 +295,7 @@ public class Variables implements IVariables {
   @Override
   public String resolve(String aString, IRowMeta rowMeta, Object[] rowData)
       throws HopValueException {
-    if (aString == null || aString.isEmpty()) {
+    if (Utils.isEmpty(aString)) {
       return aString;
     }
 
