@@ -58,7 +58,6 @@ import org.apache.hop.core.row.value.ValueMetaNumber;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.variables.Variables;
 import org.apache.hop.junit.rules.RestoreHopEnvironment;
-import org.junit.After;
 import org.junit.Before;
 import org.junit.BeforeClass;
 import org.junit.ClassRule;
@@ -77,18 +76,18 @@ public class DatabaseTest {
   private static final String[] TABLE_TYPES_TO_GET = {"TABLE", "VIEW"};
 
   // common fields
-  private String sql = "select * from employees";
-  private String columnName = "salary";
-  private ResultSet rs = mock(ResultSet.class);
-  private DatabaseMeta dbMetaMock = mock(DatabaseMeta.class);
-  private DatabaseMetaData dbMetaDataMock = mock(DatabaseMetaData.class);
-  private ILoggingObject log = mock(ILoggingObject.class);
-  private IDatabase iDatabase = mock(IDatabase.class);
+  private final String sql = "select * from employees";
+  private final String columnName = "salary";
+  private final ResultSet rs = mock(ResultSet.class);
+  private final DatabaseMeta dbMetaMock = mock(DatabaseMeta.class);
+  private final DatabaseMetaData dbMetaDataMock = mock(DatabaseMetaData.class);
+  private final ILoggingObject log = mock(ILoggingObject.class);
+  private final IDatabase iDatabase = mock(IDatabase.class);
 
-  private DatabaseMeta meta = mock(DatabaseMeta.class);
-  private PreparedStatement ps = mock(PreparedStatement.class);
-  private DatabaseMetaData dbMetaData = mock(DatabaseMetaData.class);
-  private ResultSetMetaData rsMetaData = mock(ResultSetMetaData.class);
+  private final DatabaseMeta meta = mock(DatabaseMeta.class);
+  private final PreparedStatement ps = mock(PreparedStatement.class);
+  private final DatabaseMetaData dbMetaData = mock(DatabaseMetaData.class);
+  private final ResultSetMetaData rsMetaData = mock(ResultSetMetaData.class);
   private Connection conn;
   private IVariables variables;
 
@@ -106,9 +105,6 @@ public class DatabaseTest {
     variables = new Variables();
   }
 
-  @After
-  public void tearDown() {}
-
   @Test
   public void testGetQueryFieldsFromDatabaseMetaData() throws Exception {
     DatabaseMeta meta = mock(DatabaseMeta.class);
@@ -134,10 +130,10 @@ public class DatabaseTest {
     db.setConnection(conn);
     IRowMeta iRowMeta = db.getQueryFieldsFromDatabaseMetaData();
 
-    assertEquals(iRowMeta.size(), 1);
-    assertEquals(iRowMeta.getValueMeta(0).getName(), columnName);
-    assertEquals(iRowMeta.getValueMeta(0).getOriginalColumnTypeName(), columnType);
-    assertEquals(iRowMeta.getValueMeta(0).getLength(), columnSize);
+    assertEquals(1, iRowMeta.size());
+    assertEquals(columnName, iRowMeta.getValueMeta(0).getName());
+    assertEquals(columnType, iRowMeta.getValueMeta(0).getOriginalColumnTypeName());
+    assertEquals(columnSize, iRowMeta.getValueMeta(0).getLength());
   }
 
   /**
@@ -473,7 +469,7 @@ public class DatabaseTest {
 
   @Test
   public void testDisconnectPstmCloseFail()
-      throws SQLException, HopDatabaseException, NoSuchFieldException, IllegalAccessException {
+      throws SQLException, NoSuchFieldException, IllegalAccessException {
     Database db = new Database(log, variables, meta);
     Connection connection = mockConnection(dbMetaData);
     db.setConnection(connection);
@@ -527,7 +523,7 @@ public class DatabaseTest {
     db.setConnection(mockConnection(dbMetaDataMock));
 
     String[] tableNames = db.getTablenames();
-    assertEquals(tableNames.length, 1);
+    assertEquals(1, tableNames.length);
   }
 
   @Test
@@ -596,8 +592,8 @@ public class DatabaseTest {
     db.setConnection(conn);
     IRowMeta iRowMeta = db.getQueryFieldsFromPreparedStatement(sql);
 
-    assertEquals(iRowMeta.size(), 1);
-    assertEquals(iRowMeta.getValueMeta(0).getName(), columnName);
+    assertEquals(1, iRowMeta.size());
+    assertEquals(columnName, iRowMeta.getValueMeta(0).getName());
     assertTrue(iRowMeta.getValueMeta(0) instanceof ValueMetaNumber);
   }
 
@@ -618,8 +614,8 @@ public class DatabaseTest {
     db.setConnection(conn);
     IRowMeta iRowMeta = db.getQueryFieldsFallback(sql, false, null, null);
 
-    assertEquals(iRowMeta.size(), 1);
-    assertEquals(iRowMeta.getValueMeta(0).getName(), columnName);
+    assertEquals(1, iRowMeta.size());
+    assertEquals(columnName, iRowMeta.getValueMeta(0).getName());
     assertTrue(iRowMeta.getValueMeta(0) instanceof ValueMetaNumber);
   }
 }
