@@ -28,7 +28,7 @@ import org.apache.hop.metadata.api.IHopMetadata;
     key = "type-1",
     name = "type 1",
     description = "This is a simple test object type 1",
-    image = "ui/images/dummy.svg")
+    image = "org/apache/hop/images/dummy.svg")
 public class MetadataType1 extends HopMetadataBase implements IHopMetadata {
 
   @HopMetadataProperty private String description;
