@@ -63,7 +63,6 @@ public interface IGc {
   enum EImage {
     LOCK,
     EDIT,
-    CONTEXT_MENU,
     TRUE,
     TRUE_DISABLED,
     FALSE,
@@ -78,7 +77,6 @@ public interface IGc {
     TARGET_DISABLED,
     INPUT,
     OUTPUT,
-    ARROW,
     COPY_ROWS,
     COPY_ROWS_DISABLED,
     UNCONDITIONAL,
