@@ -147,10 +147,8 @@ public class BaseTransformMeta<Main extends ITransform, Data extends ITransformD
   protected Type[] getGenericType(Class<?> clazz) {
     do {
       Type type = clazz.getGenericSuperclass();
-      if (type != null) {
-        if (type instanceof ParameterizedType) {
-          return new Type[] {type};
-        }
+      if (type != null && type instanceof ParameterizedType) {
+        return new Type[] {type};
       }
       // If the class is not parameterized, try parent class
       clazz = clazz.getSuperclass();
@@ -219,6 +217,7 @@ public class BaseTransformMeta<Main extends ITransform, Data extends ITransformD
    *
    * @param ch the new changed
    */
+  @Override
   public void setChanged(boolean ch) {
     changed = ch;
   }
@@ -248,8 +247,7 @@ public class BaseTransformMeta<Main extends ITransform, Data extends ITransformD
   }
 
   /**
-   * Produces the XML string that describes this transform's information.
-   *
+   * @deprecated Produces the XML string that describes this transform's information.
    * @return String containing the XML describing this transform.
    * @throws HopException in case there is an XML conversion or encoding error
    */
@@ -260,9 +258,8 @@ public class BaseTransformMeta<Main extends ITransform, Data extends ITransformD
   }
 
   /**
-   * Automatically load metadata from XML using @{@link
-   * org.apache.hop.metadata.api.HopMetadataProperty} annotations
-   *
+   * @deprecated Automatically load metadata from XML using @{@link
+   *     org.apache.hop.metadata.api.HopMetadataProperty} annotations
    * @param transformNode
    * @param metadataProvider
    * @throws HopXmlException
