@@ -34,7 +34,7 @@ import org.w3c.dom.Node;
 
 @Transform(
     id = "Dummy",
-    image = "ui/images/dummy.svg",
+    image = "org/apache/hop/images/dummy.svg",
     name = "i18n:org.apache.hop.pipeline.transform:BaseTransform.TypeLongDesc.Dummy",
     description = "i18n:org.apache.hop.pipeline.transform:BaseTransform.TypeTooltipDesc.Dummy",
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Flow",
@@ -93,7 +93,7 @@ public class DummyMeta extends BaseTransformMeta<Dummy, DummyData> {
       IVariables variables,
       IHopMetadataProvider metadataProvider) {
     CheckResult cr;
-    if (prev == null || prev.size() == 0) {
+    if (prev == null || prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_WARNING,
