@@ -140,7 +140,7 @@ public class WorkflowExecutionConfiguration implements IExecutionConfiguration,
     }
 
     List<String> vars = workflowMeta.getUsedVariables();
-    if (vars != null && !vars.isEmpty()) {
+    if (!Utils.isEmpty(vars)) {
       HashMap<String, String> newVariables = new HashMap<>();
 
       for (int i = 0; i < vars.size(); i++) {
