@@ -20,14 +20,14 @@ package org.apache.hop.www;
 import static java.nio.charset.StandardCharsets.UTF_8;
 
 import com.fasterxml.jackson.databind.ObjectMapper;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.io.PrintWriter;
 import java.net.URLEncoder;
 import java.nio.charset.StandardCharsets;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
 import org.apache.hop.core.Const;
 import org.apache.hop.core.annotations.HopServerServlet;
 import org.apache.hop.core.exception.HopException;
@@ -149,7 +149,7 @@ public class GetWorkflowStatusServlet extends BaseHttpServlet implements IHopSer
           for (ActionResult actionResult : workflow.getActionResults()) {
             ActionStatus actionState = new ActionStatus();
             actionState.setName(actionResult.getActionName());
-            if (actionResult.getResult().getResult()) {
+            if (actionResult.getResult().isResult()) {
               actionState.setStatus(Status.FINISHED);
             } else {
               actionState.setStatus(Status.STOPPED);
