@@ -30,8 +30,6 @@ import org.apache.hop.core.compress.CompressionPluginType;
 import org.apache.hop.core.compress.CompressionProviderFactory;
 import org.apache.hop.core.plugins.PluginRegistry;
 import org.apache.hop.junit.rules.RestoreHopEngineEnvironment;
-import org.junit.After;
-import org.junit.AfterClass;
 import org.junit.Before;
 import org.junit.BeforeClass;
 import org.junit.ClassRule;
@@ -50,17 +48,11 @@ public class GzipCompressionProviderTest {
     PluginRegistry.init();
   }
 
-  @AfterClass
-  public static void tearDownAfterClass() throws Exception {}
-
   @Before
-  public void setUp() throws Exception {
+  public void setUp() {
     factory = CompressionProviderFactory.getInstance();
   }
 
-  @After
-  public void tearDown() throws Exception {}
-
   @Test
   public void testCtor() {
     GzipCompressionProvider ncp = new GzipCompressionProvider();
