@@ -19,12 +19,12 @@ package org.apache.hop.pipeline;
 import static java.util.Arrays.asList;
 import static java.util.Collections.emptyList;
 import static java.util.Collections.singletonList;
-import static org.hamcrest.CoreMatchers.equalTo;
+import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertThat;
 import static org.junit.Assert.assertTrue;
 import static org.mockito.ArgumentMatchers.same;
 import static org.mockito.Mockito.any;
@@ -80,7 +80,7 @@ public class PipelineMetaTest {
   private IHopMetadataProvider metadataProvider;
 
   @Before
-  public void setUp() throws Exception {
+  public void setUp() {
     pipelineMeta = new PipelineMeta();
     variables = new Variables();
     metadataProvider = new MemoryMetadataProvider();
@@ -108,7 +108,7 @@ public class PipelineMetaTest {
   }
 
   @Test
-  public void testContentChangeListener() throws Exception {
+  public void testContentChangeListener() {
     IContentChangedListener listener = mock(IContentChangedListener.class);
     pipelineMeta.addContentChangedListener(listener);
 
@@ -130,7 +130,7 @@ public class PipelineMetaTest {
   }
 
   @Test
-  public void testCompare() throws Exception {
+  public void testCompare() {
     PipelineMeta pipelineMeta = new PipelineMeta();
     pipelineMeta.setNameSynchronizedWithFilename(false);
     pipelineMeta.setFilename("aFile");
@@ -162,19 +162,19 @@ public class PipelineMetaTest {
   }
 
   @Test
-  public void testEquals() throws Exception {
+  public void testEquals() {
     PipelineMeta pipelineMeta = new PipelineMeta();
     pipelineMeta.setFilename("1");
     pipelineMeta.setName("2");
-    assertFalse(pipelineMeta.equals("somethingelse"));
+    assertNotEquals("somethingelse", pipelineMeta);
     PipelineMeta pipelineMeta2 = new PipelineMeta();
     pipelineMeta2.setFilename("1");
     pipelineMeta2.setName("2");
-    assertTrue(pipelineMeta.equals(pipelineMeta2));
+    assertEquals(pipelineMeta, pipelineMeta2);
   }
 
   @Test
-  public void testPipelineHops() throws Exception {
+  public void testPipelineHops() {
     PipelineMeta pipelineMeta = new PipelineMeta();
     pipelineMeta.setFilename("pipelineFile");
     pipelineMeta.setName("myPipeline");
@@ -212,7 +212,7 @@ public class PipelineMetaTest {
   }
 
   @Test
-  public void testGetAllPipelineHops() throws Exception {
+  public void testGetAllPipelineHops() {
     PipelineMeta pipelineMeta = new PipelineMeta();
     pipelineMeta.setFilename("pipelineFile");
     pipelineMeta.setName("myPipeline");
@@ -373,8 +373,8 @@ public class PipelineMetaTest {
     IRowMeta results =
         pipelineMeta.getTransformFields(variables, append, after, mock(IProgressMonitor.class));
 
-    assertThat(1, equalTo(results.size()));
-    assertThat("outputField", equalTo(results.getFieldNames()[0]));
+    assertEquals(1, results.size());
+    assertEquals("outputField", results.getFieldNames()[0]);
   }
 
   @Test
@@ -397,10 +397,9 @@ public class PipelineMetaTest {
         pipelineMeta.getTransformFields(
             variables, someTransform, after, mock(IProgressMonitor.class));
 
-    assertThat(4, equalTo(results.size()));
-    assertThat(
-        new String[] {"field3", "field4", "field5", "outputField"},
-        equalTo(results.getFieldNames()));
+    assertEquals(4, results.size());
+    assertArrayEquals(
+        new String[] {"field3", "field4", "field5", "outputField"}, results.getFieldNames());
   }
 
   @Test
@@ -408,8 +407,8 @@ public class PipelineMetaTest {
     PipelineMeta pipelineMeta = new PipelineMeta();
     List<TransformMeta> result = pipelineMeta.findPreviousTransforms(null, false);
 
-    assertThat(0, equalTo(result.size()));
-    assertThat(result, equalTo(new ArrayList<>()));
+    assertEquals(0, result.size());
+    assertEquals(result, new ArrayList<>());
   }
 
   private void wireUpTestPipelineMeta(
