@@ -18,7 +18,7 @@
 package org.apache.hop.pipeline;
 
 import static org.junit.Assert.assertEquals;
-import static org.mockito.Matchers.anyString;
+import static org.mockito.ArgumentMatchers.anyString;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.doThrow;
 import static org.mockito.Mockito.mock;
@@ -93,8 +93,7 @@ public class PipelineTest {
    * @throws InterruptedException
    */
   @Test
-  public void testPipelineFinishListenersConcurrentModification()
-      throws HopException, InterruptedException {
+  public void testPipelineFinishListenersConcurrentModification() throws InterruptedException {
     CountDownLatch start = new CountDownLatch(1);
     PipelineFinishListenerAdder add = new PipelineFinishListenerAdder(pipeline, start);
     PipelineFinishListenerFirer firer = new PipelineFinishListenerFirer(pipeline, start);
