@@ -18,13 +18,14 @@
 
 package org.apache.hop.workflow.action;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
 import java.lang.reflect.InvocationTargetException;
 import org.apache.hop.core.exception.HopXmlException;
 import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
 import org.apache.hop.metadata.serializer.memory.MemoryMetadataProvider;
 import org.apache.hop.metadata.serializer.xml.XmlMetadataUtil;
-import org.junit.Assert;
 import org.w3c.dom.Document;
 import org.w3c.dom.Node;
 
@@ -64,7 +65,7 @@ public class ActionSerializationTestUtil {
     Node copyNode = XmlHandler.getSubNode(copyDocument, xmlTag);
     T copy = clazz.getConstructor().newInstance();
     XmlMetadataUtil.deSerializeFromXml(null, copyNode, clazz, copy, metadataProvider);
-    Assert.assertEquals(meta.getXml(), copy.getXml());
+    assertEquals(meta.getXml(), copy.getXml());
   }
 
   public static String getXml(IAction action) {
