@@ -90,7 +90,6 @@ public class ActionCopyFiles extends ActionBase implements Cloneable, IAction {
 
   private static final String CONST_SPACE = "          ";
   private static final String CONST_SPACE_SHORT = "      ";
-  private static final String CONST_DASH = " ------ ";
   private static final String CONST_FILE_COPIED = "ActionCopyFiles.Log.FileCopied";
   private static final String CONST_COPY_PROCESS = "ActionCopyFiles.Error.Exception.CopyProcess";
   private static final String CONST_FILE_EXISTS = "ActionCopyFiles.Log.FileExists";
@@ -295,14 +294,12 @@ public class ActionCopyFiles extends ActionBase implements Cloneable, IAction {
       result.setResult(false);
       result.setNrErrors(1);
 
-      if (argFromPrevious) {
-        if (isDetailed()) {
-          logDetailed(
-              BaseMessages.getString(
-                  PKG,
-                  "ActionCopyFiles.Log.ArgFromPrevious.Found",
-                  (rows != null ? rows.size() : 0) + ""));
-        }
+      if (argFromPrevious && isDetailed()) {
+        logDetailed(
+            BaseMessages.getString(
+                PKG,
+                "ActionCopyFiles.Log.ArgFromPrevious.Found",
+                (rows != null ? rows.size() : 0) + ""));
       }
 
       if (argFromPrevious && rows != null) { // Copy the input row to the (command line) arguments
@@ -524,7 +521,6 @@ public class ActionCopyFiles extends ActionBase implements Cloneable, IAction {
                 // Remove ONLY Files
                 if (removeFile.getType() == FileType.FILE) {
                   boolean deletefile = removeFile.delete();
-                  logBasic(CONST_DASH);
                   if (!deletefile) {
                     logError(
                         CONST_SPACE_SHORT
@@ -578,7 +574,6 @@ public class ActionCopyFiles extends ActionBase implements Cloneable, IAction {
                           toString());
                   result.getResultFiles().put(resultFile.getFile().toString(), resultFile);
                   if (isDetailed()) {
-                    logDetailed(CONST_DASH);
                     logDetailed(
                         CONST_SPACE_SHORT
                             + BaseMessages.getString(
@@ -843,7 +838,6 @@ public class ActionCopyFiles extends ActionBase implements Cloneable, IAction {
                 if (includeSubFolders && copyEmptyFolders && Utils.isEmpty(fileWildcard)) {
                   if ((filename == null) || (!filename.exists())) {
                     if (isDetailed()) {
-                      logDetailed(CONST_DASH);
                       logDetailed(
                           CONST_SPACE_SHORT
                               + BaseMessages.getString(
@@ -855,7 +849,6 @@ public class ActionCopyFiles extends ActionBase implements Cloneable, IAction {
                     returncode = true;
                   } else {
                     if (isDetailed()) {
-                      logDetailed(CONST_DASH);
                       logDetailed(
                           CONST_SPACE_SHORT
                               + BaseMessages.getString(
@@ -883,7 +876,6 @@ public class ActionCopyFiles extends ActionBase implements Cloneable, IAction {
                   // Check if the file exists
                   if ((filename == null) || (!filename.exists())) {
                     if (isDetailed()) {
-                      logDetailed(CONST_DASH);
                       logDetailed(
                           CONST_SPACE_SHORT
                               + BaseMessages.getString(
@@ -895,7 +887,6 @@ public class ActionCopyFiles extends ActionBase implements Cloneable, IAction {
                     returncode = true;
                   } else {
                     if (isDetailed()) {
-                      logDetailed(CONST_DASH);
                       logDetailed(
                           CONST_SPACE_SHORT
                               + BaseMessages.getString(
@@ -925,7 +916,6 @@ public class ActionCopyFiles extends ActionBase implements Cloneable, IAction {
               if (includeSubFolders && copyEmptyFolders && Utils.isEmpty(fileWildcard)) {
                 if ((filename == null) || (!filename.exists())) {
                   if (isDetailed()) {
-                    logDetailed("", CONST_DASH);
                     logDetailed(
                         CONST_SPACE_SHORT
                             + BaseMessages.getString(
@@ -938,7 +928,6 @@ public class ActionCopyFiles extends ActionBase implements Cloneable, IAction {
                   returncode = true;
                 } else {
                   if (isDetailed()) {
-                    logDetailed(CONST_DASH);
                     logDetailed(
                         CONST_SPACE_SHORT
                             + BaseMessages.getString(
@@ -970,7 +959,6 @@ public class ActionCopyFiles extends ActionBase implements Cloneable, IAction {
               if (getFileWildcard(shortFilename)) {
                 if ((filename == null) || (!filename.exists())) {
                   if (isDetailed()) {
-                    logDetailed(CONST_DASH);
                     logDetailed(
                         CONST_SPACE_SHORT
                             + BaseMessages.getString(
@@ -983,7 +971,6 @@ public class ActionCopyFiles extends ActionBase implements Cloneable, IAction {
 
                 } else {
                   if (isDetailed()) {
-                    logDetailed(CONST_DASH);
                     logDetailed(
                         CONST_SPACE_SHORT
                             + BaseMessages.getString(
