@@ -171,23 +171,23 @@ public class ActionDeleteResultFilenames extends ActionBase implements Cloneable
         } else {
 
           List<ResultFile> resultFiles = result.getResultFilesList();
-          if (resultFiles != null && !resultFiles.isEmpty()) {
+          if (!Utils.isEmpty(resultFiles)) {
             for (Iterator<ResultFile> it = resultFiles.iterator();
                 it.hasNext() && !parentWorkflow.isStopped(); ) {
               ResultFile resultFile = it.next();
               FileObject file = resultFile.getFile();
-              if (file != null && file.exists()) {
-                if (checkFileWildcard(file.getName().getBaseName(), resolve(wildcard), true)
-                    && !checkFileWildcard(
-                        file.getName().getBaseName(), resolve(wildcardExclude), false)) {
-                  // Remove file from result files list
-                  result.getResultFiles().remove(resultFile.getFile().toString());
+              if (file != null
+                  && file.exists()
+                  && checkFileWildcard(file.getName().getBaseName(), resolve(wildcard), true)
+                  && !checkFileWildcard(
+                      file.getName().getBaseName(), resolve(wildcardExclude), false)) {
+                // Remove file from result files list
+                result.getResultFiles().remove(resultFile.getFile().toString());
 
-                  if (isDetailed()) {
-                    logDetailed(
-                        BaseMessages.getString(
-                            PKG, "ActionDeleteResultFilenames.log.DeletedFile", file.toString()));
-                  }
+                if (isDetailed()) {
+                  logDetailed(
+                      BaseMessages.getString(
+                          PKG, "ActionDeleteResultFilenames.log.DeletedFile", file.toString()));
                 }
               }
             }
