@@ -17,9 +17,9 @@
 
 package org.apache.hop.workflow.actions.folderisempty;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.Mockito.mock;
 
 import java.io.File;
@@ -31,24 +31,24 @@ import org.apache.hop.workflow.WorkflowMeta;
 import org.apache.hop.workflow.action.ActionMeta;
 import org.apache.hop.workflow.engine.IWorkflowEngine;
 import org.apache.hop.workflow.engines.local.LocalWorkflowEngine;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
-public class WorkflowActionFolderIsEmptyTest {
+class WorkflowActionFolderIsEmptyTest {
   private IWorkflowEngine<WorkflowMeta> workflow;
   private ActionFolderIsEmpty action;
 
   private String emptyDir;
   private String nonEmptyDir;
 
-  @BeforeClass
-  public static void setUpBeforeClass() {
+  @BeforeAll
+  static void setUpBeforeClass() {
     HopLogStore.init();
   }
 
-  @Before
-  public void setUp() throws Exception {
+  @BeforeEach
+  void setUp() throws Exception {
     workflow = new LocalWorkflowEngine(new WorkflowMeta());
     action = new ActionFolderIsEmpty();
 
@@ -72,22 +72,22 @@ public class WorkflowActionFolderIsEmptyTest {
   }
 
   @Test
-  public void testSetNrErrorsSuccess() {
+  void testSetNrErrorsSuccess() {
     action.setFolderName(emptyDir);
 
     Result result = action.execute(new Result(), 0);
 
-    assertTrue("For empty folder result should be true", result.getResult());
-    assertEquals("There should be no errors", 0, result.getNrErrors());
+    assertTrue(result.isResult(), "For empty folder result should be true");
+    assertEquals(0, result.getNrErrors(), "There should be no errors");
   }
 
   @Test
-  public void testSetNrErrorsFail() {
+  void testSetNrErrorsFail() {
     action.setFolderName(nonEmptyDir);
 
     Result result = action.execute(new Result(), 0);
 
-    assertFalse("For non-empty folder result should be false", result.getResult());
-    assertEquals("There should be still no errors", 0, result.getNrErrors());
+    assertFalse(result.isResult(), "For non-empty folder result should be false");
+    assertEquals(0, result.getNrErrors(), "There should be still no errors");
   }
 }
