@@ -20,13 +20,13 @@ package org.apache.hop.workflow.actions.ftpput;
 import java.util.Arrays;
 import java.util.List;
 import java.util.Map;
-import org.apache.hop.junit.rules.RestoreHopEngineEnvironment;
+import org.apache.hop.junit.rules.RestoreHopEngineEnvironmentExtension;
 import org.apache.hop.workflow.action.loadsave.WorkflowActionLoadSaveTestSupport;
-import org.junit.ClassRule;
+import org.junit.jupiter.api.extension.RegisterExtension;
 
-public class WorkflowActionFtpPutLoadSaveTest
-    extends WorkflowActionLoadSaveTestSupport<ActionFtpPut> {
-  @ClassRule public static RestoreHopEngineEnvironment env = new RestoreHopEngineEnvironment();
+class WorkflowActionFtpPutLoadSaveTest extends WorkflowActionLoadSaveTestSupport<ActionFtpPut> {
+  @RegisterExtension
+  static RestoreHopEngineEnvironmentExtension env = new RestoreHopEngineEnvironmentExtension();
 
   @Override
   protected Class<ActionFtpPut> getActionClass() {
