@@ -188,8 +188,7 @@ public class ActionMysqlBulkFile extends ActionBase {
           // Format Date
 
           // Try to clean filename (without wildcard)
-          String wildcard =
-              realFilename.substring(realFilename.length() - 4, realFilename.length());
+          String wildcard = realFilename.substring(realFilename.length() - 4);
           if (wildcard.substring(0, 1).equals(".")) {
             // Find wildcard
             realFilename =
