@@ -119,7 +119,7 @@ public class ActionPingDialog extends ActionDialog {
     FormData fdlHostname = new FormData();
     fdlHostname.left = new FormAttachment(0, 0);
     fdlHostname.top = new FormAttachment(wName, margin);
-    fdlHostname.right = new FormAttachment(middle, 0);
+    fdlHostname.right = new FormAttachment(middle, -margin);
     wlHostname.setLayoutData(fdlHostname);
 
     wHostname = new TextVar(variables, shell, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
@@ -140,7 +140,7 @@ public class ActionPingDialog extends ActionDialog {
     PropsUi.setLook(wlPingType);
     FormData fdlPingType = new FormData();
     fdlPingType.left = new FormAttachment(0, 0);
-    fdlPingType.right = new FormAttachment(middle, 0);
+    fdlPingType.right = new FormAttachment(middle, -margin);
     fdlPingType.top = new FormAttachment(wHostname, margin);
     wlPingType.setLayoutData(fdlPingType);
     wPingType = new CCombo(shell, SWT.SINGLE | SWT.READ_ONLY | SWT.BORDER);
@@ -169,7 +169,7 @@ public class ActionPingDialog extends ActionDialog {
     PropsUi.setLook(wlTimeOut);
     FormData fdlTimeOut = new FormData();
     fdlTimeOut.left = new FormAttachment(0, 0);
-    fdlTimeOut.right = new FormAttachment(middle, 0);
+    fdlTimeOut.right = new FormAttachment(middle, -margin);
     fdlTimeOut.top = new FormAttachment(wPingType, margin);
     wlTimeOut.setLayoutData(fdlTimeOut);
 
@@ -189,7 +189,7 @@ public class ActionPingDialog extends ActionDialog {
     PropsUi.setLook(wlNbrPackets);
     FormData fdlNbrPackets = new FormData();
     fdlNbrPackets.left = new FormAttachment(0, 0);
-    fdlNbrPackets.right = new FormAttachment(middle, 0);
+    fdlNbrPackets.right = new FormAttachment(middle, -margin);
     fdlNbrPackets.top = new FormAttachment(wTimeOut, margin);
     wlNbrPackets.setLayoutData(fdlNbrPackets);
 
@@ -247,8 +247,8 @@ public class ActionPingDialog extends ActionDialog {
       wNbrPackets.setText("2");
     }
 
-    if (action.getTimeOut() != null) {
-      wTimeOut.setText(action.getTimeOut());
+    if (action.getTimeout() != null) {
+      wTimeOut.setText(action.getTimeout());
     } else {
       wTimeOut.setText("3000");
     }
@@ -276,7 +276,7 @@ public class ActionPingDialog extends ActionDialog {
     action.setName(wName.getText());
     action.setHostname(wHostname.getText());
     action.setNbrPackets(wNbrPackets.getText());
-    action.setTimeOut(wTimeOut.getText());
+    action.setTimeout(wTimeOut.getText());
     action.ipingtype = wPingType.getSelectionIndex();
     if (wPingType.getSelectionIndex() == action.isystemPing) {
       action.pingtype = action.systemPing;
