@@ -17,21 +17,21 @@
 
 package org.apache.hop.workflow.actions.pipeline;
 
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.doCallRealMethod;
 import static org.mockito.Mockito.mock;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
-public class WorkflowEntryPipelineDialogTest {
+class WorkflowEntryPipelineDialogTest {
 
   private static final String FILE_NAME = "TestPipeline.hpl";
 
   ActionPipelineDialog dialog;
 
   @Test
-  public void testEntryName() {
+  void testEntryName() {
     dialog = mock(ActionPipelineDialog.class);
     doCallRealMethod().when(dialog).getEntryName(any());
     assertEquals(dialog.getEntryName(FILE_NAME), "${Internal.Entry.Current.Folder}/" + FILE_NAME);
