@@ -198,7 +198,7 @@ public class ActionShell extends ActionBase {
         SimpleDateFormat sdf = new SimpleDateFormat("HHmmss");
         retval += "_" + sdf.format(cal.getTime());
       }
-      if (logext != null && logext.length() > 0) {
+      if (!Utils.isEmpty(logext)) {
         retval += "." + logext;
       }
     }
