@@ -16,11 +16,11 @@
  */
 package org.apache.hop.databases.cratedb;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertThrows;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import org.apache.hop.core.database.DatabaseMeta;
 import org.apache.hop.core.row.value.ValueMetaBigNumber;
@@ -31,22 +31,22 @@ import org.apache.hop.core.row.value.ValueMetaInternetAddress;
 import org.apache.hop.core.row.value.ValueMetaNumber;
 import org.apache.hop.core.row.value.ValueMetaString;
 import org.apache.hop.core.row.value.ValueMetaTimestamp;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
-public class CrateDBDatabaseMetaTest {
+class CrateDBDatabaseMetaTest {
   CrateDBDatabaseMeta nativeMeta;
 
   private static final String SEQUENCES_NOT_SUPPORTED = "CrateDB doesn't support sequences";
 
-  @Before
-  public void setupBefore() {
+  @BeforeEach
+  void setupBefore() {
     nativeMeta = new CrateDBDatabaseMeta();
     nativeMeta.setAccessType(DatabaseMeta.TYPE_ACCESS_NATIVE);
   }
 
   @Test
-  public void testSettings() {
+  void testSettings() {
     assertEquals("&", nativeMeta.getExtraOptionSeparator());
     assertEquals("?", nativeMeta.getExtraOptionIndicator());
     assertArrayEquals(new int[] {DatabaseMeta.TYPE_ACCESS_NATIVE}, nativeMeta.getAccessTypeList());
@@ -174,7 +174,7 @@ public class CrateDBDatabaseMetaTest {
   }
 
   @Test
-  public void testSqlStatements() {
+  void testSqlStatements() {
     assertEquals("SELECT * FROM FOO limit 1", nativeMeta.getSqlQueryFields("FOO"));
     assertEquals("SELECT * FROM FOO limit 1", nativeMeta.getSqlTableExists("FOO"));
     assertEquals("SELECT FOO FROM BAR limit 1", nativeMeta.getSqlColumnExists("FOO", "BAR"));
@@ -330,22 +330,22 @@ public class CrateDBDatabaseMetaTest {
   }
 
   @Test
-  public void doesNotSupportSequences() {
+  void doesNotSupportSequences() {
     assertThrows(
-        SEQUENCES_NOT_SUPPORTED,
         UnsupportedOperationException.class,
-        () -> nativeMeta.getSqlListOfSequences());
+        () -> nativeMeta.getSqlListOfSequences(),
+        SEQUENCES_NOT_SUPPORTED);
     assertThrows(
-        SEQUENCES_NOT_SUPPORTED,
         UnsupportedOperationException.class,
-        () -> nativeMeta.getSqlNextSequenceValue("FOO"));
+        () -> nativeMeta.getSqlNextSequenceValue("FOO"),
+        SEQUENCES_NOT_SUPPORTED);
     assertThrows(
-        SEQUENCES_NOT_SUPPORTED,
         UnsupportedOperationException.class,
-        () -> nativeMeta.getSqlCurrentSequenceValue("FOO"));
+        () -> nativeMeta.getSqlCurrentSequenceValue("FOO"),
+        SEQUENCES_NOT_SUPPORTED);
     assertThrows(
-        SEQUENCES_NOT_SUPPORTED,
         UnsupportedOperationException.class,
-        () -> nativeMeta.getSqlSequenceExists("FOO"));
+        () -> nativeMeta.getSqlSequenceExists("FOO"),
+        SEQUENCES_NOT_SUPPORTED);
   }
 }
