@@ -16,10 +16,10 @@
  */
 package org.apache.hop.databases.exasol4;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import org.apache.hop.core.database.DatabaseMeta;
 import org.apache.hop.core.row.value.ValueMetaBigNumber;
@@ -30,20 +30,20 @@ import org.apache.hop.core.row.value.ValueMetaInternetAddress;
 import org.apache.hop.core.row.value.ValueMetaNumber;
 import org.apache.hop.core.row.value.ValueMetaString;
 import org.apache.hop.core.row.value.ValueMetaTimestamp;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
-public class Exasol4DatabaseMetaTest {
+class Exasol4DatabaseMetaTest {
   Exasol4DatabaseMeta nativeMeta;
 
-  @Before
-  public void setupBefore() {
+  @BeforeEach
+  void setupBefore() {
     nativeMeta = new Exasol4DatabaseMeta();
     nativeMeta.setAccessType(DatabaseMeta.TYPE_ACCESS_NATIVE);
   }
 
   @Test
-  public void testSettings() throws Exception {
+  void testSettings() throws Exception {
     assertArrayEquals(new int[] {DatabaseMeta.TYPE_ACCESS_NATIVE}, nativeMeta.getAccessTypeList());
     assertEquals(8563, nativeMeta.getDefaultDatabasePort());
     assertFalse(nativeMeta.isSupportsAutoInc());
@@ -53,7 +53,7 @@ public class Exasol4DatabaseMetaTest {
     assertFalse(nativeMeta.isSupportsSequences());
     assertTrue(nativeMeta.useSchemaNameForTableList());
     assertFalse(nativeMeta.isSupportsSynonyms());
-    assertEquals(
+    assertArrayEquals(
         new String[] {
           "ABSOLUTE",
           "ACTION",
@@ -501,7 +501,7 @@ public class Exasol4DatabaseMetaTest {
   }
 
   @Test
-  public void testSqlStatements() {
+  void testSqlStatements() {
     assertEquals(" WHERE ROWNUM <= 15", nativeMeta.getLimitClause(15));
     assertEquals(
         "SELECT /*+FIRST_ROWS*/ * FROM FOO WHERE 1=0", nativeMeta.getSqlQueryFields("FOO"));
