@@ -17,18 +17,18 @@
 
 package org.apache.hop.databases.greenplum;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import org.apache.hop.core.database.IDatabase;
 import org.apache.hop.core.util.Utils;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
-public class SequenceMetaTest {
+class SequenceMetaTest {
 
   @Test
-  public void testSupport() {
+  void testSupport() {
 
     IDatabase[] support =
         new IDatabase[] {
@@ -43,24 +43,24 @@ public class SequenceMetaTest {
   public static void assertSupports(IDatabase db, boolean expected) {
     String dbType = db.getClass().getSimpleName();
     if (expected) {
-      assertTrue(dbType, db.isSupportsSequences());
-      assertFalse(dbType + ": List of Sequences", Utils.isEmpty(db.getSqlListOfSequences()));
-      assertFalse(dbType + ": Sequence Exists", Utils.isEmpty(db.getSqlSequenceExists("testSeq")));
+      assertTrue(db.isSupportsSequences(), dbType);
+      assertFalse(Utils.isEmpty(db.getSqlListOfSequences()), dbType + ": List of Sequences");
+      assertFalse(Utils.isEmpty(db.getSqlSequenceExists("testSeq")), dbType + ": Sequence Exists");
       assertFalse(
-          dbType + ": Current Value", Utils.isEmpty(db.getSqlCurrentSequenceValue("testSeq")));
-      assertFalse(dbType + ": Next Value", Utils.isEmpty(db.getSqlNextSequenceValue("testSeq")));
+          Utils.isEmpty(db.getSqlCurrentSequenceValue("testSeq")), dbType + ": Current Value");
+      assertFalse(Utils.isEmpty(db.getSqlNextSequenceValue("testSeq")), dbType + ": Next Value");
     } else {
-      assertFalse(db.getClass().getSimpleName(), db.isSupportsSequences());
-      assertTrue(dbType + ": List of Sequences", Utils.isEmpty(db.getSqlListOfSequences()));
-      assertTrue(dbType + ": Sequence Exists", Utils.isEmpty(db.getSqlSequenceExists("testSeq")));
+      assertFalse(db.isSupportsSequences(), db.getClass().getSimpleName());
+      assertTrue(Utils.isEmpty(db.getSqlListOfSequences()), dbType + ": List of Sequences");
+      assertTrue(Utils.isEmpty(db.getSqlSequenceExists("testSeq")), dbType + ": Sequence Exists");
       assertTrue(
-          dbType + ": Current Value", Utils.isEmpty(db.getSqlCurrentSequenceValue("testSeq")));
-      assertTrue(dbType + ": Next Value", Utils.isEmpty(db.getSqlNextSequenceValue("testSeq")));
+          Utils.isEmpty(db.getSqlCurrentSequenceValue("testSeq")), dbType + ": Current Value");
+      assertTrue(Utils.isEmpty(db.getSqlNextSequenceValue("testSeq")), dbType + ": Next Value");
     }
   }
 
   @Test
-  public void testSql() {
+  void testSql() {
 
     IDatabase iDatabase;
     final String sequenceName = "sequence_name";
