@@ -194,10 +194,33 @@ public class InformixDatabaseMeta extends BaseDatabaseMeta implements IDatabase
             retval += "INTEGER PRIMARY KEY";
           }
         } else {
-          if ((length < 0 && precision < 0) || precision > 0 || length > 9) {
+          if (type == IValueMeta.TYPE_INTEGER) {
+            // Integer values...
+            if (length < 5) {
+              retval += "SMALLINT";
+            } else if (length < 10) {
+              retval += "INT";
+            } else if (length < 20) {
+              retval += "BIGINT";
+            } else {
+              retval += "DECIMAL(" + length + ",0)";
+            }
+          } else if (type == IValueMeta.TYPE_BIGNUMBER) {
+            // Fixed point value...
+            if (length
+                < 1) { // user configured no value for length. Use 16 digits, which is comparable to
+              // mantissa 2^53 of IEEE 754 binary64 "double".
+              length = 16;
+            }
+            if (precision
+                < 1) { // user configured no value for precision. Use 16 digits, which is comparable
+              // to IEEE 754 binary64 "double".
+              precision = 16;
+            }
+            retval += "DECIMAL(" + length + "," + precision + ")";
+          } else {
+            // Floating point value with double precision...
             retval += "FLOAT";
-          } else { // Precision == 0 && length<=9
-            retval += "INTEGER";
           }
         }
         break;
