@@ -17,11 +17,11 @@
 
 package org.apache.hop.databases.oracle;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.eq;
 
@@ -47,32 +47,33 @@ import org.apache.hop.core.row.value.ValueMetaTimestamp;
 import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.variables.Variables;
-import org.apache.hop.junit.rules.RestoreHopEnvironment;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.ClassRule;
-import org.junit.Test;
+import org.apache.hop.junit.rules.RestoreHopEngineEnvironmentExtension;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.RegisterExtension;
 import org.mockito.Mockito;
 import org.mockito.stubbing.Answer;
 
-public class OracleDatabaseMetaTest {
-  @ClassRule public static RestoreHopEnvironment env = new RestoreHopEnvironment();
+class OracleDatabaseMetaTest {
+  @RegisterExtension
+  static RestoreHopEngineEnvironmentExtension env = new RestoreHopEngineEnvironmentExtension();
 
   private final String sequenceName = "sequence_name";
 
   private OracleDatabaseMeta nativeMeta;
   private IVariables variables;
 
-  @BeforeClass
-  public static void setUpBeforeClass() throws HopException {
+  @BeforeAll
+  static void setUpBeforeClass() throws HopException {
     PluginRegistry.addPluginType(ValueMetaPluginType.getInstance());
     PluginRegistry.addPluginType(DatabasePluginType.getInstance());
     PluginRegistry.init();
     HopLogStore.init();
   }
 
-  @Before
-  public void setupOnce() throws Exception {
+  @BeforeEach
+  void setupOnce() throws Exception {
     nativeMeta = new OracleDatabaseMeta();
     nativeMeta.setAccessType(DatabaseMeta.TYPE_ACCESS_NATIVE);
     HopClientEnvironment.init();
@@ -80,7 +81,7 @@ public class OracleDatabaseMetaTest {
   }
 
   @Test
-  public void testOverriddenSettings() throws Exception {
+  void testOverriddenSettings() throws Exception {
     // Tests the settings of the Oracle Database Meta
     // according to the features of the DB as we know them
 
@@ -242,7 +243,7 @@ public class OracleDatabaseMetaTest {
   }
 
   @Test
-  public void testOverriddenSqlStatements() {
+  void testOverriddenSqlStatements() {
     assertEquals(" WHERE ROWNUM <= 5", nativeMeta.getLimitClause(5));
     String reusedFieldsQuery = "SELECT * FROM FOO WHERE 1=0";
     assertEquals(reusedFieldsQuery, nativeMeta.getSqlQueryFields("FOO"));
@@ -390,7 +391,7 @@ public class OracleDatabaseMetaTest {
   }
 
   @Test
-  public void testGetFieldDefinition() {
+  void testGetFieldDefinition() {
     assertEquals(
         "FOO DATE",
         nativeMeta.getFieldDefinition(new ValueMetaDate("FOO"), "", "", false, true, false));
@@ -470,7 +471,7 @@ public class OracleDatabaseMetaTest {
   private String[] row2 = new String[] {"ROW2COL1", "ROW2COL2"};
 
   @Test
-  public void testCheckIndexExists() throws Exception {
+  void testCheckIndexExists() throws Exception {
     String expectedSql = "SELECT * FROM USER_IND_COLUMNS WHERE TABLE_NAME = 'FOO'";
     Database db = Mockito.mock(Database.class);
     IRowMeta rm = Mockito.mock(IRowMeta.class);
@@ -503,22 +504,22 @@ public class OracleDatabaseMetaTest {
   }
 
   @Test
-  public void testSupportsSavepoint() {
+  void testSupportsSavepoint() {
     assertFalse(nativeMeta.isReleaseSavepoint());
   }
 
   @Test
-  public void testSupportsSequence() {
+  void testSupportsSequence() {
     String dbType = nativeMeta.getClass().getSimpleName();
-    assertTrue(dbType, nativeMeta.isSupportsSequences());
-    assertFalse(dbType + ": List of Sequences", Utils.isEmpty(nativeMeta.getSqlListOfSequences()));
+    assertTrue(nativeMeta.isSupportsSequences(), dbType);
+    assertFalse(Utils.isEmpty(nativeMeta.getSqlListOfSequences()), dbType + ": List of Sequences");
     assertFalse(
-        dbType + ": Sequence Exists", Utils.isEmpty(nativeMeta.getSqlSequenceExists("testSeq")));
+        Utils.isEmpty(nativeMeta.getSqlSequenceExists("testSeq")), dbType + ": Sequence Exists");
     assertFalse(
-        dbType + ": Current Value",
-        Utils.isEmpty(nativeMeta.getSqlCurrentSequenceValue("testSeq")));
+        Utils.isEmpty(nativeMeta.getSqlCurrentSequenceValue("testSeq")),
+        dbType + ": Current Value");
     assertFalse(
-        dbType + ": Next Value", Utils.isEmpty(nativeMeta.getSqlNextSequenceValue("testSeq")));
+        Utils.isEmpty(nativeMeta.getSqlNextSequenceValue("testSeq")), dbType + ": Next Value");
 
     assertEquals(
         "SELECT sequence_name.nextval FROM DUAL", nativeMeta.getSqlNextSequenceValue(sequenceName));
@@ -528,7 +529,7 @@ public class OracleDatabaseMetaTest {
   }
 
   @Test
-  public void testSupportsTimestampDataTypeIsTrue() {
+  void testSupportsTimestampDataTypeIsTrue() {
     nativeMeta.setSupportsTimestampDataType(true);
     assertEquals(
         "TIMESTAMP",
