@@ -17,8 +17,8 @@
 
 package org.apache.hop.databases.oracle;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
@@ -37,29 +37,30 @@ import org.apache.hop.core.row.value.ValueMetaFactory;
 import org.apache.hop.core.row.value.ValueMetaPluginType;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.variables.Variables;
-import org.apache.hop.junit.rules.RestoreHopEnvironment;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.ClassRule;
-import org.junit.Test;
+import org.apache.hop.junit.rules.RestoreHopEngineEnvironmentExtension;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.RegisterExtension;
 
-public class OracleValueMetaBaseTest {
-  @ClassRule public static RestoreHopEnvironment env = new RestoreHopEnvironment();
+class OracleValueMetaBaseTest {
+  @RegisterExtension
+  static RestoreHopEngineEnvironmentExtension env = new RestoreHopEngineEnvironmentExtension();
 
   private DatabaseMeta databaseMeta;
   private IValueMeta valueMetaBase;
   private ResultSet resultSet;
   private IVariables variables;
 
-  @BeforeClass
-  public static void setUpBeforeClass() throws HopException {
+  @BeforeAll
+  static void setUpBeforeClass() throws HopException {
     PluginRegistry.addPluginType(ValueMetaPluginType.getInstance());
     PluginRegistry.addPluginType(DatabasePluginType.getInstance());
     PluginRegistry.init();
   }
 
-  @Before
-  public void setUp() throws HopException {
+  @BeforeEach
+  void setUp() throws HopException {
     valueMetaBase = ValueMetaFactory.createValueMeta(IValueMeta.TYPE_NONE);
     databaseMeta = spy(DatabaseMeta.class);
     databaseMeta.setIDatabase(spy(OracleDatabaseMeta.class));
@@ -68,7 +69,7 @@ public class OracleValueMetaBaseTest {
   }
 
   @Test
-  public void testMetadataPreviewSqlVarBinaryToString() throws SQLException, HopDatabaseException {
+  void testMetadataPreviewSqlVarBinaryToString() throws SQLException, HopDatabaseException {
     when(resultSet.getInt("DATA_TYPE")).thenReturn(Types.VARBINARY);
     when(resultSet.getInt("COLUMN_SIZE")).thenReturn(16);
 
@@ -78,8 +79,7 @@ public class OracleValueMetaBaseTest {
   }
 
   @Test
-  public void testMetadataPreviewSqlLongVarBinaryToString()
-      throws SQLException, HopDatabaseException {
+  void testMetadataPreviewSqlLongVarBinaryToString() throws SQLException, HopDatabaseException {
     when(resultSet.getInt("DATA_TYPE")).thenReturn(Types.LONGVARBINARY);
 
     IValueMeta valueMeta = valueMetaBase.getMetadataPreview(variables, databaseMeta, resultSet);
@@ -87,7 +87,7 @@ public class OracleValueMetaBaseTest {
   }
 
   @Test
-  public void testMetadataPreviewSqlNumericWithStrictBigNumberInterpretation()
+  void testMetadataPreviewSqlNumericWithStrictBigNumberInterpretation()
       throws SQLException, HopDatabaseException {
 
     when(resultSet.getInt("DATA_TYPE")).thenReturn(Types.NUMERIC);
@@ -100,7 +100,7 @@ public class OracleValueMetaBaseTest {
   }
 
   @Test
-  public void testMetadataPreviewSqlNumericWithoutStrictBigNumberInterpretation()
+  void testMetadataPreviewSqlNumericWithoutStrictBigNumberInterpretation()
       throws SQLException, HopDatabaseException {
     when(resultSet.getInt("DATA_TYPE")).thenReturn(Types.NUMERIC);
     when(resultSet.getInt("COLUMN_SIZE")).thenReturn(38);
@@ -112,7 +112,7 @@ public class OracleValueMetaBaseTest {
   }
 
   @Test
-  public void testMetadataPreviewSqlTimestampToDate() throws SQLException, HopDatabaseException {
+  void testMetadataPreviewSqlTimestampToDate() throws SQLException, HopDatabaseException {
     when(resultSet.getInt("DATA_TYPE")).thenReturn(Types.TIMESTAMP);
     when(resultSet.getInt("DECIMAL_DIGITS")).thenReturn(19);
     when(resultSet.getObject("DECIMAL_DIGITS")).thenReturn(mock(Object.class));
@@ -125,7 +125,7 @@ public class OracleValueMetaBaseTest {
   }
 
   @Test
-  public void testMetdataPreviewSqlDoubleWithTooBigLengthAndPrecision()
+  void testMetdataPreviewSqlDoubleWithTooBigLengthAndPrecision()
       throws SQLException, HopDatabaseException {
     doReturn(Types.DOUBLE).when(resultSet).getInt("DATA_TYPE");
     doReturn(128).when(resultSet).getInt("COLUMN_SIZE");
