@@ -17,53 +17,44 @@
 
 package org.apache.hop.beam.core;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
 
 import java.util.Date;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
-public class HopRowTest {
+class HopRowTest {
 
   @Test
-  public void equalsTest() {
-    Object[] row1 =
-        new Object[] {"AAA", "BBB", Long.valueOf(100), Double.valueOf(1.234), new Date(876876868)};
-    Object[] row2 =
-        new Object[] {"AAA", "BBB", Long.valueOf(100), Double.valueOf(1.234), new Date(876876868)};
+  void equalsTest() {
+    Object[] row1 = new Object[] {"AAA", "BBB", 100L, 1.234, new Date(876876868)};
+    Object[] row2 = new Object[] {"AAA", "BBB", 100L, 1.234, new Date(876876868)};
     HopRow hopRow1 = new HopRow(row1);
     HopRow hopRow2 = new HopRow(row2);
     assertEquals(hopRow1, hopRow2);
 
-    Object[] row3 =
-        new Object[] {"AAA", "BBB", Long.valueOf(100), Double.valueOf(1.234), new Date(876876868)};
-    Object[] row4 =
-        new Object[] {"AAA", "CCC", Long.valueOf(100), Double.valueOf(1.234), new Date(876876868)};
+    Object[] row3 = new Object[] {"AAA", "BBB", 100L, 1.234, new Date(876876868)};
+    Object[] row4 = new Object[] {"AAA", "CCC", 100L, 1.234, new Date(876876868)};
     HopRow hopRow3 = new HopRow(row3);
     HopRow hopRow4 = new HopRow(row4);
     assertNotEquals(hopRow3, hopRow4);
 
-    Object[] row5 =
-        new Object[] {"AAA", null, Long.valueOf(100), Double.valueOf(1.234), new Date(876876868)};
-    Object[] row6 =
-        new Object[] {"AAA", null, Long.valueOf(100), Double.valueOf(1.234), new Date(876876868)};
+    Object[] row5 = new Object[] {"AAA", null, 100L, 1.234, new Date(876876868)};
+    Object[] row6 = new Object[] {"AAA", null, 100L, 1.234, new Date(876876868)};
     HopRow hopRow5 = new HopRow(row5);
     HopRow hopRow6 = new HopRow(row6);
     assertEquals(hopRow5, hopRow6);
 
-    Object[] row7 =
-        new Object[] {"AAA", "BBB", Long.valueOf(100), Double.valueOf(1.234), new Date(876876868)};
-    Object[] row8 =
-        new Object[] {"AAA", null, Long.valueOf(100), Double.valueOf(1.234), new Date(876876868)};
+    Object[] row7 = new Object[] {"AAA", "BBB", 100L, 1.234, new Date(876876868)};
+    Object[] row8 = new Object[] {"AAA", null, 100L, 1.234, new Date(876876868)};
     HopRow hopRow7 = new HopRow(row7);
     HopRow hopRow8 = new HopRow(row8);
     assertNotEquals(hopRow7, hopRow8);
   }
 
   @Test
-  public void hashCodeTest() {
-    Object[] row1 =
-        new Object[] {"AAA", "BBB", Long.valueOf(100), Double.valueOf(1.234), new Date(876876868)};
+  void hashCodeTest() {
+    Object[] row1 = new Object[] {"AAA", "BBB", 100L, 1.234, new Date(876876868)};
     HopRow hopRow1 = new HopRow(row1);
     assertEquals(-1023250643, hopRow1.hashCode());
   }
