@@ -19,12 +19,12 @@ package org.apache.hop.beam.transform;
 
 import org.apache.hop.beam.util.BeamPipelineMetaUtil;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
-public class BasePipelineTest extends PipelineTestBase {
+class BasePipelineTest extends PipelineTestBase {
 
   @Test
-  public void testBasicPipeline() throws Exception {
+  void testBasicPipeline() throws Exception {
 
     PipelineMeta pipelineMeta =
         BeamPipelineMetaUtil.generateBeamInputOutputPipelineMeta(
