@@ -149,11 +149,12 @@ public class KettleConst {
               })
           .collect(Collectors.toMap(data -> (String) data[0], data -> (String) data[1]));
 
+  public static final String CONST_TRANS = "TRANS";
   public static final Map<String, String> kettleReplaceContent =
       Stream.of(
               new Object[][] {
                 {"JOB", "WORKFLOW"},
-                {"TRANS", "PIPELINE"},
+                {CONST_TRANS, "PIPELINE"},
                 {"PARENT_JOB", "PARENT_WORKFLOW"},
                 {"GP_JOB", "GP_WORKFLOW"},
                 {"ROOT_JOB", "ROOT_WORKFLOW"},
@@ -208,6 +209,19 @@ public class KettleConst {
                   "SWITCH_CASE_TARGET.CASE_TARGET_TRANSFORM_NAME"
                 }, // switchcase
                 {"DEFAULT_TARGET_STEP_NAME", "DEFAULT_TARGET_TRANSFORM_NAME"}, // switchcase
+                // Transform Javascript
+                {"trans_Status", "pipeline_Status"},
+                {"CONTINUE_TRANSFORMATION", "CONTINUE_PIPELINE"},
+                {"SKIP_TRANSFORMATION", "SKIP_PIPELINE"},
+                {"ERROR_TRANSFORMATION", "ERROR_PIPELINE"},
+                {"ABORT_TRANSFORMATION", "ABORT_PIPELINE"},
+                // Action Javascript
+                {"parent_job", "parent_workflow"},
+                // UJDC
+                {
+                  "processRow(StepMetaInterface smi, StepDataInterface sdi) throws KettleException",
+                  "processRow() throws HopException"
+                },
                 {"CURRENT_JOB", "CURRENT_WORKFLOW"}, // set variable
                 {"PARENT_JOB", "PARENT_WORKFLOW"}, // set variable
                 {"ROOT_JOB", "ROOT_WORKFLOW"} // set variable
@@ -216,11 +230,13 @@ public class KettleConst {
 
   public static final HashMap<String, String> replacements = new HashMap<>();
 
-  public static final List<String> repositoryTypes = Arrays.asList("JOB", "TRANS");
+  public static final List<String> repositoryTypes = Arrays.asList("JOB", CONST_TRANS);
 
   public static final List<String> jobTypes = Arrays.asList("JOB");
 
-  public static final List<String> transTypes = Arrays.asList("TRANS");
+  public static final List<String> transTypes = Arrays.asList(CONST_TRANS);
 
-  public KettleConst() {}
+  public KettleConst() {
+    // Do nothing
+  }
 }
