@@ -516,12 +516,11 @@ public class KettleImport extends HopImportBase implements IHopImport {
           && KettleConst.repositoryTypes.contains(repositoryNode.getTextContent())) {
         for (int j = 0; j < node.getChildNodes().getLength(); j++) {
           Node childNode = node.getChildNodes().item(j);
-          if (childNode.getNodeName().equals("jobname")
-              || childNode.getNodeName().equals("transname")
-              || childNode.getNodeName().equals("trans_name")) {
-            if (!StringUtil.isEmpty(childNode.getTextContent())) {
-              nodeToProcess = processRepositoryNode(node);
-            }
+          if ((childNode.getNodeName().equals("jobname")
+                  || childNode.getNodeName().equals("transname")
+                  || childNode.getNodeName().equals("trans_name"))
+              && !StringUtil.isEmpty(childNode.getTextContent())) {
+            nodeToProcess = processRepositoryNode(node);
           }
         }
         nodeList = nodeToProcess.getChildNodes();
