@@ -204,8 +204,7 @@ public class AvroOutputField implements Cloneable, Comparable<AvroOutputField> {
 
   public static int getDefaultAvroType(int pentahoType) {
     switch (pentahoType) {
-      case IValueMeta.TYPE_NUMBER:
-      case IValueMeta.TYPE_BIGNUMBER:
+      case IValueMeta.TYPE_NUMBER, IValueMeta.TYPE_BIGNUMBER:
         return AVRO_TYPE_DOUBLE;
       case IValueMeta.TYPE_INTEGER:
         return AVRO_TYPE_LONG;
