@@ -33,6 +33,7 @@ import org.apache.hop.core.exception.HopTransformException;
 import org.apache.hop.core.row.IRowMeta;
 import org.apache.hop.core.row.IValueMeta;
 import org.apache.hop.core.util.StringUtil;
+import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.HopMetadataProperty;
@@ -524,7 +525,7 @@ public class RedshiftBulkLoaderMeta
                 boolean error_found = false;
                 // OK, we have the table fields.
                 // Now see what we can find as previous transform...
-                if (prev != null && prev.size() > 0) {
+                if (prev != null && !prev.isEmpty()) {
                   cr =
                       new CheckResult(
                           ICheckResult.TYPE_RESULT_OK,
@@ -798,7 +799,7 @@ public class RedshiftBulkLoaderMeta
         new SqlStatement(transformMeta.getName(), databaseMeta, null); // default: nothing to do!
 
     if (databaseMeta != null) {
-      if (prev != null && prev.size() > 0) {
+      if (prev != null && !prev.isEmpty()) {
         if (!StringUtil.isEmpty(tablename)) {
           Database db = new Database(loggingObject, variables, databaseMeta);
           try {
@@ -809,7 +810,7 @@ public class RedshiftBulkLoaderMeta
             String cr_table = db.getDDL(schemaTable, prev);
 
             // Empty string means: nothing to do: set it to null...
-            if (cr_table == null || cr_table.length() == 0) {
+            if (Utils.isEmpty(cr_table)) {
               cr_table = null;
             }
 
