@@ -16,8 +16,8 @@
  */
 package org.apache.hop.vfs.s3.vfs;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
@@ -33,36 +33,36 @@ import org.apache.hop.vfs.s3.s3.vfs.S3FileName;
 import org.apache.hop.vfs.s3.s3.vfs.S3FileProvider;
 import org.apache.hop.vfs.s3.s3.vfs.S3FileSystem;
 import org.apache.hop.vfs.s3.s3common.S3HopProperty;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /** Unit tests for S3FileSystem */
-public class S3FileSystemTest {
+class S3FileSystemTest {
 
   S3FileSystem fileSystem;
   S3FileName fileName;
 
-  @BeforeClass
-  public static void initHop() throws Exception {
+  @BeforeAll
+  static void initHop() throws Exception {
     HopEnvironment.init();
   }
 
-  @Before
-  public void setUp() {
+  @BeforeEach
+  void setUp() {
     fileName = new S3FileName(S3FileNameTest.SCHEME, "/", "", FileType.FOLDER);
     fileSystem = new S3FileSystem(fileName, new FileSystemOptions());
   }
 
   @Test
-  public void testCreateFile() throws Exception {
+  void testCreateFile() throws Exception {
     assertNotNull(
         fileSystem.createFile(
             new S3FileName("s3", "bucketName", "/bucketName/key", FileType.FILE)));
   }
 
   @Test
-  public void testGetS3Service() {
+  void testGetS3Service() {
     assertNotNull(fileSystem.getS3Client());
 
     FileSystemOptions options = new FileSystemOptions();
@@ -79,7 +79,7 @@ public class S3FileSystemTest {
   }
 
   @Test
-  public void getPartSize() throws Exception {
+  void getPartSize() {
 
     S3FileSystem s3FileSystem = getTestInstance();
     s3FileSystem.storageUnitConverter = new StorageUnitConverter();
@@ -96,34 +96,32 @@ public class S3FileSystemTest {
   }
 
   @Test
-  public void testParsePartSize() throws Exception {
+  void testParsePartSize() {
     S3FileSystem s3FileSystem = getTestInstance();
     s3FileSystem.storageUnitConverter = new StorageUnitConverter();
     long _5MBLong = 5L * 1024L * 1024L;
     long _124MBLong = 124L * 1024L * 1024L;
     long _5GBLong = 5L * 1024L * 1024L * 1024L;
     long _12GBLong = 12L * 1024L * 1024L * 1024L;
-    long minimumPartSize = _5MBLong;
-    long maximumPartSize = _5GBLong;
 
     // TEST 1: below minimum
-    assertEquals(minimumPartSize, s3FileSystem.parsePartSize("1MB"));
+    assertEquals(_5MBLong, s3FileSystem.parsePartSize("1MB"));
 
     // TEST 2: at minimum
-    assertEquals(minimumPartSize, s3FileSystem.parsePartSize("5MB"));
+    assertEquals(_5MBLong, s3FileSystem.parsePartSize("5MB"));
 
     // TEST 3: between minimum and maximum
     assertEquals(_124MBLong, s3FileSystem.parsePartSize("124MB"));
 
     // TEST 4: at maximum
-    assertEquals(maximumPartSize, s3FileSystem.parsePartSize("5GB"));
+    assertEquals(_5GBLong, s3FileSystem.parsePartSize("5GB"));
 
     // TEST 5: above maximum
     assertEquals(_12GBLong, s3FileSystem.parsePartSize("12GB"));
   }
 
   @Test
-  public void testConvertToInt() throws Exception {
+  void testConvertToInt() {
     S3FileSystem s3FileSystem = getTestInstance();
 
     // TEST 1: below int max
@@ -137,7 +135,7 @@ public class S3FileSystemTest {
   }
 
   @Test
-  public void testConvertToLong() throws Exception {
+  void testConvertToLong() {
     S3FileSystem s3FileSystem = getTestInstance();
     long _10MBLong = 10L * 1024L * 1024L;
     s3FileSystem.storageUnitConverter = new StorageUnitConverter();
