@@ -17,14 +17,14 @@
 
 package org.apache.hop.vfs.s3.vfs;
 
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
 import org.apache.commons.vfs2.FileType;
 import org.apache.hop.vfs.s3.s3n.vfs.S3NFileName;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
-public class S3NFileNameTest {
+class S3NFileNameTest {
 
   private S3NFileName fileName = null;
 
@@ -32,25 +32,25 @@ public class S3NFileNameTest {
   public static final String SCHEME = "s3n";
   public static final int PORT = 843;
 
-  @Before
-  public void setup() {
+  @BeforeEach
+  void setup() {
     fileName = new S3NFileName(SCHEME, "", "", FileType.FOLDER);
   }
 
   @Test
-  public void testGetURI() {
+  void testGetURI() {
     String expected = buildS3URL("/");
     assertEquals(expected, fileName.getURI());
   }
 
   @Test
-  public void testCreateName() {
+  void testCreateName() {
     assertEquals(
         "s3n:///path/to/my/file", fileName.createName("/path/to/my/file", FileType.FILE).getURI());
   }
 
   @Test
-  public void testAppendRootUriWithNonDefaultPort() {
+  void testAppendRootUriWithNonDefaultPort() {
     fileName = new S3NFileName(SCHEME, "", "FooFolder", FileType.FOLDER);
     String expectedUri = SCHEME + "://" + "FooFolder";
     assertEquals(expectedUri, fileName.getURI());
