@@ -36,8 +36,6 @@ import org.apache.hop.neo4j.transforms.output.Neo4JOutputDialog;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.PipelinePreviewFactory;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.ui.core.FormDataBuilder;
 import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
@@ -79,10 +77,11 @@ import org.neo4j.driver.Value;
 import org.neo4j.driver.types.Type;
 import org.neo4j.driver.util.Pair;
 
-public class CypherDialog extends BaseTransformDialog implements ITransformDialog {
+public class CypherDialog extends BaseTransformDialog {
 
   private static final Class<?> PKG =
       CypherMeta.class; // for i18n purposes, needed by Translator2!!
+  public static final String CONST_ERROR = "Error";
 
   private CTabFolder wTabFolder;
 
@@ -114,13 +113,9 @@ public class CypherDialog extends BaseTransformDialog implements ITransformDialo
   private CypherMeta input;
 
   public CypherDialog(
-      Shell parent,
-      IVariables variables,
-      Object inputMetadata,
-      PipelineMeta pipelineMeta,
-      String transformName) {
-    super(parent, variables, (BaseTransformMeta) inputMetadata, pipelineMeta, transformName);
-    input = (CypherMeta) inputMetadata;
+      Shell parent, IVariables variables, CypherMeta inputMetadata, PipelineMeta pipelineMeta) {
+    super(parent, variables, inputMetadata, pipelineMeta);
+    input = inputMetadata;
 
     metadataProvider = HopGui.getInstance().getMetadataProvider();
   }
@@ -225,7 +220,7 @@ public class CypherDialog extends BaseTransformDialog implements ITransformDialo
     try {
       wConnection.fillItems();
     } catch (Exception e) {
-      new ErrorDialog(shell, "Error", "Error getting list of connections", e);
+      new ErrorDialog(shell, CONST_ERROR, "Error getting list of connections", e);
     }
     Control lastControl = wConnection;
 
@@ -494,7 +489,7 @@ public class CypherDialog extends BaseTransformDialog implements ITransformDialo
                     Neo4JOutputDialog.getPropertyNameTypePrimary(
                         item, valueMeta, new int[] {1}, new int[] {3}, -1));
           } catch (Exception ex) {
-            new ErrorDialog(shell, "Error", "Error getting transform input fields", ex);
+            new ErrorDialog(shell, CONST_ERROR, "Error getting transform input fields", ex);
           }
         });
 
@@ -833,7 +828,7 @@ public class CypherDialog extends BaseTransformDialog implements ITransformDialo
       wReturns.setRowNums();
       wReturns.optWidth(true);
     } catch (Exception e) {
-      new ErrorDialog(shell, "Error", "Error getting return values from Cypher statement", e);
+      new ErrorDialog(shell, CONST_ERROR, "Error getting return values from Cypher statement", e);
     } finally {
       if (transaction != null) {
         transaction.rollback();
