@@ -1036,7 +1036,7 @@ public class Neo4JOutputDialog extends BaseTransformDialog {
               PKG, "Neo4JOutputDialog.Warning.CreateIndexesIsLimited", Const.CR));
     }
 
-    if (message.length() > 0
+    if (!message.isEmpty()
         && "Y".equalsIgnoreCase(props.getCustomParameter(STRING_DYNAMIC_LABELS_WARNING, "Y"))) {
 
       MessageDialogWithToggle md =
@@ -1110,6 +1110,8 @@ public class Neo4JOutputDialog extends BaseTransformDialog {
                 (item, valueMeta) ->
                     getPropertyNameTypePrimary(item, valueMeta, new int[] {2}, new int[] {3}, 4));
             break;
+          default:
+            break;
         }
       }
     } catch (HopException ke) {
