@@ -19,18 +19,18 @@
 package org.apache.hop.neo4j.actions.cypherscript;
 
 import org.apache.hop.workflow.action.ActionSerializationTestUtil;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
-public class CypherScriptTest {
+class CypherScriptTest {
   @Test
-  public void testSerialization() throws Exception {
+  void testSerialization() throws Exception {
     CypherScript action =
         ActionSerializationTestUtil.testSerialization(
             "/cypher-script-action.xml", CypherScript.class);
 
-    Assert.assertEquals("Test", action.getConnectionName());
-    Assert.assertEquals("A Cypher statement", action.getScript());
-    Assert.assertFalse(action.isReplacingVariables());
+    Assertions.assertEquals("Test", action.getConnectionName());
+    Assertions.assertEquals("A Cypher statement", action.getScript());
+    Assertions.assertFalse(action.isReplacingVariables());
   }
 }
