@@ -20,6 +20,7 @@ package org.apache.hop.parquet.transforms.input;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import lombok.Getter;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hop.core.RowMetaAndData;
 import org.apache.parquet.hadoop.api.InitContext;
@@ -35,7 +36,7 @@ public class ParquetReadSupport extends ReadSupport<RowMetaAndData> {
     this.fields = fields;
   }
 
-  private MessageType messageType;
+  @Getter private MessageType messageType;
 
   @Override
   public ReadContext init(InitContext context) {
@@ -51,13 +52,4 @@ public class ParquetReadSupport extends ReadSupport<RowMetaAndData> {
       ReadContext readContext) {
     return new ParquetRecordMaterializer(messageType, fields);
   }
-
-  /**
-   * Gets messageType
-   *
-   * @return value of messageType
-   */
-  public MessageType getMessageType() {
-    return messageType;
-  }
 }
