@@ -24,8 +24,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.dialog.EnterSelectionDialog;
@@ -47,8 +45,8 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
-public class AddSequenceDialog extends BaseTransformDialog implements ITransformDialog {
-  private static final Class<?> PKG = AddSequenceMeta.class; // For Translator
+public class AddSequenceDialog extends BaseTransformDialog {
+  private static final Class<?> PKG = AddSequenceMeta.class;
 
   private Text wValuename;
 
@@ -83,9 +81,12 @@ public class AddSequenceDialog extends BaseTransformDialog implements ITransform
   private final AddSequenceMeta input;
 
   public AddSequenceDialog(
-      Shell parent, IVariables variables, Object in, PipelineMeta pipelineMeta, String sname) {
-    super(parent, variables, (BaseTransformMeta) in, pipelineMeta, sname);
-    input = (AddSequenceMeta) in;
+      Shell parent,
+      IVariables variables,
+      AddSequenceMeta transformMeta,
+      PipelineMeta pipelineMeta) {
+    super(parent, variables, transformMeta, pipelineMeta);
+    input = transformMeta;
   }
 
   @Override
