@@ -173,18 +173,16 @@ public class BlockUntilTransformsFinishDialog extends BaseTransformDialog {
 
     List<String> entries = new ArrayList<>();
     for (String previousTransform : previousTransforms) {
-      if (!previousTransform.equals(transformName)) {
-        if (nextTransforms != null && !nextTransforms.isEmpty()) {
-          boolean found = false;
-          for (String nextTransform : nextTransforms) {
-            if (nextTransform.equals(previousTransform)) {
-              found = true;
-            }
-          }
-          if (!found) {
-            entries.add(previousTransform);
+      if (!previousTransform.equals(transformName) && !Utils.isEmpty(nextTransforms)) {
+        boolean found = false;
+        for (String nextTransform : nextTransforms) {
+          if (nextTransform.equals(previousTransform)) {
+            found = true;
           }
         }
+        if (!found) {
+          entries.add(previousTransform);
+        }
       }
     }
     previousTransforms = entries.toArray(new String[0]);
