@@ -74,7 +74,7 @@ public class BlockUntilTransformsFinishMeta
       IHopMetadataProvider metadataProvider) {
     CheckResult cr;
 
-    if (prev == null || prev.size() == 0) {
+    if (prev == null || prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_WARNING,
