@@ -26,8 +26,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.ui.core.ConstUi;
 import org.apache.hop.ui.core.PropsUi;
@@ -52,8 +50,8 @@ import org.eclipse.swt.widgets.Table;
 import org.eclipse.swt.widgets.TableItem;
 import org.eclipse.swt.widgets.Text;
 
-public class CheckSumDialog extends BaseTransformDialog implements ITransformDialog {
-  private static final Class<?> PKG = CheckSumDialog.class; // For Translator
+public class CheckSumDialog extends BaseTransformDialog {
+  private static final Class<?> PKG = CheckSumDialog.class;
 
   private final CheckSumMeta input;
 
@@ -71,9 +69,9 @@ public class CheckSumDialog extends BaseTransformDialog implements ITransformDia
   private CCombo wResultType;
 
   public CheckSumDialog(
-      Shell parent, IVariables variables, Object in, PipelineMeta tr, String sname) {
-    super(parent, variables, (BaseTransformMeta) in, tr, sname);
-    input = (CheckSumMeta) in;
+      Shell parent, IVariables variables, CheckSumMeta transformMeta, PipelineMeta pipelineMeta) {
+    super(parent, variables, transformMeta, pipelineMeta);
+    input = transformMeta;
   }
 
   @Override
@@ -95,7 +93,7 @@ public class CheckSumDialog extends BaseTransformDialog implements ITransformDia
     shell.setText(BaseMessages.getString(PKG, "CheckSumDialog.Shell.Title"));
 
     int middle = props.getMiddlePct();
-    int margin = props.getMargin();
+    int margin = PropsUi.getMargin();
 
     // TransformName line
     wlTransformName = new Label(shell, SWT.RIGHT);
