@@ -258,7 +258,7 @@ public class CheckSumMeta extends BaseTransformMeta<CheckSum, CheckSumData> {
     }
     remarks.add(cr);
 
-    if (prev == null || prev.size() == 0) {
+    if (prev == null || prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_WARNING,
