@@ -240,7 +240,7 @@ public class CloneRowMeta extends BaseTransformMeta<CloneRow, CloneRowData> {
       remarks.add(cr);
     }
 
-    if (prev == null || prev.size() == 0) {
+    if (prev == null || prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_WARNING,
