@@ -82,19 +82,17 @@ public class CrateDBBulkLoader extends BaseTransform<CrateDBBulkLoaderMeta, Crat
         verifyDatabaseConnection();
         data.databaseMeta = this.getPipelineMeta().findDatabase(meta.getConnection(), variables);
 
-        if (meta.isStreamToS3Csv()) {
-          if (!meta.isUseHttpEndpoint()) {
-            String readFromFilename = resolve(meta.getReadFromFilename());
-            String localPath = resolve(meta.getVolumeMapping());
-            if (!StringUtils.isEmpty(localPath) && isURIOfScheme(readFromFilename, Scheme.FILE)) {
-              data.writer =
-                  HopVfs.getOutputStream(
-                      FilenameUtils.concat(localPath, extractFilename(readFromFilename)), false);
-            } else {
-              data.writer = HopVfs.getOutputStream(readFromFilename, false);
-            }
-            // get the file output stream to write to S3
+        if (meta.isStreamToS3Csv() && !meta.isUseHttpEndpoint()) {
+          String readFromFilename = resolve(meta.getReadFromFilename());
+          String localPath = resolve(meta.getVolumeMapping());
+          if (!StringUtils.isEmpty(localPath) && isURIOfScheme(readFromFilename, Scheme.FILE)) {
+            data.writer =
+                HopVfs.getOutputStream(
+                    FilenameUtils.concat(localPath, extractFilename(readFromFilename)), false);
+          } else {
+            data.writer = HopVfs.getOutputStream(readFromFilename, false);
           }
+          // get the file output stream to write to S3
         }
 
         data.db = new Database(this, this, data.databaseMeta);
@@ -223,10 +221,6 @@ public class CrateDBBulkLoader extends BaseTransform<CrateDBBulkLoaderMeta, Crat
 
         data.fieldnrs = new HashMap<>();
 
-        //        if (meta.isTruncateTable()) {
-        //          // truncateTable();
-        //        }
-
         meta.getFields(data.insertRowMeta, getTransformName(), null, null, this, metadataProvider);
 
         if (!meta.specifyFields()) {
@@ -441,9 +435,7 @@ public class CrateDBBulkLoader extends BaseTransform<CrateDBBulkLoaderMeta, Crat
         case IValueMeta.TYPE_STRING:
           convertedValue = (String) rowItem;
           break;
-        case IValueMeta.TYPE_INTEGER:
-        case IValueMeta.TYPE_NUMBER:
-        case IValueMeta.TYPE_BIGNUMBER:
+        case IValueMeta.TYPE_INTEGER, IValueMeta.TYPE_NUMBER, IValueMeta.TYPE_BIGNUMBER:
           convertedValue = String.valueOf(rowItem);
           break;
         case IValueMeta.TYPE_TIMESTAMP:
@@ -516,7 +508,7 @@ public class CrateDBBulkLoader extends BaseTransform<CrateDBBulkLoaderMeta, Crat
     for (int i = 0; i < fieldList.size(); i++) {
       CrateDBBulkLoaderField field = fieldList.get(i);
       if (i > 0) {
-        sb.append(", " + field.getDatabaseField());
+        sb.append(", ").append(field.getDatabaseField());
       } else {
         sb.append(field.getDatabaseField());
       }
@@ -580,7 +572,7 @@ public class CrateDBBulkLoader extends BaseTransform<CrateDBBulkLoaderMeta, Crat
       rowMeta = data.db.getTableFields(meta.getTableName());
     }
     try {
-      if (rowMeta.size() == 0) {
+      if (rowMeta.isEmpty()) {
         throw new HopException("No fields found in table");
       }
 
@@ -859,18 +851,17 @@ public class CrateDBBulkLoader extends BaseTransform<CrateDBBulkLoaderMeta, Crat
             }
           }
 
-        } else if (escapeExists && source[index] == escape[0]) {
-
+        } else if (escapeExists
+            && source[index] == escape[0]
+            && index + escape.length <= source.length) {
           // Potential match found, make sure there are enough bytes to support a full match
-          if (index + escape.length <= source.length) {
-            // First byte of separator found
-            result = true; // Assume match
-            for (int i = 1; i < escape.length; i++) {
-              if (source[index + i] != escape[i]) {
-                // Separator match is proven false
-                result = false;
-                break;
-              }
+          // First byte of separator found
+          result = true; // Assume match
+          for (int i = 1; i < escape.length; i++) {
+            if (source[index + i] != escape[i]) {
+              // Separator match is proven false
+              result = false;
+              break;
             }
           }
         }
