@@ -159,7 +159,7 @@ public class DelayMeta extends BaseTransformMeta<Delay, DelayData> {
     }
     remarks.add(cr);
 
-    if (prev == null || prev.size() == 0) {
+    if (prev == null || prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_WARNING,
