@@ -752,7 +752,7 @@ public class DimensionLookup extends BaseTransform<DimensionLookupMeta, Dimensio
           } else if (data.databaseMeta.supportsSequences()
               // Try to get the value by looking at a SEQUENCE (oracle mostly)
               && meta.getSequenceName() != null
-              && meta.getSequenceName().length() > 0) {
+              && !meta.getSequenceName().isEmpty()) {
             technicalKey =
                 data.db.getNextSequenceValue(
                     data.realSchemaName, meta.getSequenceName(), f.getReturns().getKeyField());
@@ -1248,7 +1248,7 @@ public class DimensionLookup extends BaseTransform<DimensionLookupMeta, Dimensio
     if (technicalKey == null && data.databaseMeta.supportsAutoGeneratedKeys()) {
       try {
         RowMetaAndData keys = data.db.getGeneratedKeys(data.prepStatementInsert);
-        if (keys.getRowMeta().size() > 0) {
+        if (!keys.getRowMeta().isEmpty()) {
           technicalKey = keys.getRowMeta().getInteger(keys.getData(), 0);
         } else {
           throw new HopDatabaseException(
