@@ -23,12 +23,12 @@ import org.apache.hop.core.row.IRowMeta;
 import org.apache.hop.core.row.RowMeta;
 import org.apache.hop.core.row.value.ValueMetaTimestamp;
 import org.apache.hop.core.util.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
-public class DimensionCacheTest {
+class DimensionCacheTest {
 
   @Test
-  public void testCompareDateInterval() {
+  void testCompareDateInterval() {
     IRowMeta rowMeta = new RowMeta();
     rowMeta.addValueMeta(new ValueMetaTimestamp("DATE_FROM"));
     rowMeta.addValueMeta(new ValueMetaTimestamp("DATE_TO"));
