@@ -186,7 +186,7 @@ public class FieldsChangeSequenceMeta
     }
     remarks.add(cr);
 
-    if (prev == null || prev.size() == 0) {
+    if (prev == null || prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_WARNING,
