@@ -21,8 +21,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
@@ -36,15 +34,18 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
-public class FilesFromResultDialog extends BaseTransformDialog implements ITransformDialog {
-  private static final Class<?> PKG = FilesFromResultMeta.class; // For Translator
+public class FilesFromResultDialog extends BaseTransformDialog {
+  private static final Class<?> PKG = FilesFromResultMeta.class;
 
   private final FilesFromResultMeta input;
 
   public FilesFromResultDialog(
-      Shell parent, IVariables variables, Object in, PipelineMeta pipelineMeta, String sname) {
-    super(parent, variables, (BaseTransformMeta) in, pipelineMeta, sname);
-    input = (FilesFromResultMeta) in;
+      Shell parent,
+      IVariables variables,
+      FilesFromResultMeta transformMeta,
+      PipelineMeta pipelineMeta) {
+    super(parent, variables, transformMeta, pipelineMeta);
+    input = transformMeta;
   }
 
   @Override
@@ -66,7 +67,7 @@ public class FilesFromResultDialog extends BaseTransformDialog implements ITrans
     shell.setText(BaseMessages.getString(PKG, "FilesFromResultDialog.Shell.Title"));
 
     int middle = props.getMiddlePct();
-    int margin = props.getMargin();
+    int margin = PropsUi.getMargin();
 
     // TransformName line
     wlTransformName = new Label(shell, SWT.RIGHT);
