@@ -167,7 +167,7 @@ public class FilterRowsMeta extends BaseTransformMeta<FilterRows, FilterRowsData
     remarks.add(cr);
 
     // Look up fields in the input stream <prev>
-    if (prev != null && prev.size() > 0) {
+    if (prev != null && !prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_OK,
