@@ -16,8 +16,8 @@
  */
 package org.apache.hop.pipeline.transforms.filterrows;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
 
 import com.google.common.collect.ImmutableList;
 import java.util.Arrays;
@@ -33,14 +33,13 @@ import org.apache.hop.pipeline.transforms.dummy.DummyMeta;
 import org.apache.hop.pipeline.transforms.loadsave.validator.ConditionLoadSaveValidator;
 import org.apache.hop.pipeline.transforms.loadsave.validator.IFieldLoadSaveValidator;
 import org.apache.hop.pipeline.transforms.loadsave.validator.StringLoadSaveValidator;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
-public class FilterRowsMetaTest {
+class FilterRowsMetaTest {
 
-  @Before
-  public void setUpLoadSave() throws Exception {
+  @BeforeEach
+  void setUpLoadSave() throws Exception {
     HopEnvironment.init();
     PluginRegistry.init();
     List<String> attributes = Arrays.asList("condition", "send_true_to", "send_false_to");
@@ -62,28 +61,28 @@ public class FilterRowsMetaTest {
   }
 
   @Test
-  public void testSerialization() throws Exception {
+  void testSerialization() throws Exception {
 
     FilterRowsMeta meta =
         TransformSerializationTestUtil.testSerialization(
             "/filter-rows-transform-basic.xml", FilterRowsMeta.class);
-    Assert.assertEquals("True", meta.getTransformIOMeta().getTargetStreams().get(0).getSubject());
-    Assert.assertEquals("False", meta.getTransformIOMeta().getTargetStreams().get(1).getSubject());
+    assertEquals("True", meta.getTransformIOMeta().getTargetStreams().get(0).getSubject());
+    assertEquals("False", meta.getTransformIOMeta().getTargetStreams().get(1).getSubject());
 
     Condition condition = meta.getCondition();
-    Assert.assertNotNull(condition);
-    Assert.assertEquals(2, condition.getChildren().size());
+    assertNotNull(condition);
+    assertEquals(2, condition.getChildren().size());
     Condition c1 = condition.getChildren().get(0);
-    Assert.assertEquals("stateCode", c1.getLeftValueName());
-    Assert.assertEquals("FL", c1.getRightValueString());
+    assertEquals("stateCode", c1.getLeftValueName());
+    assertEquals("FL", c1.getRightValueString());
 
     Condition c2 = condition.getChildren().get(1);
-    Assert.assertEquals("housenr", c2.getLeftValueName());
-    Assert.assertEquals("100", c2.getRightValueString());
+    assertEquals("housenr", c2.getLeftValueName());
+    assertEquals("100", c2.getRightValueString());
   }
 
   @Test
-  public void testClone() {
+  void testClone() {
     FilterRowsMeta filterRowsMeta = new FilterRowsMeta();
     filterRowsMeta.setCondition(new Condition());
     filterRowsMeta.setTrueTransformName("true");
@@ -96,7 +95,7 @@ public class FilterRowsMetaTest {
   }
 
   @Test
-  public void modifiedTarget() throws Exception {
+  void modifiedTarget() {
     FilterRowsMeta filterRowsMeta = new FilterRowsMeta();
     TransformMeta trueOutput = new TransformMeta("true", new DummyMeta());
     TransformMeta falseOutput = new TransformMeta("false", new DummyMeta());
