@@ -17,10 +17,14 @@
 
 package org.apache.hop.pipeline.transforms.formula;
 
+import static org.apache.hop.pipeline.transforms.formula.util.FormulaFieldsExtractor.getFormulaFieldList;
+
 import java.io.IOException;
 import java.sql.Timestamp;
 import java.util.Arrays;
 import java.util.HashMap;
+import java.util.List;
+import java.util.stream.IntStream;
 import org.apache.hop.core.exception.HopException;
 import org.apache.hop.core.exception.HopTransformException;
 import org.apache.hop.core.row.IValueMeta;
@@ -35,38 +39,40 @@ import org.apache.hop.pipeline.transforms.formula.util.FormulaParser;
 import org.apache.poi.ss.usermodel.CellType;
 import org.apache.poi.ss.usermodel.CellValue;
 import org.apache.poi.ss.usermodel.DateUtil;
-import org.apache.poi.ss.usermodel.Row;
-import org.apache.poi.xssf.usermodel.XSSFSheet;
-import org.apache.poi.xssf.usermodel.XSSFWorkbook;
 
 public class Formula extends BaseTransform<FormulaMeta, FormulaData> {
 
-  private XSSFWorkbook workBook;
-  private XSSFSheet workSheet;
-  private Row sheetRow;
-  private HashMap<String, String> replaceMap;
+  private FormulaPoi[] poi;
+  private List<String>[] formulaFieldLists;
+  private final HashMap<String, String> replaceMap = new HashMap<>();
 
   @Override
   public boolean init() {
-
-    workBook = new XSSFWorkbook();
-    workSheet = workBook.createSheet();
-    sheetRow = workSheet.createRow(0);
-    replaceMap = new HashMap<>();
-
     return true;
   }
 
   @Override
   public void dispose() {
-    try {
-      workBook.close();
-    } catch (IOException e) {
-      logError("Unable to close temporary workbook", e);
+    if (poi != null) {
+      for (final var it : poi) {
+        try {
+          it.destroy();
+        } catch (IOException e) {
+          logError("Unable to close temporary workbook", e);
+        }
+      }
     }
     super.dispose();
   }
 
+  @Override
+  public void batchComplete() throws HopException {
+    super.batchComplete();
+    for (final var it : poi) {
+      it.reset();
+    }
+  }
+
   @Override
   public boolean processRow() throws HopException {
 
@@ -112,6 +118,18 @@ public class Formula extends BaseTransform<FormulaMeta, FormulaData> {
           data.replaceIndex[j] = -1;
         }
       }
+
+      // create one backing row per formula
+      poi =
+          IntStream.range(0, meta.getFormulas().size())
+              .mapToObj(it -> new FormulaPoi(this::logDebug))
+              .toArray(FormulaPoi[]::new);
+      // compute only once for all rows the default field list
+      formulaFieldLists =
+          meta.getFormulas().stream()
+              .map(FormulaMetaFunction::getFormula)
+              .map(f -> getFormulaFieldList(resolve(f)))
+              .toArray(List[]::new);
     }
 
     int tempIndex = getInputRowMeta().size();
@@ -120,11 +138,6 @@ public class Formula extends BaseTransform<FormulaMeta, FormulaData> {
       logRowlevel("Read row #" + getLinesRead() + " : " + Arrays.toString(r));
     }
 
-    if (sheetRow != null) {
-      workSheet.removeRow(sheetRow);
-    }
-    sheetRow = workSheet.createRow(0);
-
     Object[] outputRowData = RowDataUtil.resizeArray(r, data.outputRowMeta.size());
     Object outputValue = null;
 
@@ -133,7 +146,13 @@ public class Formula extends BaseTransform<FormulaMeta, FormulaData> {
       FormulaMetaFunction formula = meta.getFormulas().get(i);
       FormulaParser parser =
           new FormulaParser(
-              formula, data.outputRowMeta, outputRowData, sheetRow, variables, replaceMap);
+              formula,
+              data.outputRowMeta,
+              outputRowData,
+              poi[i],
+              variables,
+              replaceMap,
+              formulaFieldLists[i]);
       try {
         CellValue cellValue = parser.getFormulaValue();
         CellType cellType = cellValue.getCellType();
@@ -215,7 +234,7 @@ public class Formula extends BaseTransform<FormulaMeta, FormulaData> {
    * class to implement your own transforms.
    *
    * @param transformMeta The TransformMeta object to run.
-   * @param meta
+   * @param meta Formula Meta of the transform
    * @param data the data object to store temporary data, database connections, caches, result sets,
    *     hashtables etc.
    * @param copyNr The copynumber for this transform.
@@ -254,46 +273,21 @@ public class Formula extends BaseTransform<FormulaMeta, FormulaData> {
           value = ((Number) formulaResult).doubleValue();
         }
         break;
-      case FormulaData.RETURN_TYPE_INTEGER:
+      case FormulaData.RETURN_TYPE_INTEGER,
+          FormulaData.RETURN_TYPE_LONG,
+          FormulaData.RETURN_TYPE_DATE,
+          FormulaData.RETURN_TYPE_BIGDECIMAL,
+          FormulaData.RETURN_TYPE_TIMESTAMP:
         if (fn.isNeedDataConversion()) {
           value = convertDataToTargetValueMeta(realIndex, formulaResult);
         } else {
           value = formulaResult;
         }
         break;
-      case FormulaData.RETURN_TYPE_LONG:
-        if (fn.isNeedDataConversion()) {
-          value = convertDataToTargetValueMeta(realIndex, formulaResult);
-        } else {
-          value = formulaResult;
-        }
-        break;
-      case FormulaData.RETURN_TYPE_DATE:
-        if (fn.isNeedDataConversion()) {
-          value = convertDataToTargetValueMeta(realIndex, formulaResult);
-        } else {
-          value = formulaResult;
-        }
-        break;
-      case FormulaData.RETURN_TYPE_BIGDECIMAL:
-        if (fn.isNeedDataConversion()) {
-          value = convertDataToTargetValueMeta(realIndex, formulaResult);
-        } else {
-          value = formulaResult;
-        }
-        break;
-      case FormulaData.RETURN_TYPE_BYTE_ARRAY:
+      case FormulaData.RETURN_TYPE_BYTE_ARRAY, FormulaData.RETURN_TYPE_BOOLEAN:
         value = formulaResult;
         break;
-      case FormulaData.RETURN_TYPE_BOOLEAN:
-        value = formulaResult;
-        break;
-      case FormulaData.RETURN_TYPE_TIMESTAMP:
-        if (fn.isNeedDataConversion()) {
-          value = convertDataToTargetValueMeta(realIndex, formulaResult);
-        } else {
-          value = formulaResult;
-        }
+      default:
         break;
     } // if none case is caught - null is returned.
     return value;
