@@ -17,6 +17,11 @@
 
 package org.apache.hop.pipeline.transforms.formula.editor.util;
 
+import lombok.Getter;
+import lombok.Setter;
+
+@Getter
+@Setter
 public class CompletionProposal {
   private String menuText;
   private String completionString;
@@ -27,46 +32,4 @@ public class CompletionProposal {
     this.completionString = completionString;
     this.offset = offset;
   }
-
-  /**
-   * @return the menuText
-   */
-  public String getMenuText() {
-    return menuText;
-  }
-
-  /**
-   * @param menuText the menuText to set
-   */
-  public void setMenuText(String menuText) {
-    this.menuText = menuText;
-  }
-
-  /**
-   * @return the completionString
-   */
-  public String getCompletionString() {
-    return completionString;
-  }
-
-  /**
-   * @param completionString the completionString to set
-   */
-  public void setCompletionString(String completionString) {
-    this.completionString = completionString;
-  }
-
-  /**
-   * @return the offset
-   */
-  public int getOffset() {
-    return offset;
-  }
-
-  /**
-   * @param offset the offset to set
-   */
-  public void setOffset(int offset) {
-    this.offset = offset;
-  }
 }
