@@ -18,8 +18,12 @@
 package org.apache.hop.pipeline.transforms.getfilenames;
 
 import java.util.Objects;
+import lombok.Getter;
+import lombok.Setter;
 import org.apache.hop.metadata.api.HopMetadataProperty;
 
+@Getter
+@Setter
 public class FilterItem {
 
   /** The file filter type selection */
@@ -34,14 +38,6 @@ public class FilterItem {
     this.fileTypeFilterSelection = fileTypeFilterSelection;
   }
 
-  public String getFileTypeFilterSelection() {
-    return fileTypeFilterSelection;
-  }
-
-  public void setFileTypeFilterSelection(String fileTypeFilterSelection) {
-    this.fileTypeFilterSelection = fileTypeFilterSelection;
-  }
-
   @Override
   public boolean equals(Object o) {
     if (this == o) return true;
