@@ -26,7 +26,6 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.PipelinePreviewFactory;
-import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.dialog.EnterNumberDialog;
@@ -52,8 +51,8 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
-public class GetTableNamesDialog extends BaseTransformDialog implements ITransformDialog {
-  private static final Class<?> PKG = GetTableNamesMeta.class; // For Translator
+public class GetTableNamesDialog extends BaseTransformDialog {
+  private static final Class<?> PKG = GetTableNamesMeta.class;
 
   private MetaSelectionLine<DatabaseMeta> wConnection;
 
@@ -91,9 +90,12 @@ public class GetTableNamesDialog extends BaseTransformDialog implements ITransfo
   private boolean gotPreviousFields = false;
 
   public GetTableNamesDialog(
-      Shell parent, IVariables variables, Object in, PipelineMeta pipelineMeta, String sname) {
-    super(parent, variables, (GetTableNamesMeta) in, pipelineMeta, sname);
-    input = (GetTableNamesMeta) in;
+      Shell parent,
+      IVariables variables,
+      GetTableNamesMeta transformMeta,
+      PipelineMeta pipelineMeta) {
+    super(parent, variables, transformMeta, pipelineMeta);
+    input = transformMeta;
   }
 
   @Override
