@@ -18,11 +18,11 @@
 package org.apache.hop.pipeline.transforms.gettablenames;
 
 import org.apache.hop.pipeline.transform.TransformSerializationTestUtil;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
-public class GetTableNamesMetaTest {
+class GetTableNamesMetaTest {
   @Test
-  public void testSerialization() throws Exception {
+  void testSerialization() throws Exception {
     TransformSerializationTestUtil.testSerialization(
         "/get-table-names-transform.xml", GetTableNamesMeta.class);
   }
