@@ -18,6 +18,8 @@
 
 package org.apache.hop.pipeline.transforms;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
 import java.util.List;
 import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.metadata.serializer.memory.MemoryMetadataProvider;
@@ -25,13 +27,12 @@ import org.apache.hop.metadata.serializer.xml.XmlMetadataUtil;
 import org.apache.hop.pipeline.transforms.groupby.Aggregation;
 import org.apache.hop.pipeline.transforms.groupby.GroupByMeta;
 import org.apache.hop.pipeline.transforms.groupby.GroupingField;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
-public class GroupByMetaTest {
+class GroupByMetaTest {
 
   @Test
-  public void testClone() throws Exception {
+  void testClone() throws Exception {
     GroupByMeta meta1 = generateTestMeta();
     GroupByMeta meta2 = meta1.clone();
 
@@ -39,7 +40,7 @@ public class GroupByMetaTest {
   }
 
   @Test
-  public void testSerialization() throws Exception {
+  void testSerialization() throws Exception {
     GroupByMeta meta1 = generateTestMeta();
     String xml = "<transform>" + XmlMetadataUtil.serializeObjectToXml(meta1) + "</transform>";
 
@@ -53,23 +54,23 @@ public class GroupByMetaTest {
   }
 
   public void compareMetas(GroupByMeta meta1, GroupByMeta meta2) {
-    Assert.assertEquals(meta1.getGroupingFields().size(), meta2.getGroupingFields().size());
+    assertEquals(meta1.getGroupingFields().size(), meta2.getGroupingFields().size());
     for (int i = 0; i < meta1.getGroupingFields().size(); i++) {
       GroupingField field1 = meta1.getGroupingFields().get(i);
       GroupingField field2 = meta2.getGroupingFields().get(i);
-      Assert.assertEquals(field1, field2);
+      assertEquals(field1, field2);
     }
-    Assert.assertEquals(meta1.getAggregations().size(), meta2.getAggregations().size());
+    assertEquals(meta1.getAggregations().size(), meta2.getAggregations().size());
     for (int i = 0; i < meta1.getAggregations().size(); i++) {
       Aggregation agg1 = meta1.getAggregations().get(i);
       Aggregation agg2 = meta2.getAggregations().get(i);
-      Assert.assertEquals(agg1, agg2);
+      assertEquals(agg1, agg2);
     }
-    Assert.assertEquals(meta1.isPassAllRows(), meta2.isPassAllRows());
-    Assert.assertEquals(meta1.isAddingLineNrInGroup(), meta2.isAddingLineNrInGroup());
-    Assert.assertEquals(meta1.getLineNrInGroupField(), meta2.getLineNrInGroupField());
-    Assert.assertEquals(meta1.getDirectory(), meta2.getDirectory());
-    Assert.assertEquals(meta1.getPrefix(), meta2.getPrefix());
+    assertEquals(meta1.isPassAllRows(), meta2.isPassAllRows());
+    assertEquals(meta1.isAddingLineNrInGroup(), meta2.isAddingLineNrInGroup());
+    assertEquals(meta1.getLineNrInGroupField(), meta2.getLineNrInGroupField());
+    assertEquals(meta1.getDirectory(), meta2.getDirectory());
+    assertEquals(meta1.getPrefix(), meta2.getPrefix());
   }
 
   private GroupByMeta generateTestMeta() {
