@@ -17,6 +17,8 @@
 
 package org.apache.hop.pipeline.transforms.javascript;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.verify;
@@ -27,17 +29,16 @@ import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.engines.local.LocalPipelineEngine;
 import org.apache.hop.workflow.Workflow;
 import org.apache.hop.workflow.engines.local.LocalWorkflowEngine;
-import org.junit.Assert;
-import org.junit.Ignore;
-import org.junit.Test;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 
-public class ScriptValueAddFunctions_SetVariableScopeTest {
+class ScriptValueAddFunctions_SetVariableScopeTest {
   private static final String VARIABLE_NAME = "variable-name";
   private static final String VARIABLE_VALUE = "variable-value";
   protected ILogChannel log = new LogChannel("junit");
 
   @Test
-  public void setParentScopeVariable_ParentIsPipeline() {
+  void setParentScopeVariable_ParentIsPipeline() {
     Pipeline parent = createPipeline();
     Pipeline child = createPipeline(parent);
 
@@ -48,7 +49,7 @@ public class ScriptValueAddFunctions_SetVariableScopeTest {
   }
 
   @Test
-  public void setParentScopeVariable_ParentIsJob() {
+  void setParentScopeVariable_ParentIsJob() {
     Workflow parent = createWorkflow();
     Pipeline child = createPipeline(parent);
 
@@ -59,7 +60,7 @@ public class ScriptValueAddFunctions_SetVariableScopeTest {
   }
 
   @Test
-  public void setParentScopeVariable_NoParent() {
+  void setParentScopeVariable_NoParent() {
     Pipeline pipeline = createPipeline();
 
     ScriptValuesAddedFunctions.setParentScopeVariable(pipeline, VARIABLE_NAME, VARIABLE_VALUE);
@@ -68,7 +69,7 @@ public class ScriptValueAddFunctions_SetVariableScopeTest {
   }
 
   @Test
-  public void setGrandParentScopeVariable_TwoLevelHierarchy() {
+  void setGrandParentScopeVariable_TwoLevelHierarchy() {
     Pipeline parent = createPipeline();
     Pipeline child = createPipeline(parent);
 
@@ -79,7 +80,7 @@ public class ScriptValueAddFunctions_SetVariableScopeTest {
   }
 
   @Test
-  public void setGrandParentScopeVariable_ThreeLevelHierarchy() {
+  void setGrandParentScopeVariable_ThreeLevelHierarchy() {
     Workflow grandParent = createWorkflow();
     Pipeline parent = createPipeline(grandParent);
     Pipeline child = createPipeline(parent);
@@ -92,7 +93,7 @@ public class ScriptValueAddFunctions_SetVariableScopeTest {
   }
 
   @Test
-  public void setGrandParentScopeVariable_FourLevelHierarchy() {
+  void setGrandParentScopeVariable_FourLevelHierarchy() {
     Workflow grandGrandParent = createWorkflow();
     Pipeline grandParent = createPipeline(grandGrandParent);
     Pipeline parent = createPipeline(grandParent);
@@ -107,7 +108,7 @@ public class ScriptValueAddFunctions_SetVariableScopeTest {
   }
 
   @Test
-  public void setGrandParentScopeVariable_NoParent() {
+  void setGrandParentScopeVariable_NoParent() {
     Pipeline pipeline = createPipeline();
 
     ScriptValuesAddedFunctions.setGrandParentScopeVariable(pipeline, VARIABLE_NAME, VARIABLE_VALUE);
@@ -116,8 +117,8 @@ public class ScriptValueAddFunctions_SetVariableScopeTest {
   }
 
   @Test
-  @Ignore("This test needs to be reviewed")
-  public void setRootScopeVariable_TwoLevelHierarchy() {
+  @Disabled("This test needs to be reviewed")
+  void setRootScopeVariable_TwoLevelHierarchy() {
     Pipeline parent = createPipeline();
     Pipeline child = createPipeline(parent);
 
@@ -128,7 +129,7 @@ public class ScriptValueAddFunctions_SetVariableScopeTest {
   }
 
   @Test
-  public void setRootScopeVariable_FourLevelHierarchy() {
+  void setRootScopeVariable_FourLevelHierarchy() {
     Workflow grandGrandParent = createWorkflow();
     Pipeline grandParent = createPipeline(grandGrandParent);
     Pipeline parent = createPipeline(grandParent);
@@ -143,7 +144,7 @@ public class ScriptValueAddFunctions_SetVariableScopeTest {
   }
 
   @Test
-  public void setRootScopeVariable_NoParent() {
+  void setRootScopeVariable_NoParent() {
     Pipeline pipeline = createPipeline();
 
     ScriptValuesAddedFunctions.setRootScopeVariable(pipeline, VARIABLE_NAME, VARIABLE_VALUE);
@@ -152,15 +153,15 @@ public class ScriptValueAddFunctions_SetVariableScopeTest {
   }
 
   @Test
-  public void setSystemScopeVariable_NoParent() {
+  void setSystemScopeVariable_NoParent() {
     Pipeline pipeline = createPipeline();
 
-    Assert.assertNull(System.getProperty(VARIABLE_NAME));
+    assertNull(System.getProperty(VARIABLE_NAME));
 
     try {
       ScriptValuesAddedFunctions.setSystemScopeVariable(pipeline, VARIABLE_NAME, VARIABLE_VALUE);
 
-      Assert.assertEquals(VARIABLE_VALUE, System.getProperty(VARIABLE_NAME));
+      assertEquals(VARIABLE_VALUE, System.getProperty(VARIABLE_NAME));
       verify(pipeline).setVariable(VARIABLE_NAME, VARIABLE_VALUE);
     } finally {
       System.clearProperty(VARIABLE_NAME);
@@ -168,18 +169,18 @@ public class ScriptValueAddFunctions_SetVariableScopeTest {
   }
 
   @Test
-  public void setSystemScopeVariable_FourLevelHierarchy() {
+  void setSystemScopeVariable_FourLevelHierarchy() {
     Workflow grandGrandParent = createWorkflow();
     Pipeline grandParent = createPipeline(grandGrandParent);
     Pipeline parent = createPipeline(grandParent);
     Pipeline child = createPipeline(parent);
 
-    Assert.assertNull(System.getProperty(VARIABLE_NAME));
+    assertNull(System.getProperty(VARIABLE_NAME));
 
     try {
       ScriptValuesAddedFunctions.setSystemScopeVariable(child, VARIABLE_NAME, VARIABLE_VALUE);
 
-      Assert.assertEquals(VARIABLE_VALUE, System.getProperty(VARIABLE_NAME));
+      assertEquals(VARIABLE_VALUE, System.getProperty(VARIABLE_NAME));
 
       verify(child).setVariable(VARIABLE_NAME, VARIABLE_VALUE);
       verify(parent).setVariable(VARIABLE_NAME, VARIABLE_VALUE);
