@@ -16,22 +16,23 @@
  */
 package org.apache.hop.pipeline.transforms.joinrows;
 
-import org.apache.hop.core.injection.BaseMetadataInjectionTest;
-import org.apache.hop.junit.rules.RestoreHopEngineEnvironment;
-import org.junit.Before;
-import org.junit.ClassRule;
-import org.junit.Test;
+import org.apache.hop.core.injection.BaseMetadataInjectionTestJunit5;
+import org.apache.hop.junit.rules.RestoreHopEngineEnvironmentExtension;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.RegisterExtension;
 
-public class JoinRowsMetaInjectionTest extends BaseMetadataInjectionTest<JoinRowsMeta> {
-  @ClassRule public static RestoreHopEngineEnvironment env = new RestoreHopEngineEnvironment();
+class JoinRowsMetaInjectionTest extends BaseMetadataInjectionTestJunit5<JoinRowsMeta> {
+  @RegisterExtension
+  static RestoreHopEngineEnvironmentExtension env = new RestoreHopEngineEnvironmentExtension();
 
-  @Before
-  public void setup() throws Exception {
+  @BeforeEach
+  void setup() throws Exception {
     setup(new JoinRowsMeta());
   }
 
   @Test
-  public void test() throws Exception {
+  void test() throws Exception {
     check("TEMP_DIR", () -> meta.getDirectory());
     check("TEMP_FILE_PREFIX", () -> meta.getPrefix());
     check("MAX_CACHE_SIZE", () -> meta.getCacheSize());
