@@ -1541,7 +1541,11 @@ public class JsonInputDialog extends BaseTransformDialog {
     while (iterator.hasNext()) {
       String string = iterator.next();
       if (string != null) {
-        path.append(".").append(string);
+        if (string.contains(".")) {
+          path.append("['").append(string).append("']");
+        } else {
+          path.append(".").append(string);
+        }
       }
     }
     paths.add(path.toString());
@@ -1553,10 +1557,6 @@ public class JsonInputDialog extends BaseTransformDialog {
       JsonInputMeta oneMeta = new JsonInputMeta();
       getInfo(oneMeta);
 
-      PipelineMeta previewMeta =
-          PipelinePreviewFactory.generatePreviewPipeline(
-              metadataProvider, oneMeta, wTransformName.getText());
-
       EnterNumberDialog numberDialog =
           new EnterNumberDialog(
               shell,
@@ -1566,6 +1566,11 @@ public class JsonInputDialog extends BaseTransformDialog {
 
       int previewSize = numberDialog.open();
       if (previewSize > 0) {
+        oneMeta.setRowLimit(previewSize);
+        PipelineMeta previewMeta =
+            PipelinePreviewFactory.generatePreviewPipeline(
+                pipelineMeta.getMetadataProvider(), oneMeta, wTransformName.getText());
+
         PipelinePreviewProgressDialog progressDialog =
             new PipelinePreviewProgressDialog(
                 shell,
