@@ -1093,7 +1093,7 @@ public class JsonOutputDialog extends BaseTransformDialog {
     jsometa.setJsonPrittified(wJSONPrittified.getSelection());
     jsometa.setSplitOutputAfter(
         Integer.parseInt(
-            wSplitOutputAfter.getText().length() == 0 ? "0" : wSplitOutputAfter.getText()));
+            wSplitOutputAfter.getText().isEmpty() ? "0" : wSplitOutputAfter.getText()));
     jsometa.setCreateParentFolder(wCreateParentFolder.getSelection());
     jsometa.setFileName(wFilename.getText());
     jsometa.setExtension(wExtension.getText());
@@ -1184,27 +1184,25 @@ public class JsonOutputDialog extends BaseTransformDialog {
             5,
             6,
             (tableItem, v) -> {
-              if (v.isNumber()) {
-                if (v.getLength() > 0) {
-                  int le = v.getLength();
-                  int pr = v.getPrecision();
+              if (v.isNumber() && v.getLength() > 0) {
+                int le = v.getLength();
+                int pr = v.getPrecision();
 
-                  if (v.getPrecision() <= 0) {
-                    pr = 0;
-                  }
-
-                  String mask = " ";
-                  for (int m = 0; m < le - pr; m++) {
-                    mask += "0";
-                  }
-                  if (pr > 0) {
-                    mask += ".";
-                  }
-                  for (int m = 0; m < pr; m++) {
-                    mask += "0";
-                  }
-                  tableItem.setText(4, mask);
+                if (v.getPrecision() <= 0) {
+                  pr = 0;
                 }
+
+                String mask = " ";
+                for (int m = 0; m < le - pr; m++) {
+                  mask += "0";
+                }
+                if (pr > 0) {
+                  mask += ".";
+                }
+                for (int m = 0; m < pr; m++) {
+                  mask += "0";
+                }
+                tableItem.setText(4, mask);
               }
               return true;
             });
