@@ -24,7 +24,7 @@ import org.apache.hop.i18n.BaseMessages;
 
 /** Describes an LDAP Input */
 public class LdapInputField implements Cloneable {
-  private static final Class<?> PKG = LdapInputMeta.class; // For Translator
+  private static final Class<?> PKG = LdapInputMeta.class;
 
   public static final String ATTRIBUTE_OBJECT_SID = "objectSid";
 
@@ -352,7 +352,7 @@ public class LdapInputField implements Cloneable {
     binaryAttributes.add("certificateRevocationList");
     binaryAttributes.add("crossCertificatePair");
     binaryAttributes.add("x500UniqueIdentifier");
-    binaryAttributes.add("objectSid");
+    binaryAttributes.add(ATTRIBUTE_OBJECT_SID);
     binaryAttributes.add("objectGUID");
     binaryAttributes.add("GUID");
   }
