@@ -761,44 +761,44 @@ public class LoadFileInputMeta extends BaseTransformMeta<LoadFileInput, LoadFile
     }
     // Add additional fields
 
-    if (getShortFileNameField() != null && getShortFileNameField().length() > 0) {
+    if (!Utils.isEmpty(getShortFileNameField())) {
       IValueMeta v = new ValueMetaString(variables.resolve(getShortFileNameField()));
       v.setLength(100, -1);
       v.setOrigin(name);
       r.addValueMeta(v);
     }
-    if (getExtensionField() != null && getExtensionField().length() > 0) {
+    if (!Utils.isEmpty(getExtensionField())) {
       IValueMeta v = new ValueMetaString(variables.resolve(getExtensionField()));
       v.setLength(100, -1);
       v.setOrigin(name);
       r.addValueMeta(v);
     }
-    if (getPathField() != null && getPathField().length() > 0) {
+    if (!Utils.isEmpty(getPathField())) {
       IValueMeta v = new ValueMetaString(variables.resolve(getPathField()));
       v.setLength(100, -1);
       v.setOrigin(name);
       r.addValueMeta(v);
     }
 
-    if (isHiddenField() != null && isHiddenField().length() > 0) {
+    if (!Utils.isEmpty(isHiddenField())) {
       IValueMeta v = new ValueMetaBoolean(variables.resolve(isHiddenField()));
       v.setOrigin(name);
       r.addValueMeta(v);
     }
 
-    if (getLastModificationDateField() != null && getLastModificationDateField().length() > 0) {
+    if (!Utils.isEmpty(getLastModificationDateField())) {
       IValueMeta v = new ValueMetaDate(variables.resolve(getLastModificationDateField()));
       v.setOrigin(name);
       r.addValueMeta(v);
     }
-    if (getUriField() != null && getUriField().length() > 0) {
+    if (!Utils.isEmpty(getUriField())) {
       IValueMeta v = new ValueMetaString(variables.resolve(getUriField()));
       v.setLength(100, -1);
       v.setOrigin(name);
       r.addValueMeta(v);
     }
 
-    if (getRootUriField() != null && getRootUriField().length() > 0) {
+    if (!Utils.isEmpty(getRootUriField())) {
       IValueMeta v = new ValueMetaString(variables.resolve(getRootUriField()));
       v.setLength(100, -1);
       v.setOrigin(name);
