@@ -23,8 +23,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.widget.ColumnInfo;
@@ -42,17 +40,20 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.TableItem;
 import org.eclipse.swt.widgets.Text;
 
-public class MappingInputDialog extends BaseTransformDialog implements ITransformDialog {
-  private static final Class<?> PKG = MappingInputMeta.class; // For Translator
+public class MappingInputDialog extends BaseTransformDialog {
+  private static final Class<?> PKG = MappingInputMeta.class;
 
   private TableView wFields;
 
   private MappingInputMeta input;
 
   public MappingInputDialog(
-      Shell parent, IVariables variables, Object in, PipelineMeta tr, String sname) {
-    super(parent, variables, (BaseTransformMeta) in, tr, sname);
-    input = (MappingInputMeta) in;
+      Shell parent,
+      IVariables variables,
+      MappingInputMeta transformMeta,
+      PipelineMeta pipelineMeta) {
+    super(parent, variables, transformMeta, pipelineMeta);
+    input = transformMeta;
   }
 
   @Override
@@ -80,7 +81,7 @@ public class MappingInputDialog extends BaseTransformDialog implements ITransfor
     shell.setText(BaseMessages.getString(PKG, "MappingInputDialog.Shell.Title"));
 
     int middle = props.getMiddlePct();
-    int margin = props.getMargin();
+    int margin = PropsUi.getMargin();
 
     // TransformName line
     wlTransformName = new Label(shell, SWT.RIGHT);
