@@ -33,14 +33,13 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.config.PipelineRunConfiguration;
 import org.apache.hop.pipeline.engines.local.LocalPipelineRunConfiguration;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.ui.core.ConstUi;
 import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.dialog.EnterMappingDialog;
 import org.apache.hop.ui.core.dialog.ErrorDialog;
+import org.apache.hop.ui.core.dialog.MessageBox;
 import org.apache.hop.ui.core.gui.GuiResource;
 import org.apache.hop.ui.core.widget.ColumnInfo;
 import org.apache.hop.ui.core.widget.ColumnsResizer;
@@ -49,6 +48,7 @@ import org.apache.hop.ui.core.widget.TableView;
 import org.apache.hop.ui.core.widget.TextVar;
 import org.apache.hop.ui.hopgui.file.pipeline.HopPipelineFileType;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
+import org.apache.hop.ui.pipeline.transform.ITableItemInsertListener;
 import org.apache.hop.ui.util.SwtSvgImageUtil;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.CTabFolder;
@@ -67,10 +67,10 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.TableItem;
 import org.eclipse.swt.widgets.Text;
 
-public class SimpleMappingDialog extends BaseTransformDialog implements ITransformDialog {
-  private static final Class<?> PKG = SimpleMappingMeta.class; // For Translator
+public class SimpleMappingDialog extends BaseTransformDialog {
+  private static final Class<?> PKG = SimpleMappingMeta.class;
 
-  private SimpleMappingMeta mappingMeta;
+  private final SimpleMappingMeta mappingMeta;
 
   private TextVar wPath;
 
@@ -84,22 +84,22 @@ public class SimpleMappingDialog extends BaseTransformDialog implements ITransfo
 
   private ModifyListener lsMod;
 
-  private MappingParameters mappingParameters;
+  private final MappingParameters mappingParameters;
 
-  private MappingIODefinition inputMapping;
+  private final MappingIODefinition inputMapping;
 
-  private MappingIODefinition outputMapping;
+  private final MappingIODefinition outputMapping;
 
   private interface ApplyChanges {
-    public void applyChanges();
+    void applyChanges();
   }
 
   private class MappingParametersTab implements ApplyChanges {
-    private TableView wMappingParameters;
+    private final TableView wMappingParameters;
 
-    private MappingParameters parameters;
+    private final MappingParameters parameters;
 
-    private Button wInheritAll;
+    private final Button wInheritAll;
 
     public MappingParametersTab(
         TableView wMappingParameters, Button wInheritAll, MappingParameters parameters) {
@@ -122,9 +122,9 @@ public class SimpleMappingDialog extends BaseTransformDialog implements ITransfo
   }
 
   private class MappingDefinitionTab implements ApplyChanges {
-    private MappingIODefinition definition;
+    private final MappingIODefinition definition;
 
-    private TableView wFieldMappings;
+    private final TableView wFieldMappings;
 
     public MappingDefinitionTab(MappingIODefinition definition, TableView fieldMappings) {
       super();
@@ -145,12 +145,15 @@ public class SimpleMappingDialog extends BaseTransformDialog implements ITransfo
     }
   }
 
-  private List<ApplyChanges> changeList;
+  private final List<ApplyChanges> changeList;
 
   public SimpleMappingDialog(
-      Shell parent, IVariables variables, Object in, PipelineMeta tr, String sname) {
-    super(parent, variables, (BaseTransformMeta) in, tr, sname);
-    mappingMeta = (SimpleMappingMeta) in;
+      Shell parent,
+      IVariables variables,
+      SimpleMappingMeta transformMeta,
+      PipelineMeta pipelineMeta) {
+    super(parent, variables, transformMeta, pipelineMeta);
+    mappingMeta = transformMeta;
     transModified = false;
 
     // Make a copy for our own purposes...
@@ -158,9 +161,9 @@ public class SimpleMappingDialog extends BaseTransformDialog implements ITransfo
     // listeners.
     // Later we need to copy it to the input class on ok()
     //
-    mappingParameters = (MappingParameters) mappingMeta.getMappingParameters().clone();
-    inputMapping = (MappingIODefinition) mappingMeta.getInputMapping().clone();
-    outputMapping = (MappingIODefinition) mappingMeta.getOutputMapping().clone();
+    mappingParameters = mappingMeta.getMappingParameters().clone();
+    inputMapping = mappingMeta.getInputMapping().clone();
+    outputMapping = mappingMeta.getOutputMapping().clone();
 
     changeList = new ArrayList<>();
   }
@@ -181,7 +184,7 @@ public class SimpleMappingDialog extends BaseTransformDialog implements ITransfo
     formLayout.marginHeight = 15;
 
     int middle = props.getMiddlePct();
-    int margin = props.getMargin();
+    int margin = PropsUi.getMargin();
 
     shell.setLayout(formLayout);
     shell.setText(BaseMessages.getString(PKG, "SimpleMappingDialog.Shell.Title"));
@@ -361,15 +364,13 @@ public class SimpleMappingDialog extends BaseTransformDialog implements ITransfo
     addOutputMappingDefinitionTab(outputMapping, 1);
 
     // Prepare a regexp checker to see if the pipeline name contains a variable
-    // boolean containsVar = Pattern.matches("^[/\\w]*(\\$\\{\\w+})[/.\\w]*",
-    // mappingMeta.getFilename());
     Pattern p = Pattern.compile("^[/\\w]*(\\$\\{\\w+})[/.\\w]*");
     Matcher m = p.matcher(Const.NVL(mappingMeta.getFilename(), ""));
 
     if (!m.lookingAt()) {
       try {
         loadPipeline();
-      } catch (Throwable t) {
+      } catch (Exception e) {
         // Ignore errors
       }
     }
@@ -540,6 +541,10 @@ public class SimpleMappingDialog extends BaseTransformDialog implements ITransfo
     } else {
       // OUTPUT
       //
+      if (mappingPipelineMeta == null) {
+        throw new HopException(
+            BaseMessages.getString(PKG, "SimpleMappingDialog.Exception.NoMappingSpecified"));
+      }
       TransformMeta mappingOutputTransformMeta =
           mappingPipelineMeta.findMappingOutputTransform(null);
       return mappingPipelineMeta.getTransformFields(variables, mappingOutputTransformMeta);
@@ -557,9 +562,9 @@ public class SimpleMappingDialog extends BaseTransformDialog implements ITransfo
 
     final CTabItem wTab;
     if (index >= wTabFolder.getItemCount()) {
-      wTab = new CTabItem(wTabFolder, SWT.CLOSE);
+      wTab = new CTabItem(wTabFolder, SWT.NONE);
     } else {
-      wTab = new CTabItem(wTabFolder, SWT.CLOSE, index);
+      wTab = new CTabItem(wTabFolder, SWT.NONE, index);
     }
     wTab.setFont(GuiResource.getInstance().getFontDefault());
     setMappingDefinitionTabNameAndToolTip(wTab, tabTitle, tabTooltip, definition, input);
@@ -628,6 +633,7 @@ public class SimpleMappingDialog extends BaseTransformDialog implements ITransfo
           @Override
           public void widgetSelected(SelectionEvent arg0) {
             try {
+              loadPipeline();
               if (input) {
                 // INPUT
                 //
@@ -664,6 +670,11 @@ public class SimpleMappingDialog extends BaseTransformDialog implements ITransfo
               } else {
                 // OUTPUT
                 //
+                ITableItemInsertListener listener =
+                    (tableItem, v) -> {
+                      tableItem.setText(2, tableItem.getText((1)));
+                      return true;
+                    };
                 IRowMeta sourceRowMeta = getFieldsFromTransform(true, input);
                 BaseTransformDialog.getFieldsFromPrevious(
                     sourceRowMeta,
@@ -675,7 +686,7 @@ public class SimpleMappingDialog extends BaseTransformDialog implements ITransfo
                     new int[] {},
                     -1,
                     -1,
-                    null);
+                    listener);
               }
             } catch (HopException e) {
               new ErrorDialog(
@@ -768,8 +779,25 @@ public class SimpleMappingDialog extends BaseTransformDialog implements ITransfo
       return;
     }
 
+    if (Utils.isEmpty(wPath.getText())) {
+      MessageBox mb = new MessageBox(shell, SWT.OK | SWT.ICON_ERROR);
+      mb.setText(BaseMessages.getString(PKG, "SimpleMappingDialog.FilenameMissing.Header"));
+      mb.setMessage(BaseMessages.getString(PKG, "SimpleMappingDialog.FilenameMissing.Message"));
+      mb.open();
+      return;
+    }
+    if (isSelfReferencing()) {
+      MessageBox mb = new MessageBox(shell, SWT.OK | SWT.ICON_ERROR);
+      mb.setText(BaseMessages.getString(PKG, "SimpleMappingDialog.SelfReference.Header"));
+      mb.setMessage(BaseMessages.getString(PKG, "SimpleMappingDialog.SelfReference.Message"));
+      mb.open();
+      return;
+    }
+
     transformName = wTransformName.getText(); // return value
     String pipelinePath = wPath.getText();
+    mappingMeta.setFilename(pipelinePath);
+    mappingMeta.setRunConfigurationName(wRunConfig.getText());
     // Prepare a regexp checker to see if the pipeline name contains a variable
     Pattern p = Pattern.compile("^[/\\w]*(\\$\\{\\w+})[/.\\w]*");
     Matcher m = p.matcher(mappingMeta.getFilename());
@@ -788,9 +816,6 @@ public class SimpleMappingDialog extends BaseTransformDialog implements ITransfo
       }
     }
 
-    mappingMeta.setFilename(pipelinePath);
-    mappingMeta.setRunConfigurationName(wRunConfig.getText());
-
     // Load the information on the tabs, optionally do some
     // verifications...
     //
@@ -810,4 +835,8 @@ public class SimpleMappingDialog extends BaseTransformDialog implements ITransfo
       // tabs...
     }
   }
+
+  private boolean isSelfReferencing() {
+    return variables.resolve(wPath.getText()).equals(variables.resolve(pipelineMeta.getFilename()));
+  }
 }
