@@ -203,7 +203,7 @@ public class SimpleMappingMeta extends TransformWithMappingMeta<SimpleMapping, S
       IVariables variables,
       IHopMetadataProvider metadataProvider) {
     CheckResult cr;
-    if (prev == null || prev.size() == 0) {
+    if (prev == null || prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_WARNING,
