@@ -17,9 +17,9 @@
 
 package org.apache.hop.pipeline.transforms.memgroupby;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.anyInt;
 import static org.mockito.ArgumentMatchers.anyString;
@@ -39,15 +39,12 @@ import org.apache.hop.core.row.value.ValueMetaInteger;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
 import org.apache.hop.pipeline.transform.TransformMeta;
-import org.junit.AfterClass;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.mockito.MockedStatic;
 
-public class MemoryGroupByMetaGetFieldsTest {
+class MemoryGroupByMetaGetFieldsTest {
 
   private static MockedStatic<ValueMetaFactory> mockedValueMetaFactory;
 
@@ -59,18 +56,14 @@ public class MemoryGroupByMetaGetFieldsTest {
   private IVariables mockSpace;
   private IHopMetadataProvider mockIHopMetadataProvider;
 
-  @BeforeClass
-  public static void setUpBeforeClass() {
+  // Static mock is now managed at method level in @BeforeEach/@AfterEach
+
+  @BeforeEach
+  void setup() {
+    // Create static mock first
     mockedValueMetaFactory = mockStatic(ValueMetaFactory.class);
-  }
 
-  @AfterClass
-  public static void tearDownAfterClass() {
-    mockedValueMetaFactory.close();
-  }
-
-  @Before
-  public void setup() {
+    // Then set up other mocks
     mockSpace = mock(IVariables.class);
 
     doReturn("N").when(mockSpace).getVariable(any(), anyString());
@@ -96,18 +89,15 @@ public class MemoryGroupByMetaGetFieldsTest {
     mockedValueMetaFactory.when(() -> ValueMetaFactory.getValueMetaName(5)).thenReturn("Integer");
   }
 
-  @BeforeEach
-  void setUpStaticMocks() {
-    mockedValueMetaFactory = mockStatic(ValueMetaFactory.class);
-  }
-
   @AfterEach
-  void tearDownStaticMocks() {
-    mockedValueMetaFactory.closeOnDemand();
+  void tearDown() {
+    if (mockedValueMetaFactory != null) {
+      mockedValueMetaFactory.close();
+    }
   }
 
   @Test
-  public void getFieldsWithSubject_WithFormat() {
+  void getFieldsWithSubject_WithFormat() {
     ValueMetaDate valueMeta = new ValueMetaDate();
     valueMeta.setConversionMask("yyyy-MM-dd");
     valueMeta.setName("date");
@@ -132,7 +122,7 @@ public class MemoryGroupByMetaGetFieldsTest {
   }
 
   @Test
-  public void getFieldsWithSubject_NoFormat() {
+  void getFieldsWithSubject_NoFormat() {
     ValueMetaDate valueMeta = new ValueMetaDate();
     valueMeta.setName("date");
 
@@ -150,7 +140,7 @@ public class MemoryGroupByMetaGetFieldsTest {
   }
 
   @Test
-  public void getFieldsWithoutSubject() {
+  void getFieldsWithoutSubject() {
     ValueMetaDate valueMeta = new ValueMetaDate();
     valueMeta.setName("date");
 
