@@ -17,11 +17,11 @@
 
 package org.apache.hop.pipeline.transforms.mergejoin;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNotSame;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNotSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.Arrays;
 import java.util.HashMap;
@@ -36,7 +36,7 @@ import org.apache.hop.core.row.value.ValueMetaInteger;
 import org.apache.hop.core.row.value.ValueMetaString;
 import org.apache.hop.core.variables.Variables;
 import org.apache.hop.core.xml.XmlHandler;
-import org.apache.hop.junit.rules.RestoreHopEngineEnvironment;
+import org.apache.hop.junit.rules.RestoreHopEngineEnvironmentExtension;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.pipeline.transform.stream.IStream;
 import org.apache.hop.pipeline.transforms.loadsave.LoadSaveTester;
@@ -44,11 +44,12 @@ import org.apache.hop.pipeline.transforms.loadsave.validator.IFieldLoadSaveValid
 import org.apache.hop.pipeline.transforms.loadsave.validator.IFieldLoadSaveValidatorFactory;
 import org.apache.hop.pipeline.transforms.loadsave.validator.ListLoadSaveValidator;
 import org.apache.hop.pipeline.transforms.loadsave.validator.StringLoadSaveValidator;
-import org.junit.ClassRule;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.RegisterExtension;
 
-public class MergeJoinMetaTest {
-  @ClassRule public static RestoreHopEngineEnvironment env = new RestoreHopEngineEnvironment();
+class MergeJoinMetaTest {
+  @RegisterExtension
+  static RestoreHopEngineEnvironmentExtension env = new RestoreHopEngineEnvironmentExtension();
 
   LoadSaveTester loadSaveTester;
 
@@ -108,12 +109,12 @@ public class MergeJoinMetaTest {
   }
 
   @Test
-  public void testSerialization() throws HopException {
+  void testSerialization() throws HopException {
     loadSaveTester.testSerialization();
   }
 
   @Test
-  public void testGetFieldsEmptyInput() throws Exception {
+  void testGetFieldsEmptyInput() throws Exception {
     RowMeta outputRowMeta = new RowMeta();
     MergeJoinMeta meta = new MergeJoinMeta();
 
@@ -175,7 +176,7 @@ public class MergeJoinMetaTest {
   }
 
   @Test
-  public void cloneTest() throws Exception {
+  void cloneTest() throws Exception {
     MergeJoinMeta meta = new MergeJoinMeta();
     meta.setKeyFields1(Arrays.asList("kf1-1", "kf1-2"));
     meta.setKeyFields2(Arrays.asList("kf2-1", "kf2-2", "kf2-3"));
@@ -200,7 +201,7 @@ public class MergeJoinMetaTest {
   }
 
   @Test
-  public void testXmlRoundTrip() throws Exception {
+  void testXmlRoundTrip() throws Exception {
     MergeJoinMeta meta = new MergeJoinMeta();
     meta.setKeyFields1(Arrays.asList("id1"));
     meta.setKeyFields2(Arrays.asList("id2"));
@@ -219,7 +220,7 @@ public class MergeJoinMetaTest {
   }
 
   @Test
-  public void testGetFields() throws Exception {
+  void testGetFields() throws Exception {
     MergeJoinMeta meta = new MergeJoinMeta();
     meta.setKeyFields1(Arrays.asList("id1"));
     meta.setKeyFields2(Arrays.asList("id2"));
