@@ -31,6 +31,7 @@ import org.apache.hop.core.row.IValueMeta;
 import org.apache.hop.core.row.RowMeta;
 import org.apache.hop.core.row.value.ValueMetaFactory;
 import org.apache.hop.core.util.StringUtil;
+import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.variables.Variables;
 import org.apache.hop.i18n.BaseMessages;
@@ -525,8 +526,7 @@ public class MongoDbDeleteDialog extends BaseTransformDialog {
 
     getInfo(currentMeta);
 
-    if ((!currentMeta.isUseJsonQuery())
-        && (currentMeta.getMongoFields() == null || currentMeta.getMongoFields().isEmpty())) {
+    if ((!currentMeta.isUseJsonQuery()) && (Utils.isEmpty(currentMeta.getMongoFields()))) {
       // popup dialog warning that no paths have been defined
       showNoFieldMessageDialog();
     } else if (currentMeta.isUseJsonQuery() && StringUtil.isEmpty(currentMeta.getJsonQuery())) {
@@ -663,7 +663,7 @@ public class MongoDbDeleteDialog extends BaseTransformDialog {
 
     List<MongoDbDeleteField> mongoFields = currentMeta.getMongoFields();
 
-    if (mongoFields != null && !mongoFields.isEmpty()) {
+    if (!Utils.isEmpty(mongoFields)) {
       for (MongoDbDeleteField field : mongoFields) {
         TableItem item = new TableItem(wtvMongoFieldsView.table, SWT.NONE);
 
@@ -759,7 +759,7 @@ public class MongoDbDeleteDialog extends BaseTransformDialog {
   private void previewDocStruct() {
     List<MongoDbDeleteField> mongoFields = tableToMongoFieldList();
 
-    if (mongoFields == null || mongoFields.isEmpty()) {
+    if (Utils.isEmpty(mongoFields)) {
       // popup dialog warning that no paths have been defined
       showNoFieldMessageDialog();
       return;
@@ -870,8 +870,20 @@ public class MongoDbDeleteDialog extends BaseTransformDialog {
         case IValueMeta.TYPE_BINARY:
           val = "<binary val>";
           break;
+        case IValueMeta.TYPE_JSON:
+          val = "<JSON document>";
+          break;
         default:
-          val = "<unsupported value type>";
+          try {
+            int uuidTypeId = ValueMetaFactory.getIdForValueMeta("UUID");
+            if (rmi.getValueMeta(index).getType() == uuidTypeId) {
+              val = "<UUID val>";
+            } else {
+              val = "<unsupported value type>";
+            }
+          } catch (Exception ignore) {
+            // UUID plugin not present, fall through
+          }
       }
     } else {
       val = "<value>";
@@ -899,7 +911,7 @@ public class MongoDbDeleteDialog extends BaseTransformDialog {
     String source = toFormat.replaceAll("[ ]*,", ","); // $NON-NLS-1$ //$NON-NLS-2$
     Element next = Element.OPEN_BRACE;
 
-    while (source.length() > 0) {
+    while (!source.isEmpty()) {
       source = source.trim();
       String toIndent = ""; // $NON-NLS-1$
       int minIndex = Integer.MAX_VALUE;
@@ -942,15 +954,15 @@ public class MongoDbDeleteDialog extends BaseTransformDialog {
           offset = 2;
         }
         result.append(targetChar).append(comma).append("\n"); // $NON-NLS-1$
-        source = source.substring(offset, source.length());
+        source = source.substring(offset);
       } else {
         pad(result, indent);
         if (next == Element.CLOSE_BRACE || next == Element.CLOSE_BRACKET) {
           toIndent = source.substring(0, minIndex);
-          source = source.substring(minIndex, source.length());
+          source = source.substring(minIndex);
         } else {
           toIndent = source.substring(0, minIndex + 1);
-          source = source.substring(minIndex + 1, source.length());
+          source = source.substring(minIndex + 1);
         }
         result.append(toIndent.trim()).append("\n"); // $NON-NLS-1$
       }
