@@ -17,15 +17,15 @@
 
 package org.apache.hop.mongo;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.fail;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
-public class KerberosUtilTest {
+class KerberosUtilTest {
 
   @Test
-  public void testJaasAuthenticationMode() throws MongoDbException {
+  void testJaasAuthenticationMode() throws MongoDbException {
     assertEquals(
         KerberosUtil.JaasAuthenticationMode.EXTERNAL,
         KerberosUtil.JaasAuthenticationMode.byName("EXTERNAL"));
