@@ -31,13 +31,13 @@ import org.apache.hop.mongo.AuthContext;
 import org.apache.hop.mongo.MongoDbException;
 import org.apache.hop.mongo.MongoUtilLogger;
 import org.apache.hop.mongo.wrapper.collection.MongoCollectionWrapper;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 import org.mockito.invocation.InvocationOnMock;
 import org.mockito.stubbing.Answer;
 
-public class KerberosMongoClientWrapperTest {
+class KerberosMongoClientWrapperTest {
   @Test
-  public void testWrapProperlyWrapsCollection() throws MongoDbException, PrivilegedActionException {
+  void testWrapProperlyWrapsCollection() throws MongoDbException, PrivilegedActionException {
     MongoClient client = mock(MongoClient.class);
     AuthContext authContext = mock(AuthContext.class);
     MongoUtilLogger log = mock(MongoUtilLogger.class);
