@@ -16,8 +16,8 @@
  */
 package org.apache.hop.mongo.wrapper.collection;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.anyList;
 import static org.mockito.Mockito.mock;
@@ -34,12 +34,12 @@ import java.util.ArrayList;
 import java.util.List;
 import org.apache.hop.mongo.MongoDbException;
 import org.apache.hop.mongo.wrapper.cursor.MongoCursorWrapper;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.mockito.Mock;
 import org.mockito.MockitoAnnotations;
 
-public class DefaultMongoCollectionWrapperTest {
+class DefaultMongoCollectionWrapperTest {
 
   private DefaultMongoCollectionWrapper defaultMongoCollectionWrapper;
   @Mock private DBCollection mockDBCollection;
@@ -48,20 +48,20 @@ public class DefaultMongoCollectionWrapperTest {
 
   private DBObject[] dbObjectArray = new DBObject[0];
 
-  @Before
-  public void setUp() {
+  @BeforeEach
+  void setUp() {
     MockitoAnnotations.openMocks(this);
     defaultMongoCollectionWrapper = new DefaultMongoCollectionWrapper(mockDBCollection);
   }
 
   @Test
-  public void testRemove() throws Exception {
+  void testRemove() throws Exception {
     defaultMongoCollectionWrapper.remove();
     verify(mockDBCollection, times(1)).remove(new BasicDBObject());
   }
 
   @Test
-  public void testCreateIndex() throws Exception {
+  void testCreateIndex() throws Exception {
     BasicDBObject index = mock(BasicDBObject.class);
     BasicDBObject options = mock(BasicDBObject.class);
     defaultMongoCollectionWrapper.createIndex(index, options);
@@ -69,7 +69,7 @@ public class DefaultMongoCollectionWrapperTest {
   }
 
   @Test
-  public void testPassThroughMethods() throws MongoDbException {
+  void testPassThroughMethods() throws MongoDbException {
     // Setup aggregate to use MongoDB Cursor method instead
     AggregationOptions options = AggregationOptions.builder().build();
     List<DBObject> pipeline = new ArrayList<>(); // can be empty
@@ -95,7 +95,7 @@ public class DefaultMongoCollectionWrapperTest {
   }
 
   @Test
-  public void testAggregate() {
+  void testAggregate() {
     Cursor mockCursor = mock(Cursor.class);
     when(mockDBCollection.aggregate(anyList(), any(AggregationOptions.class)))
         .thenReturn(mockCursor);
@@ -104,7 +104,7 @@ public class DefaultMongoCollectionWrapperTest {
   }
 
   @Test
-  public void testFindWrapsCursor() throws MongoDbException {
+  void testFindWrapsCursor() throws MongoDbException {
     assertTrue(defaultMongoCollectionWrapper.find() instanceof MongoCursorWrapper);
     verify(mockDBCollection).find();
     assertTrue(
