@@ -17,10 +17,10 @@
 
 package org.apache.hop.pipeline.transforms.mongodbinput;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.Mockito.any;
 import static org.mockito.Mockito.anyBoolean;
 import static org.mockito.Mockito.anyInt;
@@ -45,10 +45,10 @@ import org.apache.hop.core.variables.Variables;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
 import org.apache.hop.mongo.metadata.MongoDbConnection;
 import org.apache.hop.mongo.wrapper.field.MongoField;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
-public class MongoDbInputDataTest {
+class MongoDbInputDataTest {
   private IHopMetadataProvider metadataProvider;
 
   protected static String sTestData =
@@ -61,14 +61,14 @@ public class MongoDbInputDataTest {
           + "{ \"rec1\" : { \"f1\" : \"sid\", \"f2\" : \"zaphod\" } } ] }, "
           + "\"name\" : \"george\", \"aNumber\" : \"Forty two\" }";
 
-  @Before
-  public void setUp() throws HopException {
+  @BeforeEach
+  void setUp() throws HopException {
     HopClientEnvironment.init();
     metadataProvider = mock(IHopMetadataProvider.class);
   }
 
   @Test
-  public void testDiscoverFieldsThrowsException() throws Exception {
+  void testDiscoverFieldsThrowsException() throws Exception {
     String dbName = "testDb";
     String collection = "testCollection";
     String query = "testQuery";
@@ -112,7 +112,7 @@ public class MongoDbInputDataTest {
   }
 
   @Test
-  public void testDiscoverFieldsWithoutCallbackThrowsHopException() throws Exception {
+  void testDiscoverFieldsWithoutCallbackThrowsHopException() throws Exception {
     String dbName = "testDb";
     String collection = "testCollection";
     String query = "testQuery";
@@ -153,7 +153,7 @@ public class MongoDbInputDataTest {
   }
 
   @Test
-  public void testDiscoverFieldsWithoutCallbackThrowsException() throws Exception {
+  void testDiscoverFieldsWithoutCallbackThrowsException() throws Exception {
     String dbName = "testDb";
     String collection = "testCollection";
     String query = "testQuery";
@@ -194,7 +194,7 @@ public class MongoDbInputDataTest {
   }
 
   @Test
-  public void testGetNonExistentField() throws HopException {
+  void testGetNonExistentField() throws HopException {
     Object mongoO = BasicDBObject.parse(sTestData);
     assertTrue(mongoO instanceof DBObject);
 
@@ -225,7 +225,7 @@ public class MongoDbInputDataTest {
   }
 
   @Test
-  public void testArrayUnwindArrayFieldsOnly() throws HopException {
+  void testArrayUnwindArrayFieldsOnly() throws HopException {
     Object mongoO = BasicDBObject.parse(sTestData2);
     assertTrue(mongoO instanceof DBObject);
 
@@ -263,7 +263,7 @@ public class MongoDbInputDataTest {
   }
 
   @Test
-  public void testArrayUnwindOneArrayExpandFieldAndOneNormalField() throws HopException {
+  void testArrayUnwindOneArrayExpandFieldAndOneNormalField() throws HopException {
     Object mongoO = BasicDBObject.parse(sTestData2);
     assertTrue(mongoO instanceof DBObject);
 
@@ -314,7 +314,7 @@ public class MongoDbInputDataTest {
   }
 
   @Test
-  public void testArrayUnwindWithOneExistingAndOneNonExistingField() throws HopException {
+  void testArrayUnwindWithOneExistingAndOneNonExistingField() throws HopException {
     Object mongoO = BasicDBObject.parse(sTestData2);
     assertTrue(mongoO instanceof DBObject);
 
@@ -365,7 +365,7 @@ public class MongoDbInputDataTest {
   }
 
   @Test
-  public void testCleansePath() {
+  void testCleansePath() {
     // param at end of path
     assertEquals(
         "my.path.with.${a_dot_param}", MongoDbInputData.cleansePath("my.path.with.${a.dot.param}"));
