@@ -18,7 +18,6 @@
 package org.apache.hop.pipeline.transforms.multimerge;
 
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.List;
 import org.apache.hop.core.Const;
 import org.apache.hop.core.exception.HopException;
@@ -88,11 +87,7 @@ public class MultiMergeJoinDialog extends BaseTransformDialog {
   }
 
   private String[] getInputTransformNames() {
-    String[] inputTransformNames = joinMeta.getInputTransforms();
     ArrayList<String> nameList = new ArrayList<>();
-    if (inputTransformNames != null) {
-      Collections.addAll(nameList, inputTransformNames);
-    }
 
     String[] prevTransformNames = pipelineMeta.getPrevTransformNames(transformName);
     if (prevTransformNames != null) {
@@ -106,7 +101,8 @@ public class MultiMergeJoinDialog extends BaseTransformDialog {
       }
     }
 
-    return nameList.toArray(new String[nameList.size()]);
+    joinMeta.setInputTransforms(nameList.toArray(new String[0]));
+    return nameList.toArray(new String[0]);
   }
 
   /*
@@ -432,7 +428,7 @@ public class MultiMergeJoinDialog extends BaseTransformDialog {
       }
 
       String joinType = joinMeta.getJoinType();
-      if (joinType != null && joinType.length() > 0) {
+      if (!Utils.isEmpty(joinType)) {
         joinTypeCombo.setText(joinType);
       } else {
         joinTypeCombo.setText(MultiMergeJoinMeta.joinTypes[0]);
