@@ -125,7 +125,7 @@ public class NumberRangeMeta extends BaseTransformMeta<NumberRange, NumberRangeD
       IVariables variables,
       IHopMetadataProvider metadataProvider) {
     CheckResult cr;
-    if (prev == null || prev.size() == 0) {
+    if (prev == null || prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_WARNING,
