@@ -23,8 +23,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.dialog.ErrorDialog;
@@ -48,8 +46,8 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
-public class PGPDecryptStreamDialog extends BaseTransformDialog implements ITransformDialog {
-  private static final Class<?> PKG = PGPDecryptStreamMeta.class; // For Translator
+public class PGPDecryptStreamDialog extends BaseTransformDialog {
+  private static final Class<?> PKG = PGPDecryptStreamMeta.class;
   private boolean gotPreviousFields = false;
 
   private TextVar wGPGLocation;
@@ -72,9 +70,12 @@ public class PGPDecryptStreamDialog extends BaseTransformDialog implements ITran
       new String[] {BaseMessages.getString(PKG, "PGPDecryptStreamDialog.Filetype.All")};
 
   public PGPDecryptStreamDialog(
-      Shell parent, IVariables variables, Object in, PipelineMeta pipelineMeta, String sname) {
-    super(parent, variables, (BaseTransformMeta) in, pipelineMeta, sname);
-    input = (PGPDecryptStreamMeta) in;
+      Shell parent,
+      IVariables variables,
+      PGPDecryptStreamMeta transformMeta,
+      PipelineMeta pipelineMeta) {
+    super(parent, variables, transformMeta, pipelineMeta);
+    input = transformMeta;
   }
 
   @Override
@@ -97,7 +98,7 @@ public class PGPDecryptStreamDialog extends BaseTransformDialog implements ITran
     shell.setText(BaseMessages.getString(PKG, "PGPDecryptStreamDialog.Shell.Title"));
 
     int middle = props.getMiddlePct();
-    int margin = props.getMargin();
+    int margin = PropsUi.getMargin();
 
     // TransformName line
     wlTransformName = new Label(shell, SWT.RIGHT);
@@ -222,7 +223,7 @@ public class PGPDecryptStreamDialog extends BaseTransformDialog implements ITran
         new SelectionAdapter() {
           @Override
           public void widgetSelected(SelectionEvent e) {
-            PassphraseFromField();
+            passphraseFromField();
           }
         });
 
@@ -248,7 +249,9 @@ public class PGPDecryptStreamDialog extends BaseTransformDialog implements ITran
     wPassphraseFieldName.addFocusListener(
         new FocusListener() {
           @Override
-          public void focusLost(FocusEvent e) {}
+          public void focusLost(FocusEvent e) {
+            // Do nothing
+          }
 
           @Override
           public void focusGained(FocusEvent e) {
@@ -292,7 +295,9 @@ public class PGPDecryptStreamDialog extends BaseTransformDialog implements ITran
     wStreamFieldName.addFocusListener(
         new FocusListener() {
           @Override
-          public void focusLost(FocusEvent e) {}
+          public void focusLost(FocusEvent e) {
+            // Do nothing
+          }
 
           @Override
           public void focusGained(FocusEvent e) {
@@ -335,7 +340,7 @@ public class PGPDecryptStreamDialog extends BaseTransformDialog implements ITran
     setButtonPositions(new Button[] {wOk, wCancel}, margin, wResult);
 
     getData();
-    PassphraseFromField();
+    passphraseFromField();
     input.setChanged(changed);
 
     BaseDialog.defaultShellHandling(shell, c -> ok(), c -> cancel());
@@ -387,7 +392,7 @@ public class PGPDecryptStreamDialog extends BaseTransformDialog implements ITran
     dispose();
   }
 
-  private void PassphraseFromField() {
+  private void passphraseFromField() {
     wlPassphrase.setEnabled(!wPassphraseFromField.getSelection());
     wPassphrase.setEnabled(!wPassphraseFromField.getSelection());
     wlPassphraseFromField.setEnabled(wPassphraseFromField.getSelection());
