@@ -59,7 +59,7 @@ import org.apache.hop.resource.ResourceDefinition;
     keywords = "i18n::PropertyInputMeta.keyword",
     documentationUrl = "/pipeline/transforms/propertyinput.html")
 public class PropertyInputMeta extends BaseTransformMeta<PropertyInput, PropertyInputData> {
-  private static final Class<?> PKG = PropertyInputMeta.class; // For Translator
+  private static final Class<?> PKG = PropertyInputMeta.class;
 
   public static final String[] RequiredFilesDesc =
       new String[] {
@@ -400,7 +400,7 @@ public class PropertyInputMeta extends BaseTransformMeta<PropertyInput, Property
 
     FileInputList fileInputList = getFiles(variables);
 
-    if (fileInputList == null || fileInputList.getFiles().size() == 0) {
+    if (fileInputList == null || fileInputList.getFiles().isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_ERROR,
