@@ -16,17 +16,18 @@
  */
 package org.apache.hop.pipeline.transforms.propertyinput;
 
-import org.apache.hop.junit.rules.RestoreHopEngineEnvironment;
+import org.apache.hop.junit.rules.RestoreHopEngineEnvironmentExtension;
 import org.apache.hop.pipeline.transforms.propertyinput.PropertyInputMeta.KeyValue;
 import org.apache.hop.pipeline.transforms.propertyinput.PropertyInputMeta.PIField;
-import org.junit.ClassRule;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.RegisterExtension;
 
-public class PropertyInputContentParsingTest extends BasePropertyParsingTest {
-  @ClassRule public static RestoreHopEngineEnvironment env = new RestoreHopEngineEnvironment();
+class PropertyInputContentParsingTest extends BasePropertyParsingTest {
+  @RegisterExtension
+  static RestoreHopEngineEnvironmentExtension env = new RestoreHopEngineEnvironmentExtension();
 
   @Test
-  public void testDefaultOptions() throws Exception {
+  void testDefaultOptions() throws Exception {
     init("default.properties");
 
     PIField f1 = new PIField("f1");
