@@ -107,7 +107,7 @@ public class ReservoirSamplingMeta
 
     CheckResult cr;
 
-    if ((prev == null) || (prev.size() == 0)) {
+    if ((prev == null) || (prev.isEmpty())) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_WARNING,
