@@ -18,34 +18,24 @@
 package org.apache.hop.pipeline.transforms.rest;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.mockito.ArgumentMatchers.any;
-import static org.mockito.Mockito.doCallRealMethod;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.mockStatic;
-import static org.mockito.Mockito.nullable;
 import static org.mockito.Mockito.spy;
-import static org.mockito.Mockito.times;
-import static org.mockito.Mockito.verify;
 
-import javax.ws.rs.client.Client;
-import javax.ws.rs.client.Invocation;
-import javax.ws.rs.client.WebTarget;
-import javax.ws.rs.core.MultivaluedHashMap;
-import javax.ws.rs.core.MultivaluedMap;
-import javax.ws.rs.core.Response;
-import org.apache.hop.core.exception.HopException;
-import org.apache.hop.core.row.IRowMeta;
+import jakarta.ws.rs.client.Client;
+import jakarta.ws.rs.core.MultivaluedHashMap;
+import jakarta.ws.rs.core.MultivaluedMap;
+import jakarta.ws.rs.core.Response;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.engines.local.LocalPipelineEngine;
 import org.apache.hop.pipeline.transform.TransformMeta;
-import org.glassfish.jersey.client.ClientResponse;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Disabled;
 import org.junit.jupiter.api.Test;
-import org.mockito.Answers;
 import org.mockito.MockedStatic;
 
 class RestTest {
@@ -63,6 +53,7 @@ class RestTest {
   }
 
   @Test
+  @SuppressWarnings("unchecked")
   void testCreateMultivalueMap() {
     TransformMeta transformMeta = new TransformMeta();
     transformMeta.setName("TestRest");
@@ -77,54 +68,71 @@ class RestTest {
             1,
             pipelineMeta,
             spy(new LocalPipelineEngine()));
-    MultivaluedHashMap map = rest.createMultivalueMap("param1", "{a:{[val1]}}");
+    MultivaluedHashMap<String, String> map = rest.createMultivalueMap("param1", "{a:{[val1]}}");
     String val1 = map.getFirst("param1").toString();
     assertTrue(val1.contains("%7D"));
   }
 
-  @Disabled("This test needs to be reviewed")
   @Test
-  void testCallEndpointWithDeleteVerb() throws HopException {
-    MultivaluedMap<String, String> headers = null;
-    headers.add("Content-Type", "application/json");
+  void testSearchForHeaders() {
+    TransformMeta transformMeta = new TransformMeta();
+    transformMeta.setName("TestRest");
+    PipelineMeta pipelineMeta = new PipelineMeta();
+    pipelineMeta.setName("TestRest");
+    pipelineMeta.addTransform(transformMeta);
+
+    Rest rest =
+        new Rest(
+            transformMeta,
+            mock(RestMeta.class),
+            mock(RestData.class),
+            1,
+            pipelineMeta,
+            spy(new LocalPipelineEngine()));
 
     Response response = mock(Response.class);
-    doReturn(200).when(response).getStatus();
+    MultivaluedHashMap<String, Object> headers = new MultivaluedHashMap<>();
+    headers.add("Content-Type", "application/json");
+    headers.add("X-Custom-Header", "custom-value");
     doReturn(headers).when(response).getHeaders();
-    doReturn("true").when(response).getEntity().toString();
 
-    Invocation.Builder builder = mock(Invocation.Builder.class);
-    doReturn(response).when(builder).delete(ClientResponse.class);
+    MultivaluedMap<String, Object> result = rest.searchForHeaders(response);
 
-    WebTarget resource = mock(WebTarget.class);
+    assertNotNull(result);
+    assertEquals(2, result.size());
+    assertTrue(result.containsKey("Content-Type"));
+    assertTrue(result.containsKey("X-Custom-Header"));
+  }
 
-    Client client = mock(Client.class);
-    doReturn(resource).when(client).target(nullable(String.class));
+  @Test
+  void testDispose() {
+    TransformMeta transformMeta = new TransformMeta();
+    transformMeta.setName("TestRest");
+    PipelineMeta pipelineMeta = new PipelineMeta();
+    pipelineMeta.setName("TestRest");
+    pipelineMeta.addTransform(transformMeta);
 
-    RestMeta meta = mock(RestMeta.class);
-    doReturn(false).when(meta).isDetailed();
-    doReturn(false).when(meta).isUrlInField();
-    doReturn(false).when(meta).isDynamicMethod();
+    RestData data = new RestData();
+    data.config = new org.glassfish.jersey.client.ClientConfig();
+    data.headerNames = new String[] {"header1", "header2"};
+    data.indexOfHeaderFields = new int[] {0, 1};
+    data.paramNames = new String[] {"param1"};
 
-    IRowMeta rmi = mock(IRowMeta.class);
-    doReturn(1).when(rmi).size();
+    Rest rest =
+        new Rest(
+            transformMeta,
+            mock(RestMeta.class),
+            data,
+            1,
+            pipelineMeta,
+            spy(new LocalPipelineEngine()));
 
-    RestData data = mock(RestData.class);
-    data.method = RestMeta.HTTP_METHOD_DELETE;
-    data.inputRowMeta = rmi;
-    data.resultFieldName = "result";
-    data.resultCodeFieldName = "status";
-    data.resultHeaderFieldName = "headers";
+    rest.dispose();
 
-    Rest rest = mock(Rest.class, Answers.RETURNS_DEFAULTS);
-    doCallRealMethod().when(rest).callRest(any());
-    doCallRealMethod().when(rest).searchForHeaders(any());
-
-    Object[] output = rest.callRest(new Object[] {0});
-
-    verify(builder, times(1)).delete(ClientResponse.class);
-    assertEquals("true", output[1]);
-    assertEquals(200L, output[2]);
-    assertEquals("{\"Content-Type\":\"application\\/json\"}", output[3]);
+    // After dispose, these should be null
+    assertNull(data.config);
+    assertNull(data.headerNames);
+    assertNull(data.indexOfHeaderFields);
+    assertNull(data.paramNames);
   }
 }
