@@ -22,8 +22,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.widget.LabelTextVar;
@@ -38,17 +36,17 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
-public class SampleRowsDialog extends BaseTransformDialog implements ITransformDialog {
-  private static final Class<?> PKG = SampleRowsMeta.class; // For Translator
+public class SampleRowsDialog extends BaseTransformDialog {
+  private static final Class<?> PKG = SampleRowsMeta.class;
 
   private LabelTextVar wLinesRange;
   private LabelTextVar wLineNumberField;
   private SampleRowsMeta input;
 
   public SampleRowsDialog(
-      Shell parent, IVariables variables, Object in, PipelineMeta tr, String sname) {
-    super(parent, variables, (BaseTransformMeta) in, tr, sname);
-    input = (SampleRowsMeta) in;
+      Shell parent, IVariables variables, SampleRowsMeta transformMeta, PipelineMeta pipelineMeta) {
+    super(parent, variables, transformMeta, pipelineMeta);
+    input = transformMeta;
   }
 
   @Override
@@ -70,7 +68,7 @@ public class SampleRowsDialog extends BaseTransformDialog implements ITransformD
     shell.setText(BaseMessages.getString(PKG, "SampleRowsDialog.Shell.Title"));
 
     int middle = props.getMiddlePct();
-    int margin = props.getMargin();
+    int margin = PropsUi.getMargin();
 
     // TransformName line
     wlTransformName = new Label(shell, SWT.RIGHT);
