@@ -132,7 +132,7 @@ public class SampleRowsMeta extends BaseTransformMeta<SampleRows, SampleRowsData
     }
     remarks.add(cr);
 
-    if (prev == null || prev.size() == 0) {
+    if (prev == null || prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_WARNING,
