@@ -19,8 +19,8 @@ package org.apache.hop.pipeline.transforms.sasinput;
 
 import org.apache.hop.core.Const;
 import org.apache.hop.core.exception.HopXmlException;
+import org.apache.hop.core.row.value.ValueMetaBase;
 import org.apache.hop.core.row.value.ValueMetaFactory;
-import org.apache.hop.core.row.value.ValueMetaString;
 import org.apache.hop.core.xml.XmlHandler;
 import org.w3c.dom.Node;
 
@@ -75,26 +75,24 @@ public class SasInputField implements Cloneable {
 
   public String getXml() {
 
-    String xml =
-        "    "
-            + XmlHandler.addTagValue("name", name)
-            + "    "
-            + XmlHandler.addTagValue("rename", rename)
-            + "    "
-            + XmlHandler.addTagValue("type", ValueMetaFactory.getValueMetaName(type))
-            + "    "
-            + XmlHandler.addTagValue("length", length)
-            + "    "
-            + XmlHandler.addTagValue("precision", precision)
-            + "    "
-            + XmlHandler.addTagValue("conversion_mask", conversionMask)
-            + "    "
-            + XmlHandler.addTagValue("decimal", decimalSymbol)
-            + "    "
-            + XmlHandler.addTagValue("grouping", groupingSymbol)
-            + "    "
-            + XmlHandler.addTagValue("trim_type", ValueMetaString.getTrimTypeCode(trimType));
-    return xml;
+    return "    "
+        + XmlHandler.addTagValue("name", name)
+        + "    "
+        + XmlHandler.addTagValue("rename", rename)
+        + "    "
+        + XmlHandler.addTagValue("type", ValueMetaFactory.getValueMetaName(type))
+        + "    "
+        + XmlHandler.addTagValue("length", length)
+        + "    "
+        + XmlHandler.addTagValue("precision", precision)
+        + "    "
+        + XmlHandler.addTagValue("conversion_mask", conversionMask)
+        + "    "
+        + XmlHandler.addTagValue("decimal", decimalSymbol)
+        + "    "
+        + XmlHandler.addTagValue("grouping", groupingSymbol)
+        + "    "
+        + XmlHandler.addTagValue("trim_type", ValueMetaBase.getTrimTypeCode(trimType));
   }
 
   public SasInputField(Node node) throws HopXmlException {
@@ -106,7 +104,7 @@ public class SasInputField implements Cloneable {
     conversionMask = XmlHandler.getTagValue(node, "conversion_mask");
     decimalSymbol = XmlHandler.getTagValue(node, "decimal");
     groupingSymbol = XmlHandler.getTagValue(node, "grouping");
-    trimType = ValueMetaString.getTrimTypeByCode(XmlHandler.getTagValue(node, "trim_type"));
+    trimType = ValueMetaBase.getTrimTypeByCode(XmlHandler.getTagValue(node, "trim_type"));
   }
 
   /**
@@ -236,6 +234,6 @@ public class SasInputField implements Cloneable {
   }
 
   public String getTrimTypeDesc() {
-    return ValueMetaString.getTrimTypeDesc(trimType);
+    return ValueMetaBase.getTrimTypeDesc(trimType);
   }
 }
