@@ -453,10 +453,10 @@ public class SchemaMappingDialog extends BaseTransformDialog {
 
       // show a confirm dialog if some missing field was found
       //
-      if (missingSourceFields.length() > 0 || missingTargetFields.length() > 0) {
+      if (!missingSourceFields.isEmpty() || !missingTargetFields.isEmpty()) {
 
         String message = "";
-        if (missingSourceFields.length() > 0) {
+        if (!missingSourceFields.isEmpty()) {
           message +=
               BaseMessages.getString(
                       PKG,
@@ -464,7 +464,7 @@ public class SchemaMappingDialog extends BaseTransformDialog {
                       missingSourceFields.toString())
                   + Const.CR;
         }
-        if (missingTargetFields.length() > 0) {
+        if (!missingTargetFields.isEmpty()) {
           message +=
               BaseMessages.getString(
                       PKG,
