@@ -90,7 +90,7 @@ public class SetValueFieldMeta extends BaseTransformMeta<SetValueField, SetValue
       IVariables variables,
       IHopMetadataProvider metadataProvider) {
     CheckResult cr;
-    if (prev == null || prev.size() == 0) {
+    if (prev == null || prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_WARNING,
@@ -125,7 +125,7 @@ public class SetValueFieldMeta extends BaseTransformMeta<SetValueField, SetValue
     }
     remarks.add(cr);
 
-    if (fields == null || fields.isEmpty()) {
+    if (Utils.isEmpty(fields)) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_ERROR,
