@@ -80,7 +80,7 @@ public class SetVariableMeta extends BaseTransformMeta<SetVariable, SetVariableD
       IVariables variables,
       IHopMetadataProvider metadataProvider) {
     CheckResult cr;
-    if (prev == null || prev.size() == 0) {
+    if (prev == null || prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_WARNING,
