@@ -33,6 +33,7 @@ import org.apache.hop.core.exception.HopTransformException;
 import org.apache.hop.core.row.IRowMeta;
 import org.apache.hop.core.row.IValueMeta;
 import org.apache.hop.core.row.RowMeta;
+import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
@@ -1417,10 +1418,10 @@ public class SnowflakeBulkLoaderDialog extends BaseTransformDialog {
 
     // show a confirm dialog if some missing field was found
     //
-    if (missingSourceFields.length() > 0 || missingTargetFields.length() > 0) {
+    if (!missingSourceFields.isEmpty() || !missingTargetFields.isEmpty()) {
 
       String message = "";
-      if (missingSourceFields.length() > 0) {
+      if (!missingSourceFields.isEmpty()) {
         message +=
             BaseMessages.getString(
                     PKG,
@@ -1428,7 +1429,7 @@ public class SnowflakeBulkLoaderDialog extends BaseTransformDialog {
                     missingSourceFields.toString())
                 + Const.CR;
       }
-      if (missingTargetFields.length() > 0) {
+      if (!missingTargetFields.isEmpty()) {
         message +=
             BaseMessages.getString(
                     PKG,
@@ -1734,7 +1735,7 @@ public class SnowflakeBulkLoaderDialog extends BaseTransformDialog {
   private static boolean isValidRowMeta(IRowMeta rowMeta) {
     for (IValueMeta value : rowMeta.getValueMetaList()) {
       String name = value.getName();
-      if (name == null || name.isEmpty()) {
+      if (Utils.isEmpty(name)) {
         return false;
       }
     }
