@@ -218,7 +218,7 @@ public class SortRowsMeta extends BaseTransformMeta<SortRows, SortRowsData>
       IHopMetadataProvider metadataProvider) {
     CheckResult cr;
 
-    if (prev != null && prev.size() > 0) {
+    if (prev != null && !prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_OK,
