@@ -19,17 +19,18 @@ package org.apache.hop.pipeline.transforms.sort;
 
 import java.util.ArrayList;
 import java.util.List;
-import org.apache.hop.core.injection.BaseMetadataInjectionTest;
-import org.apache.hop.junit.rules.RestoreHopEngineEnvironment;
-import org.junit.Before;
-import org.junit.ClassRule;
-import org.junit.Test;
+import org.apache.hop.core.injection.BaseMetadataInjectionTestJunit5;
+import org.apache.hop.junit.rules.RestoreHopEngineEnvironmentExtension;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.RegisterExtension;
 
-public class SortRowsMetaInjectionTest extends BaseMetadataInjectionTest<SortRowsMeta> {
-  @ClassRule public static RestoreHopEngineEnvironment env = new RestoreHopEngineEnvironment();
+class SortRowsMetaInjectionTest extends BaseMetadataInjectionTestJunit5<SortRowsMeta> {
+  @RegisterExtension
+  static RestoreHopEngineEnvironmentExtension env = new RestoreHopEngineEnvironmentExtension();
 
-  @Before
-  public void setup() throws Exception {
+  @BeforeEach
+  void setup() throws Exception {
     SortRowsMeta sortRowsMeta = new SortRowsMeta();
     SortRowsField sortRowsField = new SortRowsField();
     List<SortRowsField> sortRowsFields = new ArrayList<>();
@@ -38,7 +39,7 @@ public class SortRowsMetaInjectionTest extends BaseMetadataInjectionTest<SortRow
   }
 
   @Test
-  public void test() throws Exception {
+  void test() throws Exception {
     check("SORT_DIRECTORY", () -> meta.getDirectory());
     check("SORT_FILE_PREFIX", () -> meta.getPrefix());
     check("SORT_SIZE_ROWS", () -> meta.getSortSize());
