@@ -26,8 +26,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.ui.core.ConstUi;
 import org.apache.hop.ui.core.PropsUi;
@@ -49,10 +47,11 @@ import org.eclipse.swt.widgets.Table;
 import org.eclipse.swt.widgets.TableItem;
 import org.eclipse.swt.widgets.Text;
 
-public class SortedMergeDialog extends BaseTransformDialog implements ITransformDialog {
-  private static final Class<?> PKG = SortedMergeMeta.class; // For Translator
+public class SortedMergeDialog extends BaseTransformDialog {
+  private static final Class<?> PKG = SortedMergeMeta.class;
 
   public static final String STRING_SORT_WARNING_PARAMETER = "SortedMergeSortWarning";
+  public static final String CONST_SYSTEM_COMBO_NO = "System.Combo.No";
 
   private TableView wFields;
 
@@ -63,9 +62,12 @@ public class SortedMergeDialog extends BaseTransformDialog implements ITransform
   private ColumnInfo[] colinf;
 
   public SortedMergeDialog(
-      Shell parent, IVariables variables, Object in, PipelineMeta tr, String sname) {
-    super(parent, variables, (BaseTransformMeta) in, tr, sname);
-    input = (SortedMergeMeta) in;
+      Shell parent,
+      IVariables variables,
+      SortedMergeMeta transformMeta,
+      PipelineMeta pipelineMeta) {
+    super(parent, variables, transformMeta, pipelineMeta);
+    input = transformMeta;
   }
 
   @Override
@@ -87,7 +89,7 @@ public class SortedMergeDialog extends BaseTransformDialog implements ITransform
     shell.setText(BaseMessages.getString(PKG, "SortedMergeDialog.Shell.Title"));
 
     int middle = props.getMiddlePct();
-    int margin = props.getMargin();
+    int margin = PropsUi.getMargin();
 
     // TransformName line
     wlTransformName = new Label(shell, SWT.RIGHT);
@@ -142,7 +144,7 @@ public class SortedMergeDialog extends BaseTransformDialog implements ITransform
             ColumnInfo.COLUMN_TYPE_CCOMBO,
             new String[] {
               BaseMessages.getString(PKG, "System.Combo.Yes"),
-              BaseMessages.getString(PKG, "System.Combo.No")
+              BaseMessages.getString(PKG, CONST_SYSTEM_COMBO_NO)
             });
 
     wFields =
@@ -218,7 +220,7 @@ public class SortedMergeDialog extends BaseTransformDialog implements ITransform
           2,
           input.getAscending()[i]
               ? BaseMessages.getString(PKG, "System.Combo.Yes")
-              : BaseMessages.getString(PKG, "System.Combo.No"));
+              : BaseMessages.getString(PKG, CONST_SYSTEM_COMBO_NO));
     }
 
     wFields.setRowNums();
@@ -249,7 +251,7 @@ public class SortedMergeDialog extends BaseTransformDialog implements ITransform
       TableItem ti = wFields.getNonEmpty(i);
       input.getFieldName()[i] = ti.getText(1);
       input.getAscending()[i] =
-          !BaseMessages.getString(PKG, "System.Combo.No").equalsIgnoreCase(ti.getText(2));
+          !BaseMessages.getString(PKG, CONST_SYSTEM_COMBO_NO).equalsIgnoreCase(ti.getText(2));
     }
 
     // Show a warning (optional)
