@@ -171,7 +171,7 @@ public class SortedMergeMeta extends BaseTransformMeta<SortedMerge, SortedMergeD
       IHopMetadataProvider metadataProvider) {
     CheckResult cr;
 
-    if (prev != null && prev.size() > 0) {
+    if (prev != null && !prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_OK,
