@@ -185,7 +185,7 @@ public class SplitFieldToRowsMeta
     CheckResult cr;
 
     // Look up fields in the input stream <prev>
-    if (prev != null && prev.size() > 0) {
+    if (prev != null && !prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_OK,
