@@ -186,7 +186,7 @@ public class SQLFileOutputMeta extends BaseTransformMeta<SQLFileOutput, SQLFileO
       retval += "_" + splitnr;
     }
 
-    if (file.extension != null && !file.extension.isEmpty()) {
+    if (!Utils.isEmpty(file.extension)) {
       retval += "." + variables.resolve(file.extension);
     }
 
@@ -266,7 +266,7 @@ public class SQLFileOutputMeta extends BaseTransformMeta<SQLFileOutput, SQLFileO
                 boolean errorFound = false;
                 // OK, we have the table fields.
                 // Now see what we can find as previous transform...
-                if (prev != null && prev.size() > 0) {
+                if (prev != null && !prev.isEmpty()) {
                   cr =
                       new CheckResult(
                           ICheckResult.TYPE_RESULT_OK,
@@ -489,7 +489,7 @@ public class SQLFileOutputMeta extends BaseTransformMeta<SQLFileOutput, SQLFileO
           new SqlStatement(transformMeta.getName(), databaseMeta, null); // default: nothing to do!
 
       if (databaseMeta != null) {
-        if (prev != null && prev.size() > 0) {
+        if (prev != null && !prev.isEmpty()) {
           if (!Utils.isEmpty(tableName)) {
             Database db = new Database(loggingObject, variables, databaseMeta);
             try {
@@ -500,7 +500,7 @@ public class SQLFileOutputMeta extends BaseTransformMeta<SQLFileOutput, SQLFileO
               String crTable = db.getDDL(schemaTable, prev);
 
               // Empty string means: nothing to do: set it to null...
-              if (crTable == null || crTable.isEmpty()) {
+              if (Utils.isEmpty(crTable)) {
                 crTable = null;
               }
 
