@@ -37,7 +37,9 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.transform.BaseTransformData;
 import org.apache.hop.pipeline.transform.ITransformData;
 
+@SuppressWarnings("java:S1104")
 public class SshData extends BaseTransformData implements ITransformData {
+  private static final Class<?> PKG = SshMeta.class;
   public int indexOfCommand;
   public Connection conn;
   public boolean wroteOneRow;
@@ -79,14 +81,13 @@ public class SshData extends BaseTransformData implements ITransformData {
       if (meta.isUsePrivateKey()) {
         String keyFilename = variables.resolve(meta.getKeyFileName());
         if (StringUtils.isEmpty(keyFilename)) {
-          throw new HopException(
-              BaseMessages.getString(SshMeta.PKG, "SSH.Error.PrivateKeyFileMissing"));
+          throw new HopException(BaseMessages.getString(PKG, "SSH.Error.PrivateKeyFileMissing"));
         }
-        FileObject keyFileObject = HopVfs.getFileObject(keyFilename);
+        FileObject keyFileObject = HopVfs.getFileObject(keyFilename, variables);
 
         if (!keyFileObject.exists()) {
           throw new HopException(
-              BaseMessages.getString(SshMeta.PKG, "SSH.Error.PrivateKeyNotExist", keyFilename));
+              BaseMessages.getString(PKG, "SSH.Error.PrivateKeyNotExist", keyFilename));
         }
 
         FileContent keyFileContent = keyFileObject.getContent();
@@ -139,7 +140,7 @@ public class SshData extends BaseTransformData implements ITransformData {
       }
       if (!isAuthenticated) {
         throw new HopException(
-            BaseMessages.getString(SshMeta.PKG, "SSH.Error.AuthenticationFailed", username));
+            BaseMessages.getString(PKG, "SSH.Error.AuthenticationFailed", username));
       }
     } catch (Exception e) {
       // Something wrong happened
@@ -148,7 +149,7 @@ public class SshData extends BaseTransformData implements ITransformData {
         connection.close();
       }
       throw new HopException(
-          BaseMessages.getString(SshMeta.PKG, "SSH.Error.ErrorConnecting", hostname, username), e);
+          BaseMessages.getString(PKG, "SSH.Error.ErrorConnecting", hostname, username), e);
     }
     return connection;
   }
