@@ -112,7 +112,7 @@ public class StreamLookup extends BaseTransform<StreamLookupMeta, StreamLookupDa
           break;
         default:
           // if a default value is given and no conversion is implemented throw an error
-          if (data.valueDefault[i] != null && data.valueDefault[i].trim().length() > 0) {
+          if (data.valueDefault[i] != null && !data.valueDefault[i].trim().isEmpty()) {
             throw new RuntimeException(
                 BaseMessages.getString(PKG, "StreamLookup.Exception.ConversionNotImplemented")
                     + " "
@@ -478,10 +478,8 @@ public class StreamLookup extends BaseTransform<StreamLookupMeta, StreamLookupDa
 
     putRow(data.outputRowMeta, outputRow); // copy row to output rowset(s)
 
-    if (checkFeedback(getLinesRead())) {
-      if (isBasic()) {
-        logBasic(BaseMessages.getString(PKG, "StreamLookup.Log.LineNumber") + getLinesRead());
-      }
+    if (checkFeedback(getLinesRead()) && isBasic()) {
+      logBasic(BaseMessages.getString(PKG, "StreamLookup.Log.LineNumber") + getLinesRead());
     }
 
     return true;
