@@ -493,7 +493,7 @@ public class StreamLookupDialog extends BaseTransformDialog {
       TableItem item = wReturn.getNonEmpty(i);
       input.getValue()[i] = item.getText(1);
       input.getValueName()[i] = item.getText(2);
-      if (input.getValueName()[i] == null || input.getValueName()[i].length() == 0) {
+      if (Utils.isEmpty(input.getValueName()[i])) {
         input.getValueName()[i] = input.getValue()[i];
       }
       input.getValueDefault()[i] = item.getText(3);
