@@ -304,7 +304,7 @@ public class StreamLookupMeta extends BaseTransformMeta<StreamLookup, StreamLook
       IHopMetadataProvider metadataProvider) {
     CheckResult cr;
 
-    if (prev != null && prev.size() > 0) {
+    if (prev != null && !prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_OK,
@@ -352,7 +352,7 @@ public class StreamLookupMeta extends BaseTransformMeta<StreamLookup, StreamLook
       remarks.add(cr);
     }
 
-    if (info != null && info.size() > 0) {
+    if (info != null && !info.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_OK,
