@@ -26,8 +26,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.ui.core.ConstUi;
 import org.apache.hop.ui.core.PropsUi;
@@ -50,9 +48,9 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.TableItem;
 import org.eclipse.swt.widgets.Text;
 
-public class StringOperationsDialog extends BaseTransformDialog implements ITransformDialog {
+public class StringOperationsDialog extends BaseTransformDialog {
 
-  private static final Class<?> PKG = StringOperationsMeta.class; // For Translator
+  private static final Class<?> PKG = StringOperationsMeta.class;
 
   private TableView wFields;
 
@@ -64,9 +62,12 @@ public class StringOperationsDialog extends BaseTransformDialog implements ITran
   private ColumnInfo[] ciKey;
 
   public StringOperationsDialog(
-      Shell parent, IVariables variables, Object in, PipelineMeta tr, String sname) {
-    super(parent, variables, (BaseTransformMeta) in, tr, sname);
-    input = (StringOperationsMeta) in;
+      Shell parent,
+      IVariables variables,
+      StringOperationsMeta transformMeta,
+      PipelineMeta pipelineMeta) {
+    super(parent, variables, transformMeta, pipelineMeta);
+    input = transformMeta;
   }
 
   @Override
@@ -89,7 +90,7 @@ public class StringOperationsDialog extends BaseTransformDialog implements ITran
     shell.setText(BaseMessages.getString(PKG, "StringOperationsDialog.Shell.Title"));
 
     int middle = props.getMiddlePct();
-    int margin = props.getMargin();
+    int margin = PropsUi.getMargin();
 
     // THE BUTTONS at the bottom of the dialog
     //
