@@ -25,8 +25,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.dialog.ErrorDialog;
@@ -47,8 +45,8 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.TableItem;
 import org.eclipse.swt.widgets.Text;
 
-public class SwitchCaseDialog extends BaseTransformDialog implements ITransformDialog {
-  private static final Class<?> PKG = SwitchCaseMeta.class; // For Translator
+public class SwitchCaseDialog extends BaseTransformDialog {
+  private static final Class<?> PKG = SwitchCaseMeta.class;
 
   private CCombo wFieldName;
 
@@ -69,9 +67,9 @@ public class SwitchCaseDialog extends BaseTransformDialog implements ITransformD
   private final SwitchCaseMeta input;
 
   public SwitchCaseDialog(
-      Shell parent, IVariables variables, Object in, PipelineMeta tr, String sname) {
-    super(parent, variables, (BaseTransformMeta) in, tr, sname);
-    input = (SwitchCaseMeta) in;
+      Shell parent, IVariables variables, SwitchCaseMeta transformMeta, PipelineMeta pipelineMeta) {
+    super(parent, variables, transformMeta, pipelineMeta);
+    input = transformMeta;
   }
 
   @Override
@@ -100,7 +98,7 @@ public class SwitchCaseDialog extends BaseTransformDialog implements ITransformD
     shell.setText(BaseMessages.getString(PKG, "SwitchCaseDialog.Shell.Title"));
 
     int middle = props.getMiddlePct();
-    int margin = props.getMargin();
+    int margin = PropsUi.getMargin();
 
     // TransformName line
     wlTransformName = new Label(shell, SWT.RIGHT);
