@@ -27,6 +27,7 @@ import org.apache.hop.core.Result;
 import org.apache.hop.core.exception.HopException;
 import org.apache.hop.core.row.IRowMeta;
 import org.apache.hop.core.row.RowMeta;
+import org.apache.hop.core.util.Utils;
 import org.apache.hop.execution.Execution;
 import org.apache.hop.execution.ExecutionInfoLocation;
 import org.apache.hop.execution.ExecutionType;
@@ -53,7 +54,7 @@ public class SystemData extends BaseTransform<SystemDataMeta, SystemDataData> {
   private Object[] getSystemData(IRowMeta inputRowMeta, Object[] inputRowData) throws HopException {
     Object[] row = new Object[data.outputRowMeta.size()];
     // no data is changed, clone is not needed here.
-    if (inputRowMeta.size() >= 0) System.arraycopy(inputRowData, 0, row, 0, inputRowMeta.size());
+    if (!inputRowMeta.isEmpty()) System.arraycopy(inputRowData, 0, row, 0, inputRowMeta.size());
     for (int i = 0, index = inputRowMeta.size(); i < meta.getFieldName().length; i++, index++) {
       Calendar cal;
 
@@ -535,7 +536,7 @@ public class SystemData extends BaseTransform<SystemDataMeta, SystemDataData> {
           Result previousResult = getPipeline().getPreviousResult();
           boolean result = false;
           if (previousResult != null) {
-            result = previousResult.getResult();
+            result = previousResult.isResult();
           }
           row[index] = result;
           break;
@@ -759,7 +760,7 @@ public class SystemData extends BaseTransform<SystemDataMeta, SystemDataData> {
 
     if (super.init()) {
       List<TransformMeta> previous = getPipelineMeta().findPreviousTransforms(getTransformMeta());
-      if (previous != null && !previous.isEmpty()) {
+      if (!Utils.isEmpty(previous)) {
         data.readsRows = true;
       }
 
