@@ -26,8 +26,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.dialog.EnterSelectionDialog;
@@ -52,8 +50,8 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
-public class TableExistsDialog extends BaseTransformDialog implements ITransformDialog {
-  private static final Class<?> PKG = TableExistsMeta.class; // For Translator
+public class TableExistsDialog extends BaseTransformDialog {
+  private static final Class<?> PKG = TableExistsMeta.class;
 
   private MetaSelectionLine<DatabaseMeta> wConnection;
 
@@ -66,9 +64,12 @@ public class TableExistsDialog extends BaseTransformDialog implements ITransform
   private final TableExistsMeta input;
 
   public TableExistsDialog(
-      Shell parent, IVariables variables, Object in, PipelineMeta pipelineMeta, String sname) {
-    super(parent, variables, (BaseTransformMeta) in, pipelineMeta, sname);
-    input = (TableExistsMeta) in;
+      Shell parent,
+      IVariables variables,
+      TableExistsMeta transformMeta,
+      PipelineMeta pipelineMeta) {
+    super(parent, variables, transformMeta, pipelineMeta);
+    input = transformMeta;
   }
 
   @Override
