@@ -308,7 +308,7 @@ public class TableInputMeta extends BaseTransformMeta<TableInput, TableInputData
                 ICheckResult.TYPE_RESULT_OK, "Connection to database OK", transformMeta);
         remarks.add(cr);
 
-        if (sql != null && sql.length() != 0) {
+        if (!Utils.isEmpty(sql)) {
           cr =
               new CheckResult(
                   ICheckResult.TYPE_RESULT_OK, "SQL statement is entered", transformMeta);
