@@ -30,7 +30,6 @@ import org.apache.hop.core.util.KeyValue;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
 import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.ui.core.ConstUi;
@@ -62,13 +61,14 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.TableItem;
 
-public class TeraFastDialog extends BaseTransformDialog implements ITransformDialog {
+public class TeraFastDialog extends BaseTransformDialog {
 
-  private static final Class<?> PKG = TeraFastMeta.class; // For Translator
+  private static final Class<?> PKG = TeraFastMeta.class;
 
   private static final int FORM_ATTACHMENT_OFFSET = 100;
 
   private static final int FORM_ATTACHMENT_FACTOR = -15;
+  public static final String CONST_TERA_FAST_DIALOG_BROWSE_BUTTON = "TeraFastDialog.Browse.Button";
 
   private final TeraFastMeta meta;
 
@@ -119,18 +119,17 @@ public class TeraFastDialog extends BaseTransformDialog implements ITransformDia
    * Constructor.
    *
    * @param parent parent shell.
-   * @param baseTransformMeta transform meta
+   * @param variables transform meta
    * @param pipelineMeta transaction meta
-   * @param transformName name of transform.
+   * @param transformMeta name of transform.
    */
   public TeraFastDialog(
       final Shell parent,
       IVariables variables,
-      final Object baseTransformMeta,
-      final PipelineMeta pipelineMeta,
-      final String transformName) {
-    super(parent, variables, (BaseTransformMeta) baseTransformMeta, pipelineMeta, transformName);
-    this.meta = (TeraFastMeta) baseTransformMeta;
+      final TeraFastMeta transformMeta,
+      final PipelineMeta pipelineMeta) {
+    super(parent, variables, transformMeta, pipelineMeta);
+    this.meta = transformMeta;
   }
 
   /**
@@ -499,7 +498,7 @@ public class TeraFastDialog extends BaseTransformDialog implements ITransformDia
     wlControlFile.setLayoutData(factory.createLabelLayoutData(topControl));
 
     this.wbControlFile =
-        factory.createPushButton(BaseMessages.getString(PKG, "TeraFastDialog.Browse.Button"));
+        factory.createPushButton(BaseMessages.getString(PKG, CONST_TERA_FAST_DIALOG_BROWSE_BUTTON));
     PropsUi.setLook(this.wbControlFile);
     FormData formData = factory.createControlLayoutData(topControl);
     formData.left = null;
@@ -524,7 +523,7 @@ public class TeraFastDialog extends BaseTransformDialog implements ITransformDia
     wlFastLoadPath.setLayoutData(factory.createLabelLayoutData(topControl));
 
     this.wbFastLoadPath =
-        factory.createPushButton(BaseMessages.getString(PKG, "TeraFastDialog.Browse.Button"));
+        factory.createPushButton(BaseMessages.getString(PKG, CONST_TERA_FAST_DIALOG_BROWSE_BUTTON));
     PropsUi.setLook(this.wbFastLoadPath);
     FormData formData = factory.createControlLayoutData(topControl);
     formData.left = null;
@@ -592,7 +591,7 @@ public class TeraFastDialog extends BaseTransformDialog implements ITransformDia
     wlLogFile.setLayoutData(factory.createLabelLayoutData(topControl));
 
     this.wbLogFile =
-        factory.createPushButton(BaseMessages.getString(PKG, "TeraFastDialog.Browse.Button"));
+        factory.createPushButton(BaseMessages.getString(PKG, CONST_TERA_FAST_DIALOG_BROWSE_BUTTON));
     PropsUi.setLook(this.wbLogFile);
     FormData formData = factory.createControlLayoutData(topControl);
     formData.left = null;
@@ -675,7 +674,7 @@ public class TeraFastDialog extends BaseTransformDialog implements ITransformDia
     wlDataFile.setLayoutData(factory.createLabelLayoutData(topControl));
 
     this.wbDataFile =
-        factory.createPushButton(BaseMessages.getString(PKG, "TeraFastDialog.Browse.Button"));
+        factory.createPushButton(BaseMessages.getString(PKG, CONST_TERA_FAST_DIALOG_BROWSE_BUTTON));
     PropsUi.setLook(this.wbDataFile);
     FormData formData = factory.createControlLayoutData(topControl);
     formData.left = null;
@@ -791,7 +790,7 @@ public class TeraFastDialog extends BaseTransformDialog implements ITransformDia
     formData.left = new FormAttachment(0, 0);
     formData.top = new FormAttachment(wlReturn, factory.getMargin());
     formData.right = new FormAttachment(this.wGetLU, -factory.getMargin());
-    formData.bottom = new FormAttachment(wOk, -2 * props.getMargin());
+    formData.bottom = new FormAttachment(wOk, -2 * PropsUi.getMargin());
     this.wReturn.setLayoutData(formData);
   }
 
