@@ -144,10 +144,8 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
 
             if (encodingType.isLinefeed(c)) {
               return line.toString();
-            } else if (!encodingType.isReturn(c)) {
-              if (c >= 0) {
-                line.append((char) c);
-              }
+            } else if (!encodingType.isReturn(c) && c >= 0) {
+              line.append((char) c);
             }
           }
           break;
@@ -157,7 +155,7 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
     } catch (HopFileException e) {
       throw e;
     } catch (Exception e) {
-      if (line.length() == 0) {
+      if (line.isEmpty()) {
         throw new HopFileException(
             BaseMessages.getString(
                 PKG, "TextFileInput.Log.Error.ExceptionReadingLine", e.toString()),
@@ -165,7 +163,7 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
       }
       return line.toString();
     }
-    if (line.length() > 0) {
+    if (!line.isEmpty()) {
       return line.toString();
     }
 
@@ -833,19 +831,19 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
     Long errorCount = null;
     if (info.isErrorIgnored()
         && info.getErrorCountField() != null
-        && info.getErrorCountField().length() > 0) {
-      errorCount = Long.valueOf(0L);
+        && !info.getErrorCountField().isEmpty()) {
+      errorCount = 0L;
     }
     String errorFields = null;
     if (info.isErrorIgnored()
         && info.getErrorFieldsField() != null
-        && info.getErrorFieldsField().length() > 0) {
+        && !info.getErrorFieldsField().isEmpty()) {
       errorFields = "";
     }
     String errorText = null;
     if (info.isErrorIgnored()
         && info.getErrorTextField() != null
-        && info.getErrorTextField().length() > 0) {
+        && !info.getErrorTextField().isEmpty()) {
       errorText = "";
     }
 
@@ -899,11 +897,11 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
                 value = null;
 
                 if (errorCount != null) {
-                  errorCount = Long.valueOf(errorCount.longValue() + 1L);
+                  errorCount = errorCount + 1L;
                 }
                 if (errorFields != null) {
                   StringBuilder sb = new StringBuilder(errorFields);
-                  if (sb.length() > 0) {
+                  if (!sb.isEmpty()) {
                     sb.append("\t"); // TODO document this change
                   }
                   sb.append(valueMeta.getName());
@@ -911,7 +909,7 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
                 }
                 if (errorText != null) {
                   StringBuilder sb = new StringBuilder(errorText);
-                  if (sb.length() > 0) {
+                  if (!sb.isEmpty()) {
                     sb.append(Const.CR);
                   }
                   sb.append(message);
@@ -976,7 +974,7 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
 
         // Possibly add a row number...
         if (info.includeRowNumber()) {
-          r[index] = Long.valueOf(rowNr);
+          r[index] = rowNr;
           index++;
         }
 
@@ -997,7 +995,7 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
         }
         // Add Size
         if (addSize) {
-          r[index] = Long.valueOf(size);
+          r[index] = size;
           index++;
         }
         // add Hidden
@@ -1116,12 +1114,10 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
 
       // Open the first file & read the required rows in the buffer, stop
       // if it fails and not set to skip bad files...
-      if (!openNextFile()) {
-        if (failAfterBadFile(null)) {
-          closeLastFile();
-          setOutputDone();
-          return false;
-        }
+      if (!openNextFile() && failAfterBadFile(null)) {
+        closeLastFile();
+        setOutputDone();
+        return false;
       }
 
       // Count the number of repeat fields...
@@ -1155,14 +1151,12 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
      * If the buffer is empty: open the next file. (if nothing in there, open the next, etc.)
      */
     while (data.lineBuffer.isEmpty()) {
-      if (!openNextFile()) {
+      if (!openNextFile() && failAfterBadFile(null)) {
         // Open fails: done processing unless set to skip bad files
-        if (failAfterBadFile(null)) {
-          closeLastFile();
-          setOutputDone(); // signal end to receiver(s)
-          return false;
-        } // else will continue until can open
-      }
+        closeLastFile();
+        setOutputDone(); // signal end to receiver(s)
+        return false;
+      } // else will continue until can open
     }
 
     /*
@@ -1405,10 +1399,8 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
       }
     }
 
-    if (checkFeedback(getLinesInput())) {
-      if (isBasic()) {
-        logBasic("linenr " + getLinesInput());
-      }
+    if (checkFeedback(getLinesInput()) && isBasic()) {
+      logBasic("linenr " + getLinesInput());
     }
 
     return retval;
@@ -1505,15 +1497,13 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
     boolean filterOK = true;
 
     // check for noEmptyLines
-    if (meta.noEmptyLines() && line.length() == 0) {
+    if (meta.noEmptyLines() && line.isEmpty()) {
       filterOK = false;
     } else {
       // check the filters
       filterOK = data.filterProcessor.doFilters(line);
-      if (!filterOK) {
-        if (data.filterProcessor.isStopProcessing()) {
-          data.doneReading = true;
-        }
+      if (!filterOK && data.filterProcessor.isStopProcessing()) {
+        data.doneReading = true;
       }
     }
 
@@ -1571,7 +1561,7 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
       data.dataErrorLineHandler.close();
     } catch (Exception e) {
       String errorMsg =
-          "Couldn't close file : " + data.file.getName().getFriendlyURI() + " --> " + e.toString();
+          "Couldn't close file : " + data.file.getName().getFriendlyURI() + " --> " + e;
       logError(errorMsg);
       if (failAfterBadFile(errorMsg)) {
         stopAll();
@@ -1626,7 +1616,7 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
         data.rootUriName = data.file.getName().getRootURI();
       }
       if (data.addSize) {
-        data.size = Long.valueOf(data.file.getContent().getSize());
+        data.size = data.file.getContent().getSize();
       }
       data.lineInFile = 0;
       if (meta.isPassingThruFields()) {
@@ -1659,7 +1649,7 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
             "This is a compressed file being handled by the " + provider.getName() + " provider");
       }
 
-      if (meta.getEncoding() != null && meta.getEncoding().length() > 0) {
+      if (!Utils.isEmpty(meta.getEncoding())) {
         data.isr =
             new InputStreamReader(
                 new BufferedInputStream(data.in, BUFFER_SIZE_INPUT_STREAM), meta.getEncoding());
@@ -1729,7 +1719,7 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
               + " : "
               + data.file.getName().getFriendlyURI()
               + " --> "
-              + e.toString();
+              + e;
       logError(errorMsg);
       if (failAfterBadFile(errorMsg)) {
         stopAll();
@@ -1764,7 +1754,7 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
         }
       } else { // don't checkFilterRow
 
-        if (!meta.noEmptyLines() || line.length() != 0) {
+        if (!meta.noEmptyLines() || !line.isEmpty()) {
           data.lineBuffer.add(
               new TextFileLine(line, lineNumberInFile, data.file)); // Store it in the line
           // buffer...
@@ -1793,7 +1783,7 @@ public class TextFileInput extends BaseTransform<TextFileInputMeta, TextFileInpu
       Map<String, ResultFile> resultFiles =
           (previousResult != null) ? previousResult.getResultFiles() : null;
 
-      if ((previousResult == null || resultFiles == null || resultFiles.size() == 0)
+      if ((previousResult == null || Utils.isEmpty(resultFiles))
           && data.getFiles().nrOfMissingFiles() > 0
           && !meta.isAcceptingFilenames()
           && !meta.isErrorIgnored()) {
