@@ -32,8 +32,8 @@ import org.apache.hop.ui.hopgui.perspective.explorer.file.types.text.BaseTextExp
 
 @HopFileTypePlugin(
     id = "CsvExplorerFileType",
-    name = "JSON File Type",
-    description = "JSON file handling in the explorer perspective",
+    name = "CSV File Type",
+    description = "CSV file handling in the explorer perspective",
     image = "textfile.svg")
 public class CsvExplorerFileType extends BaseTextExplorerFileType<TextExplorerFileTypeHandler>
     implements IExplorerFileType<TextExplorerFileTypeHandler> {
