@@ -17,20 +17,21 @@
 
 package org.apache.hop.pipeline.transforms.csvinput;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
 import java.nio.charset.StandardCharsets;
 import org.apache.hop.core.exception.HopException;
 import org.apache.hop.core.exception.HopTransformException;
 import org.apache.hop.core.file.TextFileInputField;
 import org.apache.hop.core.logging.ILoggingObject;
 import org.apache.hop.core.row.IRowMeta;
-import org.apache.hop.junit.rules.RestoreHopEngineEnvironment;
+import org.apache.hop.junit.rules.RestoreHopEngineEnvironmentExtension;
 import org.apache.hop.pipeline.transform.RowAdapter;
 import org.apache.hop.pipeline.transforms.mock.TransformMockHelper;
-import org.junit.AfterClass;
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.ClassRule;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.RegisterExtension;
 import org.mockito.ArgumentMatchers;
 import org.mockito.Mockito;
 
@@ -39,8 +40,10 @@ import org.mockito.Mockito;
  *
  * @see CsvInput
  */
-public class CsvInputUnicodeTest extends CsvInputUnitTestBase {
-  @ClassRule public static RestoreHopEngineEnvironment env = new RestoreHopEngineEnvironment();
+class CsvInputUnicodeTest extends CsvInputUnitTestBase {
+  @RegisterExtension
+  static RestoreHopEngineEnvironmentExtension env = new RestoreHopEngineEnvironmentExtension();
+
   private static final String UTF8 = "UTF-8";
   private static final String UTF16LE = "UTF-16LE";
   private static final String UTF16LEBOM = "x-UTF-16LE-BOM";
@@ -75,8 +78,8 @@ public class CsvInputUnicodeTest extends CsvInputUnitTestBase {
 
   private static TransformMockHelper<CsvInputMeta, CsvInputData> transformMockHelper;
 
-  @BeforeClass
-  public static void setUp() throws HopException {
+  @BeforeAll
+  static void setUp() throws HopException {
     transformMockHelper =
         TransformMockUtil.getTransformMockHelper(
             CsvInputMeta.class, CsvInputData.class, "CsvInputUnicodeTest");
@@ -87,88 +90,88 @@ public class CsvInputUnicodeTest extends CsvInputUnitTestBase {
     Mockito.when(transformMockHelper.pipeline.isRunning()).thenReturn(true);
   }
 
-  @AfterClass
-  public static void cleanUp() {
+  @AfterAll
+  static void cleanUp() {
     transformMockHelper.cleanUp();
   }
 
   @Test
-  public void testUTF16LE() throws Exception {
+  void testUTF16LE() throws Exception {
     doTest(UTF16LE, UTF16LE, TEST_DATA, ONE_CHAR_DELIM, true);
   }
 
   @Test
-  public void testUTF16BE() throws Exception {
+  void testUTF16BE() throws Exception {
     doTest(UTF16BE, UTF16BE, TEST_DATA, ONE_CHAR_DELIM, true);
   }
 
   @Test
-  public void testUTF16BE_multiDelim() throws Exception {
+  void testUTF16BE_multiDelim() throws Exception {
     doTest(UTF16BE, UTF16BE, TEST_DATA1, MULTI_CHAR_DELIM, true);
   }
 
   @Test
-  public void testUTF16LEBOM() throws Exception {
+  void testUTF16LEBOM() throws Exception {
     doTest(UTF16LEBOM, UTF16LE, TEST_DATA, ONE_CHAR_DELIM, true);
   }
 
   @Test
-  public void testUTF8() throws Exception {
+  void testUTF8() throws Exception {
     doTest(UTF8, UTF8, TEST_DATA, ONE_CHAR_DELIM, true);
   }
 
   @Test
-  public void testUTF8_multiDelim() throws Exception {
+  void testUTF8_multiDelim() throws Exception {
     doTest(UTF8, UTF8, TEST_DATA1, MULTI_CHAR_DELIM, true);
   }
 
   @Test
-  public void testUTF8_headerWithBOM() throws Exception {
+  void testUTF8_headerWithBOM() throws Exception {
     doTest(UTF8, UTF8, TEST_DATA_UTF8_BOM, ONE_CHAR_DELIM, true);
   }
 
   @Test
-  public void testUTF8_withoutHeaderWithBOM() throws Exception {
+  void testUTF8_withoutHeaderWithBOM() throws Exception {
     doTest(UTF8, UTF8, TEST_DATA_NOHEADER_UTF8_BOM, ONE_CHAR_DELIM, false);
   }
 
   @Test
-  public void testUTF16LEDataWithEnclosures() throws Exception {
+  void testUTF16LEDataWithEnclosures() throws Exception {
     doTest(UTF16LE, UTF16LE, TEST_DATA2, ONE_CHAR_DELIM, true);
   }
 
   @Test
-  public void testUTF16LE_headerWithBOM() throws Exception {
+  void testUTF16LE_headerWithBOM() throws Exception {
     doTest(UTF16LE, UTF16LE, TEST_DATA_UTF16LE_BOM, ONE_CHAR_DELIM, true);
   }
 
   @Test
-  public void testUTF16BEDataWithEnclosures() throws Exception {
+  void testUTF16BEDataWithEnclosures() throws Exception {
     doTest(UTF16BE, UTF16BE, TEST_DATA2, ONE_CHAR_DELIM, true);
   }
 
   @Test
-  public void testUTF16BE_headerWithBOM() throws Exception {
+  void testUTF16BE_headerWithBOM() throws Exception {
     doTest(UTF16BE, UTF16BE, TEST_DATA_UTF16BE_BOM, ONE_CHAR_DELIM, true);
   }
 
   @Test
-  public void testUTF16LEBOMDataWithEnclosures() throws Exception {
+  void testUTF16LEBOMDataWithEnclosures() throws Exception {
     doTest(UTF16LEBOM, UTF16LE, TEST_DATA2, ONE_CHAR_DELIM, true);
   }
 
   @Test
-  public void testUTF16BE_multiDelim_DataWithEnclosures() throws Exception {
+  void testUTF16BE_multiDelim_DataWithEnclosures() throws Exception {
     doTest(UTF16BE, UTF16BE, TEST_DATA3, MULTI_CHAR_DELIM, true);
   }
 
   @Test
-  public void testUTF16LE_multiDelim_DataWithEnclosures() throws Exception {
+  void testUTF16LE_multiDelim_DataWithEnclosures() throws Exception {
     doTest(UTF16LE, UTF16LE, TEST_DATA3, MULTI_CHAR_DELIM, true);
   }
 
   @Test
-  public void testUTF8_multiDelim_DataWithEnclosures() throws Exception {
+  void testUTF8_multiDelim_DataWithEnclosures() throws Exception {
     doTest(UTF8, UTF8, TEST_DATA3, MULTI_CHAR_DELIM, true);
   }
 
@@ -199,7 +202,7 @@ public class CsvInputUnicodeTest extends CsvInputUnitTestBase {
           @Override
           public void rowWrittenEvent(IRowMeta rowMeta, Object[] row) throws HopTransformException {
             for (int i = 0; i < rowMeta.size(); i++) {
-              Assert.assertEquals("Value", row[i]);
+              assertEquals("Value", row[i]);
             }
           }
         });
@@ -210,7 +213,7 @@ public class CsvInputUnicodeTest extends CsvInputUnitTestBase {
     } while (!haveRowsToRead);
 
     csvInput.dispose();
-    Assert.assertEquals(2, csvInput.getLinesWritten());
+    assertEquals(2, csvInput.getLinesWritten());
   }
 
   private CsvInputMeta createTransformMeta(
