@@ -17,36 +17,36 @@
 
 package org.apache.hop.pipeline.transforms.fileinput.text;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
 
 import java.io.BufferedInputStream;
 import java.io.BufferedReader;
 import java.io.InputStream;
 import java.io.InputStreamReader;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
-public class BOMDetectorTest {
+class BOMDetectorTest {
 
   BufferedInputStream getFile(String filename) throws Exception {
     String inPrefix = '/' + this.getClass().getPackage().getName().replace('.', '/') + "/files/";
     InputStream file = this.getClass().getResourceAsStream(inPrefix + filename);
-    assertNotNull("There is no file " + filename, file);
+    assertNotNull(file);
     return new BufferedInputStream(file);
   }
 
   public void testBOM(String file, String charset) throws Exception {
     BufferedInputStream in = getFile(file);
     BOMDetector detector = new BOMDetector(in);
-    assertEquals("Wrong BOM detected", charset, detector.getCharset());
+    assertEquals(charset, detector.getCharset(), "Wrong BOM detected");
     BufferedReader rd = new BufferedReader(new InputStreamReader(in, detector.getCharset()));
     String data = rd.readLine();
-    assertEquals("Wrong data in file", "data;1", data);
+    assertEquals("data;1", data, "Wrong data in file");
     in.close();
   }
 
   @Test
-  public void testBOMs() throws Exception {
+  void testBOMs() throws Exception {
     testBOM("test-BOM-UTF-8.txt", "UTF-8");
     testBOM("test-BOM-UTF-16BE.txt", "UTF-16BE");
     testBOM("test-BOM-UTF-16LE.txt", "UTF-16LE");
