@@ -27,21 +27,23 @@ import static org.mockito.Mockito.when;
 import java.util.Date;
 import org.apache.hop.core.HopEnvironment;
 import org.apache.hop.core.logging.ILoggingObject;
-import org.apache.hop.junit.rules.RestoreHopEngineEnvironment;
+import org.apache.hop.junit.rules.RestoreHopEngineEnvironmentExtension;
 import org.apache.hop.pipeline.transforms.mock.TransformMockHelper;
-import org.junit.AfterClass;
-import org.junit.BeforeClass;
-import org.junit.ClassRule;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.RegisterExtension;
 
-public class PDI_2875_Test {
+class PDI_2875_Test {
   private static TransformMockHelper<TextFileInputMeta, TextFileInputData> smh;
   private static final String VAR_NAME = "VAR";
   private static final String EXPRESSION = "${" + VAR_NAME + "}";
-  @ClassRule public static RestoreHopEngineEnvironment env = new RestoreHopEngineEnvironment();
 
-  @BeforeClass
-  public static void setUp() throws Exception {
+  @RegisterExtension
+  static RestoreHopEngineEnvironmentExtension env = new RestoreHopEngineEnvironmentExtension();
+
+  @BeforeAll
+  static void setUp() throws Exception {
     HopEnvironment.init();
     smh =
         new TransformMockHelper<>("CsvInputTest", TextFileInputMeta.class, TextFileInputData.class);
@@ -50,8 +52,8 @@ public class PDI_2875_Test {
     when(smh.pipeline.isRunning()).thenReturn(true);
   }
 
-  @AfterClass
-  public static void cleanUp() {
+  @AfterAll
+  static void cleanUp() {
     smh.cleanUp();
   }
 
@@ -71,7 +73,7 @@ public class PDI_2875_Test {
   }
 
   @Test
-  public void testVariableSubstitution() {
+  void testVariableSubstitution() {
     doReturn(new Date()).when(smh.pipeline).getExecutionStartDate();
     TextFileInputData data = new TextFileInputData();
     TextFileInputMeta meta = getMeta();
