@@ -17,8 +17,8 @@
 
 package org.apache.hop.pipeline.transforms.fileinput.text;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
@@ -46,7 +46,7 @@ import org.apache.hop.core.row.value.ValueMetaString;
 import org.apache.hop.core.util.Assert;
 import org.apache.hop.core.variables.Variables;
 import org.apache.hop.core.vfs.HopVfs;
-import org.apache.hop.junit.rules.RestoreHopEngineEnvironment;
+import org.apache.hop.junit.rules.RestoreHopEngineEnvironmentExtension;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.PipelineTestingUtil;
@@ -58,16 +58,18 @@ import org.apache.hop.pipeline.transforms.file.IBaseFileInputReader;
 import org.apache.hop.pipeline.transforms.file.IBaseFileInputTransformControl;
 import org.apache.hop.ui.pipeline.transform.common.TextFileLineUtil;
 import org.apache.hop.utils.TestUtils;
-import org.junit.BeforeClass;
-import org.junit.ClassRule;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Timeout;
+import org.junit.jupiter.api.extension.RegisterExtension;
 import org.mockito.Mockito;
 
-public class TextFileInputTest {
-  @ClassRule public static RestoreHopEngineEnvironment env = new RestoreHopEngineEnvironment();
+class TextFileInputTest {
+  @RegisterExtension
+  static RestoreHopEngineEnvironmentExtension env = new RestoreHopEngineEnvironmentExtension();
 
-  @BeforeClass
-  public static void initHop() throws Exception {
+  @BeforeAll
+  static void initHop() throws Exception {
     HopEnvironment.init();
   }
 
@@ -93,7 +95,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void testGetLineDOS() throws HopFileException, UnsupportedEncodingException {
+  void testGetLineDOS() throws HopFileException, UnsupportedEncodingException {
     String input = "col1\tcol2\tcol3\r\ndata1\tdata2\tdata3\r\n";
     String expected = "col1\tcol2\tcol3";
     String output = getInputStreamReader(input, TextFileLineUtil.FILE_FORMAT_DOS, "", "", false);
@@ -101,7 +103,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void testGetLineUnix() throws HopFileException, UnsupportedEncodingException {
+  void testGetLineUnix() throws HopFileException, UnsupportedEncodingException {
     String input = "col1\tcol2\tcol3\ndata1\tdata2\tdata3\n";
     String expected = "col1\tcol2\tcol3";
     String output = getInputStreamReader(input, TextFileLineUtil.FILE_FORMAT_UNIX, "", "", false);
@@ -109,7 +111,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void testGetLineOSX() throws HopFileException, UnsupportedEncodingException {
+  void testGetLineOSX() throws HopFileException, UnsupportedEncodingException {
     String input = "col1\tcol2\tcol3\rdata1\tdata2\tdata3\r";
     String expected = "col1\tcol2\tcol3";
     String output = getInputStreamReader(input, TextFileLineUtil.FILE_FORMAT_UNIX, "", "", false);
@@ -117,7 +119,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void testGetLineMixed() throws HopFileException, UnsupportedEncodingException {
+  void testGetLineMixed() throws HopFileException, UnsupportedEncodingException {
     String input = "col1\tcol2\tcol3\r\ndata1\tdata2\tdata3\r";
     String expected = "col1\tcol2\tcol3";
     String output = getInputStreamReader(input, TextFileLineUtil.FILE_FORMAT_MIXED, "", "", false);
@@ -125,7 +127,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void DOSWithNoBreaksAndEnclosures() throws HopFileException, UnsupportedEncodingException {
+  void DOSWithNoBreaksAndEnclosures() throws HopFileException, UnsupportedEncodingException {
     String input = "col1\tcol2\tcol3\r\ndata1\tdata2\tdata3\r\n";
     String expected = "col1\tcol2\tcol3";
     String output = getInputStreamReader(input, TextFileLineUtil.FILE_FORMAT_DOS, "", "", false);
@@ -134,8 +136,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void mixedWithNoBreaksAndEnclosures()
-      throws HopFileException, UnsupportedEncodingException {
+  void mixedWithNoBreaksAndEnclosures() throws HopFileException, UnsupportedEncodingException {
     String input = "col1\tcol2\tcol3\r\ndata1\tdata2\tdata3\r";
     String expected = "col1\tcol2\tcol3";
     String output = getInputStreamReader(input, TextFileLineUtil.FILE_FORMAT_MIXED, "", "", false);
@@ -144,8 +145,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void UNIXWithNoBreaksAndEnclosures()
-      throws HopFileException, UnsupportedEncodingException {
+  void UNIXWithNoBreaksAndEnclosures() throws HopFileException, UnsupportedEncodingException {
     String input = "col1\tcol2\tcol3\ndata1\tdata2\tdata3\n";
     String expected = "col1\tcol2\tcol3";
     String output = getInputStreamReader(input, TextFileLineUtil.FILE_FORMAT_UNIX, "", "", false);
@@ -154,7 +154,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void DOSWithBreaks() throws Exception {
+  void DOSWithBreaks() throws Exception {
     String input = "col1\tcol2\t'col3\r\ndata1'\r\ndata2\tdata3\r\n";
     String expected = "col1\tcol2\t'col3\r\ndata1'";
     String output = getInputStreamReader(input, TextFileLineUtil.FILE_FORMAT_DOS, "'", "", true);
@@ -163,7 +163,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void DOSWithBreaksAndEscape() throws Exception {
+  void DOSWithBreaksAndEscape() throws Exception {
     String input = "col1\tcol2\t?'col3\r\ndata1'\r\ndata2\tdata3\r\n";
     String expected = "col1\tcol2\t?'col3";
     String output = getInputStreamReader(input, TextFileLineUtil.FILE_FORMAT_DOS, "'", "?", true);
@@ -172,7 +172,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void UNIXWithBreaks() throws Exception {
+  void UNIXWithBreaks() throws Exception {
     String input = "col1\tcol2\t'col3\ndata1'\ndata2\tdata3\n";
     String expected = "col1\tcol2\t'col3\ndata1'";
     String output = getInputStreamReader(input, TextFileLineUtil.FILE_FORMAT_UNIX, "'", "", true);
@@ -181,7 +181,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void UNIXWithBreaksAndEscape() throws Exception {
+  void UNIXWithBreaksAndEscape() throws Exception {
     String input = "col1\tcol2\t?'col3\ndata1'\ndata2\tdata3\n";
     String expected = "col1\tcol2\t?'col3";
     String output = getInputStreamReader(input, TextFileLineUtil.FILE_FORMAT_UNIX, "'", "?", true);
@@ -190,7 +190,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void OSXWithNoBreaksAndEnclosures() throws HopFileException, UnsupportedEncodingException {
+  void OSXWithNoBreaksAndEnclosures() throws HopFileException, UnsupportedEncodingException {
     String input = "col1\tcol2\tcol3\rdata1\tdata2\tdata3\r";
     String expected = "col1\tcol2\tcol3";
     String output = getInputStreamReader(input, TextFileLineUtil.FILE_FORMAT_UNIX, "", "", false);
@@ -199,7 +199,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void OSXWithBreaks() throws Exception {
+  void OSXWithBreaks() throws Exception {
     String input = "col1\tcol2\t'col3\rdata1'\rdata2\tdata3\r";
     String expected = "col1\tcol2\t'col3\rdata1'";
     String output = getInputStreamReader(input, TextFileLineUtil.FILE_FORMAT_UNIX, "'", "", true);
@@ -208,7 +208,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void OSXWithBreaksAndEscape() throws Exception {
+  void OSXWithBreaksAndEscape() throws Exception {
     String input = "col1\tcol2\t?'col3\rdata1'\rdata2\tdata3\r";
     String expected = "col1\tcol2\t?'col3";
     String output = getInputStreamReader(input, TextFileLineUtil.FILE_FORMAT_UNIX, "'", "?", true);
@@ -217,7 +217,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void mixedWithBreaks() throws Exception {
+  void mixedWithBreaks() throws Exception {
     String input = "col1\tcol2\t'col3\r\ndata1'\ndata2\tdata3\r";
     String expected = "col1\tcol2\t'col3\ndata1'";
     String output = getInputStreamReader(input, TextFileLineUtil.FILE_FORMAT_MIXED, "'", "", true);
@@ -226,7 +226,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void mixedWithBreaksAndEscape() throws Exception {
+  void mixedWithBreaksAndEscape() throws Exception {
     String input = "col1\tcol2\t?'col3\r\ndata1'\ndata2\tdata3\r";
     String expected = "col1\tcol2\t?'col3";
     String output = getInputStreamReader(input, TextFileLineUtil.FILE_FORMAT_MIXED, "'", "?", true);
@@ -235,7 +235,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void mixedLongEnclosure() throws Exception {
+  void mixedLongEnclosure() throws Exception {
     String input = "col1\tcol2\tTEST_ENCLOSUREcol3\r\ndata1TEST_ENCLOSURE\ndata2\tdata3\r";
     String expected = "col1\tcol2\tTEST_ENCLOSUREcol3\ndata1TEST_ENCLOSURE";
     String output =
@@ -245,7 +245,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void mixedLongEnclosureAndLongEscape() throws Exception {
+  void mixedLongEnclosureAndLongEscape() throws Exception {
     String input =
         "col1\tcol2\tTEST_ESCAPETEST_ENCLOSUREcol3\r\ndata1TEST_ENCLOSURE\ndata2\tdata3\r";
     String expected = "col1\tcol2\tTEST_ESCAPETEST_ENCLOSUREcol3";
@@ -257,19 +257,18 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void mixedWithOneEnclosure() throws HopFileException, IOException {
+  void mixedWithOneEnclosure() throws HopFileException, IOException {
     String input = "col1\tcol2\t'col3\r\ndata1\r\ndata2\tdata3\r\n";
     InputStreamReader isr = getInputStreamReader(input);
     TextFileLineUtil.getLine(
         null, isr, TextFileLineUtil.FILE_FORMAT_MIXED, new StringBuilder(1000), "'", "", true);
 
-    assertFalse(
-        "Expect false as its at the end of the input not finding another Enclosure or Break",
-        isr.ready());
+    assertFalse(isr.ready());
   }
 
-  @Test(timeout = 100)
-  public void test_PDI695() throws HopFileException, UnsupportedEncodingException {
+  @Test
+  @Timeout(value = 100, unit = java.util.concurrent.TimeUnit.MILLISECONDS)
+  void test_PDI695() throws HopFileException, UnsupportedEncodingException {
     String inputDOS = "col1\tcol2\tcol3\r\ndata1\tdata2\tdata3\r\n";
     String inputUnix = "col1\tcol2\tcol3\ndata1\tdata2\tdata3\n";
     String inputOSX = "col1\tcol2\tcol3\rdata1\tdata2\tdata3\r";
@@ -287,7 +286,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void readWrappedInputWithoutHeaders() throws Exception {
+  void readWrappedInputWithoutHeaders() throws Exception {
     final String content =
         new StringBuilder()
             .append("r1c1")
@@ -321,7 +320,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void readInputWithMissedValues() throws Exception {
+  void readInputWithMissedValues() throws Exception {
     final String virtualFile = createVirtualFile("pdi-14172.txt", "1,1,1\n", "2,,2\n");
 
     BaseFileField field2 = field("col2");
@@ -346,7 +345,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void readInputWithNonEmptyNullif() throws Exception {
+  void readInputWithNonEmptyNullif() throws Exception {
     final String virtualFile = createVirtualFile("pdi-14358.txt", "-,-\n");
 
     BaseFileField col2 = field("col2");
@@ -371,7 +370,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void readInputWithDefaultValues() throws Exception {
+  void readInputWithDefaultValues() throws Exception {
     final String virtualFile = createVirtualFile("pdi-14832.txt", "1,\n");
 
     BaseFileField col2 = field("col2");
@@ -396,7 +395,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void testErrorHandlerLineNumber() throws Exception {
+  void testErrorHandlerLineNumber() throws Exception {
     final String content =
         new StringBuilder()
             .append("123")
@@ -437,7 +436,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void testHandleOpenFileException() throws Exception {
+  void testHandleOpenFileException() throws Exception {
     final String content =
         new StringBuilder().append("123").append('\n').append("333\n").toString();
     final String virtualFile = createVirtualFile("pdi-16697.txt", content);
@@ -472,7 +471,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void test_PDI17117() throws Exception {
+  void test_PDI17117() throws Exception {
     final String virtualFile = createVirtualFile("pdi-14832.txt", "1,\n");
 
     BaseFileField col2 = field("col2");
@@ -523,7 +522,7 @@ public class TextFileInputTest {
   }
 
   @Test
-  public void testClose() throws Exception {
+  void testClose() throws Exception {
 
     TextFileInputMeta mockTFIM = createMetaObject(null);
     String virtualFile = createVirtualFile("pdi-17267.txt", null);
