@@ -26,8 +26,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.ui.core.ConstUi;
 import org.apache.hop.ui.core.PropsUi;
@@ -51,8 +49,8 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.TableItem;
 import org.eclipse.swt.widgets.Text;
 
-public class UniqueRowsByHashSetDialog extends BaseTransformDialog implements ITransformDialog {
-  private static final Class<?> PKG = UniqueRowsByHashSetMeta.class; // For Translator
+public class UniqueRowsByHashSetDialog extends BaseTransformDialog {
+  private static final Class<?> PKG = UniqueRowsByHashSetMeta.class;
 
   private final UniqueRowsByHashSetMeta input;
 
@@ -70,9 +68,12 @@ public class UniqueRowsByHashSetDialog extends BaseTransformDialog implements IT
   private TextVar wErrorDesc;
 
   public UniqueRowsByHashSetDialog(
-      Shell parent, IVariables variables, Object in, PipelineMeta pipelineMeta, String sname) {
-    super(parent, variables, (BaseTransformMeta) in, pipelineMeta, sname);
-    input = (UniqueRowsByHashSetMeta) in;
+      Shell parent,
+      IVariables variables,
+      UniqueRowsByHashSetMeta transformMeta,
+      PipelineMeta pipelineMeta) {
+    super(parent, variables, transformMeta, pipelineMeta);
+    input = transformMeta;
   }
 
   @Override
@@ -94,7 +95,7 @@ public class UniqueRowsByHashSetDialog extends BaseTransformDialog implements IT
     shell.setText(BaseMessages.getString(PKG, "UniqueRowsByHashSetDialog.Shell.Title"));
 
     int middle = props.getMiddlePct();
-    int margin = props.getMargin();
+    int margin = PropsUi.getMargin();
 
     // TransformName line
     wlTransformName = new Label(shell, SWT.RIGHT);
