@@ -31,8 +31,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.ui.core.ConstUi;
 import org.apache.hop.ui.core.PropsUi;
@@ -62,8 +60,8 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.TableItem;
 import org.eclipse.swt.widgets.Text;
 
-public class UpdateDialog extends BaseTransformDialog implements ITransformDialog {
-  private static final Class<?> PKG = UpdateMeta.class; // For Translator
+public class UpdateDialog extends BaseTransformDialog {
+  private static final Class<?> PKG = UpdateMeta.class;
 
   private MetaSelectionLine<DatabaseMeta> wConnection;
 
@@ -99,9 +97,9 @@ public class UpdateDialog extends BaseTransformDialog implements ITransformDialo
   private final List<ColumnInfo> tableFieldColumns = new ArrayList<>();
 
   public UpdateDialog(
-      Shell parent, IVariables variables, Object in, PipelineMeta tr, String sname) {
-    super(parent, variables, (BaseTransformMeta) in, tr, sname);
-    input = (UpdateMeta) in;
+      Shell parent, IVariables variables, UpdateMeta transformMeta, PipelineMeta pipelineMeta) {
+    super(parent, variables, transformMeta, pipelineMeta);
+    input = transformMeta;
   }
 
   public String open() {
@@ -135,7 +133,7 @@ public class UpdateDialog extends BaseTransformDialog implements ITransformDialo
     shell.setText(BaseMessages.getString(PKG, "UpdateDialog.Shell.Title"));
 
     int middle = props.getMiddlePct();
-    int margin = props.getMargin();
+    int margin = PropsUi.getMargin();
 
     // TransformName line
     wlTransformName = new Label(shell, SWT.RIGHT);
@@ -627,7 +625,7 @@ public class UpdateDialog extends BaseTransformDialog implements ITransformDialo
 
     wKey.table.clearAll();
     if (input.getLookupField().getLookupKeys() != null
-        && input.getLookupField().getLookupKeys().size() > 0) {
+        && !input.getLookupField().getLookupKeys().isEmpty()) {
       for (int i = 0; i < input.getLookupField().getLookupKeys().size(); i++) {
         UpdateKeyField keyField = input.getLookupField().getLookupKeys().get(i);
         TableItem item = wKey.table.getItem(i);
@@ -647,7 +645,7 @@ public class UpdateDialog extends BaseTransformDialog implements ITransformDialo
     }
 
     if (input.getLookupField().getUpdateFields() != null
-        && input.getLookupField().getUpdateFields().size() > 0) {
+        && !input.getLookupField().getUpdateFields().isEmpty()) {
       wReturn.table.clearAll();
       for (int i = 0; i < input.getLookupField().getUpdateFields().size(); i++) {
         UpdateField fieldItem = input.getLookupField().getUpdateFields().get(i);
