@@ -17,10 +17,8 @@
 
 package org.apache.hop.pipeline.transforms.vertica.bulkloader.nativebinary;
 
-import java.io.UnsupportedEncodingException;
 import java.nio.ByteBuffer;
 import java.nio.CharBuffer;
-import java.nio.charset.CharacterCodingException;
 import java.nio.charset.CharsetEncoder;
 import java.util.Calendar;
 import java.util.GregorianCalendar;
@@ -157,8 +155,7 @@ public class ColumnSpec {
     this.mainBuffer = buffer;
   }
 
-  public void encode(IValueMeta valueMeta, Object value)
-      throws CharacterCodingException, UnsupportedEncodingException, HopValueException {
+  public void encode(IValueMeta valueMeta, Object value) throws HopValueException {
     if (value == null || valueMeta == null || valueMeta.getNativeDataType(value) == null) {
       return;
     }
@@ -317,7 +314,6 @@ public class ColumnSpec {
 
       default:
         throw new IllegalArgumentException("Invalid ColumnType");
-        // break;
     }
   }
 
@@ -349,8 +345,7 @@ public class ColumnSpec {
     int y = year + 4800 - a;
     int m = month + 12 * a - 3;
     // since the order number is computed, there's no need to use floating point types
-    int jdn = day + (153 * m + 2) / 5 + 365 * y + y / 4 - y / 100 + y / 400 - 32045;
-    return jdn;
+    return day + (153 * m + 2) / 5 + 365 * y + y / 4 - y / 100 + y / 400 - 32045;
   }
 
   /**
