@@ -23,8 +23,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.dialog.ErrorDialog;
@@ -43,8 +41,8 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
-public class WebServiceAvailableDialog extends BaseTransformDialog implements ITransformDialog {
-  private static final Class<?> PKG = WebServiceAvailableMeta.class; // For Translator
+public class WebServiceAvailableDialog extends BaseTransformDialog {
+  private static final Class<?> PKG = WebServiceAvailableMeta.class;
 
   private CCombo wURL;
 
@@ -59,9 +57,12 @@ public class WebServiceAvailableDialog extends BaseTransformDialog implements IT
   private boolean gotPreviousFields = false;
 
   public WebServiceAvailableDialog(
-      Shell parent, IVariables variables, Object in, PipelineMeta pipelineMeta, String sname) {
-    super(parent, variables, (BaseTransformMeta) in, pipelineMeta, sname);
-    input = (WebServiceAvailableMeta) in;
+      Shell parent,
+      IVariables variables,
+      WebServiceAvailableMeta transformMeta,
+      PipelineMeta pipelineMeta) {
+    super(parent, variables, transformMeta, pipelineMeta);
+    input = transformMeta;
   }
 
   @Override
@@ -84,7 +85,7 @@ public class WebServiceAvailableDialog extends BaseTransformDialog implements IT
     shell.setText(BaseMessages.getString(PKG, "WebServiceAvailableDialog.Shell.Title"));
 
     int middle = props.getMiddlePct();
-    int margin = props.getMargin();
+    int margin = PropsUi.getMargin();
 
     // TransformName line
     wlTransformName = new Label(shell, SWT.RIGHT);
