@@ -39,7 +39,8 @@ import org.apache.hop.pipeline.transform.TransformMeta;
     image = "webserviceavailable.svg",
     name = "i18n::WebServiceAvailable.Name",
     description = "i18n::WebServiceAvailable.Description",
-    categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Transform",
+    categoryDescription =
+        "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Validation",
     keywords = "i18n::WebServiceAvailableMeta.keyword",
     documentationUrl = "/pipeline/transforms/checkwebserviceavailable.html")
 public class WebServiceAvailableMeta
