@@ -189,7 +189,7 @@ public class WebServiceMeta extends BaseTransformMeta<WebService, WebServiceData
       IVariables variables,
       IHopMetadataProvider metadataProvider) {
     CheckResult cr;
-    if (prev == null || prev.size() == 0) {
+    if (prev == null || prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_WARNING,
@@ -410,7 +410,7 @@ public class WebServiceMeta extends BaseTransformMeta<WebService, WebServiceData
   }
 
   public boolean hasFieldsIn() {
-    return fieldsIn != null && !fieldsIn.isEmpty();
+    return !Utils.isEmpty(fieldsIn);
   }
 
   public void addFieldIn(WebServiceField field) {
