@@ -150,10 +150,9 @@ public class WorkflowExecutor extends BaseTransform<WorkflowExecutorMeta, Workfl
       if (data.groupSize < 0) {
         if (data.groupFieldIndex >= 0) { // grouping by field
           Object groupFieldData = row[data.groupFieldIndex];
-          if (data.prevGroupFieldData != null) {
-            if (data.groupFieldMeta.compare(data.prevGroupFieldData, groupFieldData) != 0) {
-              executeWorkflow();
-            }
+          if (data.prevGroupFieldData != null
+              && data.groupFieldMeta.compare(data.prevGroupFieldData, groupFieldData) != 0) {
+            executeWorkflow();
           }
           data.prevGroupFieldData = groupFieldData;
         } else if (data.groupTime > 0) { // grouping by execution time
@@ -171,11 +170,9 @@ public class WorkflowExecutor extends BaseTransform<WorkflowExecutorMeta, Workfl
 
       // Grouping by size.
       // If group buffer size exceeds specified limit, then execute workflow and flush group buffer.
-      if (data.groupSize > 0) {
+      if (data.groupSize > 0 && data.groupBuffer.size() >= data.groupSize) {
         // Pass all input rows...
-        if (data.groupBuffer.size() >= data.groupSize) {
-          executeWorkflow();
-        }
+        executeWorkflow();
       }
 
       return true;
@@ -232,7 +229,7 @@ public class WorkflowExecutor extends BaseTransform<WorkflowExecutorMeta, Workfl
         outputRow[idx++] = Long.valueOf(System.currentTimeMillis() - data.groupTimeStart);
       }
       if (!Utils.isEmpty(meta.getExecutionResultField())) {
-        outputRow[idx++] = Boolean.valueOf(result.getResult());
+        outputRow[idx++] = Boolean.valueOf(result.isResult());
       }
       if (!Utils.isEmpty(meta.getExecutionNrErrorsField())) {
         outputRow[idx++] = Long.valueOf(result.getNrErrors());
@@ -295,7 +292,7 @@ public class WorkflowExecutor extends BaseTransform<WorkflowExecutorMeta, Workfl
 
             if (idx == -1) {
               missingFields +=
-                  (missingFields.length() > 0 ? "," : "")
+                  (!missingFields.isEmpty() ? "," : "")
                       + meta.getResultRowsField().get(i).getName();
             }
 
@@ -306,18 +303,18 @@ public class WorkflowExecutor extends BaseTransform<WorkflowExecutorMeta, Workfl
                     != ValueMetaFactory.getIdForValueMeta(
                         meta.getResultRowsField().get(i).getType())) {
               expectedTypes +=
-                  (expectedTypes.length() > 0 ? "," : "")
+                  (!expectedTypes.isEmpty() ? "," : "")
                       + meta.getResultRowsField().get(i).getType();
-              currentTypes += (currentTypes.length() > 0 ? "," : "") + valueMeta.getTypeDesc();
+              currentTypes += (!currentTypes.isEmpty() ? "," : "") + valueMeta.getTypeDesc();
             }
           }
           rowConsistencyChecked = true;
 
-          if (missingFields.length() > 0) {
+          if (!missingFields.isEmpty()) {
             logError("Unable to find required fields [" + missingFields + "] in result row!");
           }
 
-          if (currentTypes.length() > 0) {
+          if (!currentTypes.isEmpty()) {
             logError(
                 BaseMessages.getString(
                     PKG, "WorkflowExecutor.IncorrectDataTypePassed", currentTypes, expectedTypes));
