@@ -17,6 +17,13 @@
 
 package org.apache.hop.pipeline.transforms.xml.getxmldata;
 
+import static org.apache.hop.pipeline.transforms.xml.getxmldata.GetXmlDataField.getElementTypeByDesc;
+import static org.apache.hop.pipeline.transforms.xml.getxmldata.GetXmlDataField.getElementTypeDesc;
+import static org.apache.hop.pipeline.transforms.xml.getxmldata.GetXmlDataField.getResultTypeByDesc;
+import static org.apache.hop.pipeline.transforms.xml.getxmldata.GetXmlDataField.getResultTypeCode;
+import static org.apache.hop.pipeline.transforms.xml.getxmldata.GetXmlDataField.getTrimTypeByDesc;
+import static org.apache.hop.pipeline.transforms.xml.getxmldata.GetXmlDataField.getTrimTypeCode;
+
 import java.io.InputStream;
 import java.nio.charset.Charset;
 import java.util.ArrayList;
@@ -1006,7 +1013,7 @@ public class GetXmlDataDialog extends BaseTransformDialog {
 
     setButtonPositions(new Button[] {wGet, wGetSnippet}, margin, null);
 
-    final int FieldsRows = input.getInputFields().length;
+    final int FieldsRows = input.getInputFields().size();
 
     ColumnInfo[] colinf =
         new ColumnInfo[] {
@@ -1480,7 +1487,7 @@ public class GetXmlDataDialog extends BaseTransformDialog {
               new LoopNodesImportProgressDialog(shell, url, readUrlPdOption);
           populateLoopPaths(url, pd);
 
-        } else if (meta.getIsAFile()) {
+        } else if (meta.isAFile()) {
           // Read file
           String str = xmlSource;
           if (str == null) {
@@ -1605,7 +1612,7 @@ public class GetXmlDataDialog extends BaseTransformDialog {
                   shell, url, variables.resolve(meta.getLoopXPath()), readUrlPdOption);
           populateFields(prd, clearFields);
 
-        } else if (meta.getIsAFile()) {
+        } else if (meta.isAFile()) {
           // Read file
           String str = xmlSource;
           if (str == null) {
@@ -1710,39 +1717,37 @@ public class GetXmlDataDialog extends BaseTransformDialog {
    * @param in The TextFileInputMeta object to obtain the data from.
    */
   public void getData(GetXmlDataMeta in) {
-    if (in.getFileName() != null) {
+    if (in.getFilesList() != null) {
       wFilenameList.removeAll();
 
-      for (int i = 0; i < in.getFileName().length; i++) {
+      for (GetXmlFileItem file : in.getFilesList()) {
         wFilenameList.add(
-            new String[] {
-              in.getFileName()[i],
-              in.getFileMask()[i],
-              in.getExludeFileMask()[i],
-              in.getRequiredFilesDesc(in.getFileRequired()[i]),
-              in.getRequiredFilesDesc(in.getIncludeSubFolders()[i])
-            });
+            file.getFileName(),
+            file.getFileMask(),
+            file.getExcludeFileMask(),
+            in.getRequiredFilesDesc(file.getFileRequired()),
+            in.getRequiredFilesDesc(file.getIncludeSubFolders()));
       }
 
       wFilenameList.removeEmptyRows();
       wFilenameList.setRowNums();
       wFilenameList.optWidth(true);
     }
-    wInclFilename.setSelection(in.includeFilename());
-    wInclRownum.setSelection(in.includeRowNumber());
-    wAddResult.setSelection(in.addResultFile());
-    wNameSpaceAware.setSelection(in.isNamespaceAware());
+    wInclFilename.setSelection(in.isIncludeFilename());
+    wInclRownum.setSelection(in.isIncludeRowNumber());
+    wAddResult.setSelection(in.isAddResultFile());
+    wNameSpaceAware.setSelection(in.isNameSpaceAware());
     wReadUrl.setSelection(in.isReadUrl());
     wIgnoreComment.setSelection(in.isIgnoreComments());
     wValidating.setSelection(in.isValidating());
-    wUseToken.setSelection(in.isuseToken());
+    wUseToken.setSelection(in.isUseToken());
     wIgnoreEmptyFile.setSelection(in.isIgnoreEmptyFile());
-    wDoNotFailIfNoFile.setSelection(in.isdoNotFailIfNoFile());
+    wDoNotFailIfNoFile.setSelection(in.isDoNotFailIfNoFile());
     wXMLStreamField.setSelection(in.isInFields());
-    wXMLIsAFile.setSelection(in.getIsAFile());
+    wXMLIsAFile.setSelection(in.isAFile());
 
-    if (in.getXMLField() != null) {
-      wXMLField.setText(in.getXMLField());
+    if (in.getXmlField() != null) {
+      wXMLField.setText(in.getXmlField());
     }
 
     if (in.getFilenameField() != null) {
@@ -1765,8 +1770,8 @@ public class GetXmlDataDialog extends BaseTransformDialog {
     }
 
     logDebug(BaseMessages.getString(PKG, "GetXMLDataDialog.Log.GettingFieldsInfo"));
-    for (int i = 0; i < in.getInputFields().length; i++) {
-      GetXmlDataField field = in.getInputFields()[i];
+    for (int i = 0; i < in.getInputFields().size(); i++) {
+      GetXmlDataField field = in.getInputFields().get(i);
 
       if (field != null) {
         TableItem item = wFields.table.getItem(i);
@@ -1783,7 +1788,7 @@ public class GetXmlDataDialog extends BaseTransformDialog {
         String decim = field.getDecimalSymbol();
         String trim = field.getTrimTypeDesc();
         String rep =
-            field.isRepeated()
+            field.isRepeat()
                 ? BaseMessages.getString(PKG, CONST_SYSTEM_COMBO_YES)
                 : BaseMessages.getString(PKG, "System.Combo.No");
 
@@ -1833,29 +1838,29 @@ public class GetXmlDataDialog extends BaseTransformDialog {
     wFields.setRowNums();
     wFields.optWidth(true);
 
-    if (in.getShortFileNameField() != null) {
-      wShortFileFieldName.setText(in.getShortFileNameField());
+    if (in.getShortFileFieldName() != null) {
+      wShortFileFieldName.setText(in.getShortFileFieldName());
     }
-    if (in.getPathField() != null) {
-      wPathFieldName.setText(in.getPathField());
+    if (in.getPathFieldName() != null) {
+      wPathFieldName.setText(in.getPathFieldName());
     }
-    if (in.isHiddenField() != null) {
-      wIsHiddenName.setText(in.isHiddenField());
+    if (in.getHiddenFieldName() != null) {
+      wIsHiddenName.setText(in.getHiddenFieldName());
     }
-    if (in.getLastModificationDateField() != null) {
-      wLastModificationTimeName.setText(in.getLastModificationDateField());
+    if (in.getLastModificationTimeFieldName() != null) {
+      wLastModificationTimeName.setText(in.getLastModificationTimeFieldName());
     }
-    if (in.getUriField() != null) {
-      wUriName.setText(in.getUriField());
+    if (in.getUriNameFieldName() != null) {
+      wUriName.setText(in.getUriNameFieldName());
     }
-    if (in.getRootUriField() != null) {
-      wRootUriName.setText(in.getRootUriField());
+    if (in.getRootUriNameFieldName() != null) {
+      wRootUriName.setText(in.getRootUriNameFieldName());
     }
-    if (in.getExtensionField() != null) {
-      wExtensionFieldName.setText(in.getExtensionField());
+    if (in.getExtensionFieldName() != null) {
+      wExtensionFieldName.setText(in.getExtensionFieldName());
     }
-    if (in.getSizeField() != null) {
-      wSizeFieldName.setText(in.getSizeField());
+    if (in.getSizeFieldName() != null) {
+      wSizeFieldName.setText(in.getSizeFieldName());
     }
 
     wTransformName.selectAll();
@@ -1900,28 +1905,34 @@ public class GetXmlDataDialog extends BaseTransformDialog {
     in.setAddResultFile(wAddResult.getSelection());
     in.setIncludeFilename(wInclFilename.getSelection());
     in.setIncludeRowNumber(wInclRownum.getSelection());
-    in.setNamespaceAware(wNameSpaceAware.getSelection());
+    in.setNameSpaceAware(wNameSpaceAware.getSelection());
     in.setReadUrl(wReadUrl.getSelection());
     in.setIgnoreComments(wIgnoreComment.getSelection());
     in.setValidating(wValidating.getSelection());
-    in.setuseToken(wUseToken.getSelection());
+    in.setUseToken(wUseToken.getSelection());
     in.setIgnoreEmptyFile(wIgnoreEmptyFile.getSelection());
-    in.setdoNotFailIfNoFile(wDoNotFailIfNoFile.getSelection());
+    in.setDoNotFailIfNoFile(wDoNotFailIfNoFile.getSelection());
 
     in.setInFields(wXMLStreamField.getSelection());
-    in.setIsAFile(wXMLIsAFile.getSelection());
-    in.setXMLField(wXMLField.getText());
+    in.setAFile(wXMLIsAFile.getSelection());
+    in.setXmlField(wXMLField.getText());
 
     int nrFiles = wFilenameList.getItemCount();
     int nrFields = wFields.nrNonEmpty();
 
-    in.allocate(nrFiles, nrFields);
-    in.setFileName(wFilenameList.getItems(0));
-    in.setFileMask(wFilenameList.getItems(1));
-    in.setExcludeFileMask(wFilenameList.getItems(2));
-    in.setFileRequired(wFilenameList.getItems(3));
-    in.setIncludeSubFolders(wFilenameList.getItems(4));
+    in.getFilesList().clear();
+    for (int i = 0; i < wFilenameList.getItemCount(); i++) {
+      GetXmlFileItem fi =
+          new GetXmlFileItem(
+              wFilenameList.getItem(i, 1),
+              wFilenameList.getItem(i, 2),
+              wFilenameList.getItem(i, 3),
+              wFilenameList.getItem(i, 4),
+              wFilenameList.getItem(i, 5));
+      in.getFilesList().add(fi);
+    }
 
+    in.getInputFields().clear();
     for (int i = 0; i < nrFields; i++) {
       GetXmlDataField field = new GetXmlDataField();
 
@@ -1929,29 +1940,29 @@ public class GetXmlDataDialog extends BaseTransformDialog {
 
       field.setName(item.getText(1));
       field.setXPath(item.getText(2));
-      field.setElementType(GetXmlDataField.getElementTypeByDesc(item.getText(3)));
-      field.setResultType(GetXmlDataField.getResultTypeByDesc(item.getText(4)));
-      field.setType(ValueMetaBase.getType(item.getText(5)));
+      field.setElementType(getElementTypeDesc(getElementTypeByDesc(item.getText(3))));
+      field.setResultType(getResultTypeCode(getResultTypeByDesc(item.getText(4))));
+      field.setType(ValueMetaBase.getTypeDesc(ValueMetaBase.getType(item.getText(5))));
       field.setFormat(item.getText(6));
       field.setLength(Const.toInt(item.getText(7), -1));
       field.setPrecision(Const.toInt(item.getText(8), -1));
       field.setCurrencySymbol(item.getText(9));
       field.setDecimalSymbol(item.getText(10));
       field.setGroupSymbol(item.getText(11));
-      field.setTrimType(GetXmlDataField.getTrimTypeByDesc(item.getText(12)));
-      field.setRepeated(
+      field.setTrimType(getTrimTypeCode(getTrimTypeByDesc(item.getText(12))));
+      field.setRepeat(
           BaseMessages.getString(PKG, CONST_SYSTEM_COMBO_YES).equalsIgnoreCase(item.getText(13)));
 
-      in.getInputFields()[i] = field;
+      in.getInputFields().add(field);
     }
-    in.setShortFileNameField(wShortFileFieldName.getText());
-    in.setPathField(wPathFieldName.getText());
-    in.setIsHiddenField(wIsHiddenName.getText());
-    in.setLastModificationDateField(wLastModificationTimeName.getText());
-    in.setUriField(wUriName.getText());
-    in.setRootUriField(wRootUriName.getText());
-    in.setExtensionField(wExtensionFieldName.getText());
-    in.setSizeField(wSizeFieldName.getText());
+    in.setShortFileFieldName(wShortFileFieldName.getText());
+    in.setPathFieldName(wPathFieldName.getText());
+    in.setHiddenFieldName(wIsHiddenName.getText());
+    in.setLastModificationTimeFieldName(wLastModificationTimeName.getText());
+    in.setUriNameFieldName(wUriName.getText());
+    in.setRootUriNameFieldName(wRootUriName.getText());
+    in.setExtensionFieldName(wExtensionFieldName.getText());
+    in.setSizeFieldName(wSizeFieldName.getText());
   }
 
   // check if the loop xpath is given
