@@ -365,7 +365,7 @@ public class XsltMeta extends BaseTransformMeta<Xslt, XsltData> {
       IHopMetadataProvider metadataProvider) {
     CheckResult cr;
 
-    if (prev != null && prev.size() > 0) {
+    if (prev != null && !prev.isEmpty()) {
       cr =
           new CheckResult(
               ICheckResult.TYPE_RESULT_OK,
