@@ -22,6 +22,7 @@ import org.apache.hop.core.RowMetaAndData;
 import org.apache.hop.core.exception.HopValueException;
 import org.apache.hop.core.row.IRowMeta;
 import org.apache.hop.core.row.IValueMeta;
+import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.PropsUi;
@@ -96,7 +97,7 @@ public class SelectRowDialog extends Dialog {
 
     // Simply exit and close in case we don't have anything to edit or show
     //
-    if (buffer == null || buffer.isEmpty()) {
+    if (Utils.isEmpty(buffer)) {
       return null;
     }
 
