@@ -128,7 +128,6 @@ public class GuiResource {
   private Map<String, Image> imagesDatabase;
 
   private SwtUniversalImage imageLogo;
-  private SwtUniversalImage imageDisabledHop;
   private SwtUniversalImage imageDatabase;
   private SwtUniversalImage imageData;
   private SwtUniversalImage imagePreview;
@@ -144,14 +143,10 @@ public class GuiResource {
   private SwtUniversalImage imageArrowError;
   private SwtUniversalImage imageArrowDisabled;
   private SwtUniversalImage imageArrowCandidate;
-  private SwtUniversalImage imageBol;
   private SwtUniversalImage imageServer;
-  private SwtUniversalImage imageArrow;
   private SwtUniversalImage imageFolder;
   private SwtUniversalImage imageFile;
-  private SwtUniversalImage imageFolderConnections;
   private SwtUniversalImage imageEdit;
-  private SwtUniversalImage imageClearText;
   private SwtUniversalImage imageCopyRows;
   private SwtUniversalImage imageCopyRowsDisabled;
   private SwtUniversalImage imageFailure;
@@ -170,7 +165,6 @@ public class GuiResource {
   private SwtUniversalImage imageTrueDisabled;
   private SwtUniversalImage imageFalse;
   private SwtUniversalImage imageFalseDisabled;
-  private SwtUniversalImage imageContextMenu;
   private SwtUniversalImage imageUnconditional;
   private SwtUniversalImage imageUnconditionalDisabled;
   private SwtUniversalImage imageParallel;
@@ -192,7 +186,6 @@ public class GuiResource {
   @Getter private Image imageCheck;
   @Getter private Image imageClear;
   @Getter private Image imageClose;
-  @Getter private Image imageClosePanel;
   @Getter private Image imageCollapseAll;
   @Getter private Image imageColor;
   @Getter private Image imageCopy;
@@ -200,7 +193,6 @@ public class GuiResource {
   @Getter private Image imageDelete;
   @Getter private Image imageDown;
   @Getter private Image imageDuplicate;
-  @Getter private Image imageEditOption;
   @Getter private Image imageEmpty;
   @Getter private Image imageExpandAll;
   @Getter private Image imageFunction;
@@ -218,7 +210,6 @@ public class GuiResource {
   @Getter private Image imageNew;
   @Getter private Image imageNote;
   @Getter private Image imageOptions;
-  @Getter private Image imagePalette;
   @Getter private Image imagePaste;
   @Getter private Image imagePause;
   @Getter private Image imagePlugin;
@@ -419,13 +410,10 @@ public class GuiResource {
 
     // Common images
     imageLogo.dispose();
-    imageDisabledHop.dispose();
     imageDatabase.dispose();
     imageData.dispose();
     imagePreview.dispose();
-    imageBol.dispose();
     imageServer.dispose();
-    imageArrow.dispose();
     imageFile.dispose();
     imageFolder.dispose();
     imageMissing.dispose();
@@ -433,7 +421,6 @@ public class GuiResource {
     imagePipeline.dispose();
     imagePartitionSchema.dispose();
     imageWorkflow.dispose();
-    imageFolderConnections.dispose();
     imageCopyRows.dispose();
     imageCopyRowsDisabled.dispose();
     imageError.dispose();
@@ -441,7 +428,6 @@ public class GuiResource {
     imageInfo.dispose();
     imageInfoDisabled.dispose();
     imageWarning.dispose();
-    imageClearText.dispose();
     imageDeprecated.dispose();
     imageExpandAll.dispose();
     imageSearch.dispose();
@@ -459,7 +445,6 @@ public class GuiResource {
     imageFalseDisabled.dispose();
     imageFailure.dispose();
     imageSuccess.dispose();
-    imageContextMenu.dispose();
     imageParallel.dispose();
     imageParallelDisabled.dispose();
     imageUnconditional.dispose();
@@ -487,7 +472,6 @@ public class GuiResource {
     disposeImage(imageCheck);
     disposeImage(imageClear);
     disposeImage(imageClose);
-    disposeImage(imageClosePanel);
     disposeImage(imageCollapseAll);
     disposeImage(imageColor);
     disposeImage(imageCopy);
@@ -495,7 +479,6 @@ public class GuiResource {
     disposeImage(imageDelete);
     disposeImage(imageDown);
     disposeImage(imageDuplicate);
-    disposeImage(imageEditOption);
     disposeImage(imageFunction);
     disposeImage(imageHelp);
     disposeImage(imageHide);
@@ -716,16 +699,14 @@ public class GuiResource {
     imageCalendar = loadAsResource(display, "ui/images/calendar.svg", ConstUi.SMALL_ICON_SIZE);
     imageCatalog = loadAsResource(display, "ui/images/catalog.svg", ConstUi.SMALL_ICON_SIZE);
     imageCheck = loadAsResource(display, "ui/images/check.svg", ConstUi.SMALL_ICON_SIZE);
-    imageClosePanel = loadAsResource(display, "ui/images/close-panel.svg", ConstUi.SMALL_ICON_SIZE);
     imageCollapseAll =
         loadAsResource(display, "ui/images/collapse-all.svg", ConstUi.SMALL_ICON_SIZE);
-    imageColor = loadAsResource(display, "ui/images/edit_option.svg", ConstUi.SMALL_ICON_SIZE);
+    imageColor = loadAsResource(display, "ui/images/color.svg", ConstUi.SMALL_ICON_SIZE);
     imageCancel = loadAsResource(display, "ui/images/cancel.svg", ConstUi.SMALL_ICON_SIZE);
     imageCopy = loadAsResource(display, "ui/images/copy.svg", ConstUi.SMALL_ICON_SIZE);
     imageCut = loadAsResource(display, "ui/images/cut.svg", ConstUi.SMALL_ICON_SIZE);
     imageDuplicate = loadAsResource(display, "ui/images/duplicate.svg", ConstUi.SMALL_ICON_SIZE);
     imagePaste = loadAsResource(display, "ui/images/paste.svg", ConstUi.SMALL_ICON_SIZE);
-    imageEditOption = loadAsResource(display, "ui/images/edit_option.svg", ConstUi.SMALL_ICON_SIZE);
     imageExpandAll = loadAsResource(display, "ui/images/expand-all.svg", ConstUi.SMALL_ICON_SIZE);
     imageLabel = loadAsResource(display, "ui/images/label.svg", ConstUi.SMALL_ICON_SIZE);
     imageFunction = loadAsResource(display, "ui/images/function.svg", ConstUi.SMALL_ICON_SIZE);
@@ -786,7 +767,6 @@ public class GuiResource {
     imageUp = loadAsResource(display, "ui/images/up.svg", ConstUi.SMALL_ICON_SIZE);
     imageLocation = loadAsResource(display, "ui/images/location.svg", ConstUi.SMALL_ICON_SIZE);
     imageOptions = loadAsResource(display, "ui/images/options.svg", ConstUi.SMALL_ICON_SIZE);
-    imagePalette = loadAsResource(display, "ui/images/palette.svg", ConstUi.SMALL_ICON_SIZE);
     imageUndo = loadAsResource(display, "ui/images/undo.svg", ConstUi.SMALL_ICON_SIZE);
     imageRedo = loadAsResource(display, "ui/images/redo.svg", ConstUi.SMALL_ICON_SIZE);
     imageClear = loadAsResource(display, "ui/images/clear.svg", ConstUi.SMALL_ICON_SIZE);
@@ -817,8 +797,6 @@ public class GuiResource {
     imageMissing = SwtSvgImageUtil.getImageAsResource(display, "ui/images/missing.svg");
     imageDeprecated = SwtSvgImageUtil.getImageAsResource(display, "ui/images/deprecated.svg");
     imageLocked = SwtSvgImageUtil.getImageAsResource(display, "ui/images/lock.svg");
-    imageBol = SwtSvgImageUtil.getImageAsResource(display, "ui/images/bol.svg");
-    imageClearText = SwtSvgImageUtil.getImageAsResource(display, "ui/images/clear-text.svg");
     imageCopyRows = SwtSvgImageUtil.getImageAsResource(display, "ui/images/copy-rows.svg");
     imageCopyRowsDisabled =
         SwtSvgImageUtil.getImageAsResource(display, "ui/images/copy-rows-disabled.svg");
@@ -836,7 +814,6 @@ public class GuiResource {
     imageTarget = SwtSvgImageUtil.getImageAsResource(display, "ui/images/target.svg");
     imageTargetDisabled =
         SwtSvgImageUtil.getImageAsResource(display, "ui/images/target-disabled.svg");
-    imageContextMenu = SwtSvgImageUtil.getImageAsResource(display, "ui/images/context_menu.svg");
     imageParallel = SwtSvgImageUtil.getImageAsResource(display, "ui/images/parallel-hop.svg");
     imageParallelDisabled =
         SwtSvgImageUtil.getImageAsResource(display, "ui/images/parallel-hop-disabled.svg");
@@ -848,10 +825,6 @@ public class GuiResource {
     imageInject = SwtSvgImageUtil.getImageAsResource(display, "ui/images/inject.svg");
     imageBalance = SwtSvgImageUtil.getImageAsResource(display, "ui/images/scales.svg");
     imageCheckpoint = SwtSvgImageUtil.getImageAsResource(display, "ui/images/checkpoint.svg");
-    imageArrow = SwtSvgImageUtil.getImageAsResource(display, "ui/images/arrow.svg");
-    imageFolderConnections =
-        SwtSvgImageUtil.getImageAsResource(display, "ui/images/folder_connection.svg");
-    imageDisabledHop = SwtSvgImageUtil.getImageAsResource(display, "ui/images/DHOP.svg");
 
     // Hop arrow
     //
@@ -979,10 +952,14 @@ public class GuiResource {
   }
 
   /**
+   * Use the image folder instead.
+   *
    * @return Returns the imageBol.
    */
+  @Deprecated
   public Image getImageBol() {
-    return imageBol.getAsBitmapForSize(display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
+    return imageFolder.getAsBitmapForSize(
+        display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
   }
 
   /**
@@ -1042,14 +1019,6 @@ public class GuiResource {
     return imageLogo.getAsBitmapForSize(display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
   }
 
-  /**
-   * @return Returns the imageDisabledHop.
-   */
-  public Image getImageDisabledHop() {
-    return imageDisabledHop.getAsBitmapForSize(
-        display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
-  }
-
   /**
    * @return Returns the imagesTransforms.
    */
@@ -1182,7 +1151,7 @@ public class GuiResource {
   }
 
   public Image getImageVariableMini() {
-    return getZoomedImaged(imageVariable, display, 10, 10);
+    return getZoomedImaged(imageVariable, display, 12, 12);
   }
 
   public Image getImagePipeline() {
@@ -1190,6 +1159,12 @@ public class GuiResource {
         imagePipeline, display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
   }
 
+  @Deprecated
+  public Image getImageClosePanel() {
+    return imageClose;
+  }
+
+  @Deprecated
   public Image getImageFolderConnections() {
     return getZoomedImaged(
         imagePipeline, display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
@@ -1205,21 +1180,6 @@ public class GuiResource {
         imageWorkflow, display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
   }
 
-  public Image getEditOptionButton() {
-    return imageEditOption;
-  }
-
-  /**
-   * @return the imageArrow
-   */
-  public Image getImageArrow() {
-    return getZoomedImaged(imageArrow, display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
-  }
-
-  public SwtUniversalImage getSwtImageArrow() {
-    return imageArrow;
-  }
-
   /**
    * @return the imageArrow
    */
@@ -1293,11 +1253,6 @@ public class GuiResource {
     return fontMediumBold.getFont();
   }
 
-  public Image getImageClearText() {
-    return getZoomedImaged(
-        imageClearText, display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
-  }
-
   public Image getImageCopyHop() {
     return getZoomedImaged(
         imageCopyRows, display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
@@ -1584,18 +1539,6 @@ public class GuiResource {
     return imageSuccess;
   }
 
-  /**
-   * @return the imageContextMenu
-   */
-  public Image getImageContextMenu() {
-    return getZoomedImaged(
-        imageContextMenu, display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
-  }
-
-  public SwtUniversalImage getSwtImageContextMenu() {
-    return imageContextMenu;
-  }
-
   public Image getImageParallelHop() {
     return getZoomedImaged(
         imageParallel, display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
