@@ -21,6 +21,7 @@ import java.util.Collections;
 import java.util.List;
 import org.apache.commons.lang.StringUtils;
 import org.apache.hop.core.Const;
+import org.apache.hop.core.Props;
 import org.apache.hop.core.exception.HopException;
 import org.apache.hop.core.gui.plugin.GuiPlugin;
 import org.apache.hop.core.gui.plugin.toolbar.GuiToolbarElement;
@@ -51,6 +52,7 @@ import org.eclipse.swt.layout.FormLayout;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
 import org.eclipse.swt.widgets.Label;
+import org.eclipse.swt.widgets.Listener;
 import org.eclipse.swt.widgets.ToolBar;
 
 /**
@@ -61,7 +63,7 @@ import org.eclipse.swt.widgets.ToolBar;
  */
 @GuiPlugin
 public class MetaSelectionLine<T extends IHopMetadata> extends Composite {
-  private static final Class<?> PKG = MetaSelectionLine.class; // For Translator
+  private static final Class<?> PKG = MetaSelectionLine.class;
 
   public static final String GUI_PLUGIN_TOOLBAR_PARENT_ID = "MetaSelectionLine-Toolbar";
   public static final String TOOLBAR_ITEM_EDIT = "10010-metadata-edit";
@@ -183,12 +185,12 @@ public class MetaSelectionLine<T extends IHopMetadata> extends Composite {
             metadata.image(),
             (int) (ConstUi.SMALL_ICON_SIZE * props.getZoomFactor()),
             (int) (ConstUi.SMALL_ICON_SIZE * props.getZoomFactor()));
-    addListener(SWT.Dispose, e -> editImage.dispose());
+    super.addListener(SWT.Dispose, e -> editImage.dispose());
 
     // Toolbar for default actions
     //
     wToolBar = new ToolBar(this, SWT.FLAT | SWT.HORIZONTAL);
-    PropsUi.setLook(wToolBar, PropsUi.WIDGET_STYLE_DEFAULT);
+    PropsUi.setLook(wToolBar, Props.WIDGET_STYLE_DEFAULT);
     FormData fdToolBar = new FormData();
     fdToolBar.right = new FormAttachment(100, 0);
     fdToolBar.top = new FormAttachment(0, 0);
@@ -199,7 +201,6 @@ public class MetaSelectionLine<T extends IHopMetadata> extends Composite {
     GuiToolbarWidgets toolbarWidgets = new GuiToolbarWidgets();
     toolbarWidgets.registerGuiPluginObject(this);
     // Removed for Windows dark mode
-    // toolbarWidgets.setItemBackgroundColor(GuiResource.getInstance().getColorBackground());
     toolbarWidgets.createToolbarWidgets(wToolBar, GUI_PLUGIN_TOOLBAR_PARENT_ID);
 
     int textFlags = SWT.SINGLE | SWT.LEFT | SWT.BORDER;
@@ -279,7 +280,9 @@ public class MetaSelectionLine<T extends IHopMetadata> extends Composite {
     return managedClass.getAnnotation(HopMetadata.class).name();
   }
 
-  protected void manageMetadata() {}
+  protected void manageMetadata() {
+    // Do nothing
+  }
 
   /**
    * We look at the managed class name, add Dialog to it and then simply us that class to edit the
@@ -343,8 +346,8 @@ public class MetaSelectionLine<T extends IHopMetadata> extends Composite {
    *
    * @param parent the parent composite object
    * @param previous the previous control
-   * @param
-   * @return the combo box UI component
+   * @param selected
+   * @param lsMod
    */
   public void addToConnectionLine(
       Composite parent, Control previous, T selected, ModifyListener lsMod) {
@@ -375,13 +378,18 @@ public class MetaSelectionLine<T extends IHopMetadata> extends Composite {
     fdConnection.left = new FormAttachment(0, 0);
     fdConnection.right = new FormAttachment(100, 0);
     if (previous != null) {
-      fdConnection.top = new FormAttachment(previous, props.getMargin());
+      fdConnection.top = new FormAttachment(previous, PropsUi.getMargin());
     } else {
-      fdConnection.top = new FormAttachment(0, props.getMargin());
+      fdConnection.top = new FormAttachment(0, PropsUi.getMargin());
     }
     setLayoutData(fdConnection);
   }
 
+  @Override
+  public void addListener(int eventTYpe, Listener listener) {
+    wCombo.addListener(eventTYpe, listener);
+  }
+
   public void addModifyListener(ModifyListener lsMod) {
     wCombo.addModifyListener(lsMod);
   }
