@@ -27,7 +27,7 @@ import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Shell;
 
 public class VariableButtonListenerFactory {
-  private static final Class<?> PKG = VariableButtonListenerFactory.class; // For Translator
+  private static final Class<?> PKG = VariableButtonListenerFactory.class;
 
   // Listen to the Variable... button
   public static final SelectionAdapter getSelectionAdapter(
@@ -91,9 +91,7 @@ public class VariableButtonListenerFactory {
     esd.clearModal();
     if (esd.open() != null) {
       int nr = esd.getSelectionNr();
-      String var = key[nr];
-
-      return var;
+      return key[nr];
     } else {
       return null;
     }
