@@ -267,19 +267,21 @@ public class ExecutionPerspective implements IHopPerspective, TabClosable {
     //
     ToolBar toolBar = new ToolBar(tabFolder, SWT.FLAT);
     final ToolItem item = new ToolItem(toolBar, SWT.PUSH);
-    item.setImage(GuiResource.getInstance().getImageMinimizePanel());
+    item.setImage(GuiResource.getInstance().getImageMaximizePanel());
     item.addListener(
         SWT.Selection,
         e -> {
           if (sash.getMaximizedControl() == null) {
             sash.setMaximizedControl(tabFolder);
-            item.setImage(GuiResource.getInstance().getImageMaximizePanel());
+            item.setImage(GuiResource.getInstance().getImageMinimizePanel());
           } else {
             sash.setMaximizedControl(null);
-            item.setImage(GuiResource.getInstance().getImageMinimizePanel());
+            item.setImage(GuiResource.getInstance().getImageMaximizePanel());
           }
         });
     tabFolder.setTopRight(toolBar, SWT.RIGHT);
+    int height = toolBar.computeSize(SWT.DEFAULT, SWT.DEFAULT).y;
+    tabFolder.setTabHeight(Math.max(height, tabFolder.getTabHeight()));
 
     new TabCloseHandler(this);
 
@@ -438,6 +440,8 @@ public class ExecutionPerspective implements IHopPerspective, TabClosable {
             addViewer(viewer);
           }
           break;
+        default:
+          break;
       }
     } finally {
       getShell().setCursor(null);
@@ -561,6 +565,8 @@ public class ExecutionPerspective implements IHopPerspective, TabClosable {
                     case Workflow:
                       decorateWorkflowTreeItem(executionItem, execution);
                       break;
+                    default:
+                      break;
                   }
                 }
               } catch (Exception e) {
