@@ -34,6 +34,7 @@ import org.apache.hop.core.plugins.IPlugin;
 import org.apache.hop.core.plugins.PluginRegistry;
 import org.apache.hop.core.search.ISearchable;
 import org.apache.hop.core.util.TranslateUtil;
+import org.apache.hop.core.util.Utils;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.HopMetadata;
 import org.apache.hop.metadata.api.IHopMetadata;
@@ -346,20 +347,24 @@ public class MetadataPerspective implements IHopPerspective, TabClosable {
     // Show/Hide tree
     //
     ToolBar tabToolBar = new ToolBar(tabFolder, SWT.FLAT);
+    tabFolder.setTopRight(tabToolBar, SWT.RIGHT);
+    PropsUi.setLook(tabToolBar);
+
     final ToolItem item = new ToolItem(tabToolBar, SWT.PUSH);
-    item.setImage(GuiResource.getInstance().getImageMinimizePanel());
+    item.setImage(GuiResource.getInstance().getImageMaximizePanel());
     item.addListener(
         SWT.Selection,
         e -> {
           if (sash.getMaximizedControl() == null) {
             sash.setMaximizedControl(tabFolder);
-            item.setImage(GuiResource.getInstance().getImageMaximizePanel());
+            item.setImage(GuiResource.getInstance().getImageMinimizePanel());
           } else {
             sash.setMaximizedControl(null);
-            item.setImage(GuiResource.getInstance().getImageMinimizePanel());
+            item.setImage(GuiResource.getInstance().getImageMaximizePanel());
           }
         });
-    tabFolder.setTopRight(tabToolBar, SWT.RIGHT);
+    int height = tabToolBar.computeSize(SWT.DEFAULT, SWT.DEFAULT).y;
+    tabFolder.setTabHeight(Math.max(height, tabFolder.getTabHeight()));
 
     new TabCloseHandler(this);
 
@@ -844,7 +849,7 @@ public class MetadataPerspective implements IHopPerspective, TabClosable {
           }
           TreeItem parentItem = classItem;
 
-          if (hopMetadata.getVirtualPath() != null && !hopMetadata.getVirtualPath().isEmpty()) {
+          if (!Utils.isEmpty(hopMetadata.getVirtualPath())) {
             List<String> folders =
                 new ArrayList<>(Arrays.asList(hopMetadata.getVirtualPath().split("/")));
             // remove empty elements
@@ -1096,7 +1101,7 @@ public class MetadataPerspective implements IHopPerspective, TabClosable {
                     ? item.getText()
                     : (String) item.getData(VIRTUAL_PATH)));
     String folder = dialog.open();
-    if (folder != null && !folder.isEmpty()) {
+    if (!Utils.isEmpty(folder)) {
       for (TreeItem treeItem : item.getItems()) {
         if (folder.equals(treeItem.getText()) && treeItem.getData("type").equals(FOLDER)) {
           ShowMessageDialog msgDialog =
