@@ -23,8 +23,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.pipeline.transforms.injector.InjectorField;
 import org.apache.hop.pipeline.transforms.injector.InjectorMeta;
 import org.apache.hop.ui.core.PropsUi;
@@ -43,17 +41,17 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.TableItem;
 import org.eclipse.swt.widgets.Text;
 
-public class InjectorDialog extends BaseTransformDialog implements ITransformDialog {
-  private static final Class<?> PKG = InjectorMeta.class; // For Translator
+public class InjectorDialog extends BaseTransformDialog {
+  private static final Class<?> PKG = InjectorMeta.class;
 
   private TableView wFields;
 
   private InjectorMeta input;
 
   public InjectorDialog(
-      Shell parent, IVariables variables, Object in, PipelineMeta pipelineMeta, String sname) {
-    super(parent, variables, (BaseTransformMeta) in, pipelineMeta, sname);
-    input = (InjectorMeta) in;
+      Shell parent, IVariables variables, InjectorMeta transformMeta, PipelineMeta pipelineMeta) {
+    super(parent, variables, transformMeta, pipelineMeta);
+    input = transformMeta;
   }
 
   @Override
@@ -75,7 +73,7 @@ public class InjectorDialog extends BaseTransformDialog implements ITransformDia
     shell.setText(BaseMessages.getString(PKG, "InjectorDialog.Shell.Title"));
 
     int middle = props.getMiddlePct();
-    int margin = props.getMargin();
+    int margin = PropsUi.getMargin();
 
     // TransformName line
     wlTransformName = new Label(shell, SWT.RIGHT);
